@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc 7891 2007-09-27 11:32:09Z andrewross $
+// $Id: plstream.cc 8196 2008-01-30 15:59:12Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -659,7 +659,16 @@ void plstream::gcol0( PLINT icol0, PLINT& r, PLINT& g, PLINT& b )
     plgcol0( icol0, &r, &g, &b );
 }
 
-// Returns the background color by 8 bit RGB value/
+// Returns 8 bit RGB values + alpha value for given color from color map 0.
+
+void plstream::gcol0a( PLINT icol0, PLINT& r, PLINT& g, PLINT& b, PLFLT& a )
+{
+    set_stream();
+
+    plgcol0a( icol0, &r, &g, &b, &a );
+}
+
+// Returns the background color by 8 bit RGB value.
 
 void plstream::gcolbg( PLINT& r, PLINT& g, PLINT& b )
 {
@@ -668,6 +677,15 @@ void plstream::gcolbg( PLINT& r, PLINT& g, PLINT& b )
     plgcolbg( &r, &g, &b );
 }
 
+// Returns the background color by 8 bit RGB value + alpha value.
+
+void plstream::gcolbga( PLINT& r, PLINT& g, PLINT& b, PLFLT& a )
+{
+    set_stream();
+
+    plgcolbga( &r, &g, &b, &a );
+}
+
 // Returns the current compression setting
 
 void plstream::gcompression(PLINT& compression) 
@@ -934,7 +952,7 @@ void plstream::lsty( PLINT lin )
 
 /* plot continental outline in world coordinates */
 
-void plstream::map( void (*mapform)(PLINT, PLFLT *, PLFLT *), char *type,
+void plstream::map( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
 		    PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat )
 {
     set_stream();
@@ -1075,7 +1093,7 @@ void plstream::plot3dcl( PLFLT *x, PLFLT *y, PLFLT **z,
 
 /* Process options list using current options info. */
 
-int plstream::parseopts( int *p_argc, char **argv, PLINT mode )
+int plstream::parseopts( int *p_argc, const char **argv, PLINT mode )
 {
     set_stream();
 
@@ -1241,6 +1259,15 @@ void plstream::scmap0( PLINT *r, PLINT *g, PLINT *b, PLINT ncol0 )
     plscmap0(r,g,b,ncol0);
 }
 
+/* Set color map 0 colors by 8 bit RGB values + alpha value */
+
+void plstream::scmap0a( PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol0 )
+{
+    set_stream();
+
+    plscmap0a(r,g,b,a,ncol0);
+}
+
 /* Set color map 1 colors by 8 bit RGB values */
 
 void plstream::scmap1( PLINT *r, PLINT *g, PLINT *b, PLINT ncol1 )
@@ -1250,6 +1277,15 @@ void plstream::scmap1( PLINT *r, PLINT *g, PLINT *b, PLINT ncol1 )
     plscmap1(r,g,b,ncol1);
 }
 
+/* Set color map 1 colors by 8 bit RGB values + alpha value */
+
+void plstream::scmap1a( PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol1 )
+{
+    set_stream();
+
+    plscmap1a(r,g,b,a,ncol1);
+}
+
 /* Set color map 1 colors using a piece-wise linear relationship between */
 /* intensity [0,1] (cmap 1 index) and position in HLS or RGB color space. */
 
@@ -1273,6 +1309,31 @@ void plstream::scmap1l( bool itype, PLINT npts, PLFLT *intensity,
         delete loc_rev;
 }
 
+/* Set color map 1 colors using a piece-wise linear relationship between */
+/* intensity [0,1] (cmap 1 index) and position in HLS or RGB color space */
+/* and alpha value. */
+
+void plstream::scmap1la( bool itype, PLINT npts, PLFLT *intensity,
+			PLFLT *coord1, PLFLT *coord2, PLFLT *coord3,
+			PLFLT *a, bool *rev )
+{
+    PLBOOL * loc_rev = NULL;
+    if (rev != NULL) {
+        loc_rev = new PLBOOL[npts-1];
+        for (int i=0;i<npts-1;i++) {
+            loc_rev[i] = (PLBOOL) rev[i];
+	}
+    }
+    
+    set_stream();
+
+    plscmap1la((PLBOOL) itype,npts,intensity,coord1,coord2,coord3,a,loc_rev);
+
+    if (loc_rev != NULL)
+        delete loc_rev;
+}
+
+/*
 void plstream::scmap1l( bool itype, PLINT npts, PLFLT *intensity,
 			PLFLT *coord1, PLFLT *coord2, PLFLT *coord3)
 {
@@ -1281,6 +1342,7 @@ void plstream::scmap1l( bool itype, PLINT npts, PLFLT *intensity,
     plscmap1l((PLBOOL) itype,npts,intensity,coord1,coord2,coord3,NULL);
 
 }
+*/
 
 // Deprecated version using PLINT instead of bool
 void plstream::scmap1l( PLINT itype, PLINT npts, PLFLT *intensity,
@@ -1312,6 +1374,15 @@ void plstream::scol0( PLINT icol0, PLINT r, PLINT g, PLINT b )
     plscol0(icol0,r,g,b);
 }
 
+/* Set a given color from color map 0 by 8 bit RGB value + alpha value*/
+
+void plstream::scol0a( PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT a )
+{
+    set_stream();
+
+    plscol0a(icol0,r,g,b,a);
+}
+
 /* Set the background color by 8 bit RGB value */
 
 void plstream::scolbg( PLINT r, PLINT g, PLINT b )
@@ -1321,6 +1392,15 @@ void plstream::scolbg( PLINT r, PLINT g, PLINT b )
     plscolbg(r,g,b);
 }
 
+/* Set the background color by 8 bit RGB + alpha value */
+
+void plstream::scolbga( PLINT r, PLINT g, PLINT b, PLFLT a )
+{
+    set_stream();
+
+    plscolbga(r,g,b,a);
+}
+
 /* Used to globally turn color output on/off */
 
 void plstream::scolor( PLINT color )
@@ -1785,13 +1865,13 @@ void plstream::start( const char *devname, PLINT nx, PLINT ny )
 
 /* Create 1d stripchart */
 
-void plstream::stripc(PLINT *id, char *xspec, char *yspec,
+void plstream::stripc(PLINT *id, const char *xspec, const char *yspec,
         PLFLT xmin, PLFLT xmax, PLFLT xjump, PLFLT ymin, PLFLT ymax,
         PLFLT xlpos, PLFLT ylpos,
         bool y_ascl, bool acc,
         PLINT colbox, PLINT collab,
-        PLINT colline[], PLINT styline[], char *legline[],
-        char *labx, char *laby, char *labtop)
+        PLINT colline[], PLINT styline[], const char *legline[],
+        const char *labx, const char *laby, const char *labtop)
 {
     set_stream();
 
@@ -1802,13 +1882,13 @@ void plstream::stripc(PLINT *id, char *xspec, char *yspec,
 
 
 // Deprecated version using PLINT not bool
-void plstream::stripc(PLINT *id, char *xspec, char *yspec,
+void plstream::stripc(PLINT *id, const char *xspec, const char *yspec,
         PLFLT xmin, PLFLT xmax, PLFLT xjump, PLFLT ymin, PLFLT ymax,
         PLFLT xlpos, PLFLT ylpos,
         PLINT y_ascl, PLINT acc,
         PLINT colbox, PLINT collab,
-        PLINT colline[], PLINT styline[], char *legline[],
-        char *labx, char *laby, char *labtop)
+        PLINT colline[], PLINT styline[], const char *legline[],
+        const char *labx, const char *laby, const char *labtop)
 {
     set_stream();
 
@@ -1919,6 +1999,15 @@ void plstream::text()
     pltext();
 }
 
+/* Set the format for date / time labels */
+
+void plstream::timefmt(const char *fmt)
+{
+    set_stream();
+
+    pltimefmt(fmt);
+}
+
 /* Sets the edges of the viewport with the given aspect ratio, leaving */
 /* room for labels. */
 
@@ -2019,7 +2108,7 @@ void plstream::xormod(PLINT mode, PLINT *status)
 
 /* Returns a list of file-oriented device names and their menu strings */
 
-void plstream::gFileDevs( char ***p_menustr, char ***p_devname, int *p_ndev )
+void plstream::gFileDevs( const char ***p_menustr, const char ***p_devname, int *p_ndev )
 {
     set_stream();
 
@@ -2046,7 +2135,7 @@ void plstream::sError(PLINT *errcode, char *errmsg) {
 
 /* Sets an optional user exit handler. */
 
-void plstream::sexit( int (*handler) (char *) )
+void plstream::sexit( int (*handler) (const char *) )
 {
     set_stream();
 
@@ -2172,7 +2261,7 @@ void plstream::ResetOpts()
 
 /* Merge user option table into internal info structure. */
 
-int plstream::MergeOpts( PLOptionTable *options, char *name, char **notes )
+int plstream::MergeOpts( PLOptionTable *options, const char *name, const char **notes )
 {
     set_stream();
 
@@ -2190,7 +2279,7 @@ void plstream::SetUsage( char *program_string, char *usage_string )
 
 /* Process input strings, treating them as an option and argument pair. */
 
-int plstream::SetOpt( char *opt, char *optarg )
+int plstream::SetOpt( const char *opt, const char *optarg )
 {
     set_stream();
 
@@ -2199,7 +2288,7 @@ int plstream::SetOpt( char *opt, char *optarg )
 
 /* Process options list using current options info. */
 
-int plstream::ParseOpts( int *p_argc, char **argv, PLINT mode )
+int plstream::ParseOpts( int *p_argc, const char **argv, PLINT mode )
 {
     set_stream();
 
