@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.h,v 1.28 2005/12/06 16:36:02 andrewross Exp $
+// $Id: plstream.h 8196 2008-01-30 15:59:12Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -68,7 +68,7 @@ class Coord_2d {
     virtual void min_max( PLFLT& _min, PLFLT& _max ) =0;
 };
 
-class cxx_pltr2 : public Coord_Xformer {
+class PLDLLIMPEXP cxx_pltr2 : public Coord_Xformer {
     Coord_2d& xg;
     Coord_2d& yg;
   public:
@@ -82,7 +82,7 @@ class cxx_pltr2 : public Coord_Xformer {
 // Cool stuff.
 //===========================================================================//
 
-class plstream {
+class PLDLLIMPEXP plstream {
 
     PLINT stream;
 
@@ -195,9 +195,8 @@ class plstream {
 		void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 		PLPointer pltr_data );
 
-// /* Copies state parameters from the reference stream to the current stream. */
+// Copies state parameters from the reference stream to the current stream.
 
-//     void cpstrm( PLINT iplsr, PLINT flags );
      void cpstrm( plstream &pls, bool flags );
 
 // Converts input values from relative device coordinates to relative plot
@@ -276,10 +275,18 @@ class plstream {
 
     void gcol0( PLINT icol0, PLINT& r, PLINT& g, PLINT& b );
 
+// Returns 8 bit RGB and 0.0-1.0 alpha values for given color from color map 0.
+
+    void gcol0a( PLINT icol0, PLINT& r, PLINT& g, PLINT& b, PLFLT& a );
+
 // Returns the background color by 8 bit RGB value.
 
     void gcolbg( PLINT& r, PLINT& g, PLINT& b );
 
+// Returns the background color by 8 bit RGB and 0.0-1.0 alpha values.
+
+    void gcolbga( PLINT& r, PLINT& g, PLINT& b, PLFLT& a );
+
 // Returns the current compression setting
 
     void gcompression(PLINT& compression);
@@ -400,7 +407,7 @@ class plstream {
 
 /* plot continental outline in world coordinates */
 
-    void map( void (*mapform)(PLINT, PLFLT *, PLFLT *), char *type,
+    void map( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
 	      PLFLT minlong, PLFLT maxlong, PLFLT minlat, PLFLT maxlat );
 
 /* Plot the latitudes and longitudes on the background. */
@@ -428,10 +435,15 @@ class plstream {
     void mtex( const char *side, PLFLT disp, PLFLT pos, PLFLT just,
 	       const char *text );
 
+/* Prints out "text" at specified position relative to viewport (3D) */
+
+    void mtex3( const char *side, PLFLT disp, PLFLT pos, PLFLT just,
+	       const char *text );
+
 /* Plots a 3-d representation of the function z[x][y]. */
 
     void plot3d( PLFLT *x, PLFLT *y, PLFLT **z,
-		 PLINT nx, PLINT ny, PLINT opt, PLINT side );
+		 PLINT nx, PLINT ny, PLINT opt, bool side );
 
 /* Plots a 3-d representation of the function z[x][y] with contour. */
 
@@ -465,7 +477,7 @@ class plstream {
     
 /* Process options list using current options info. */
 
-    int parseopts( int *p_argc, char **argv, PLINT mode );
+    int parseopts( int *p_argc, const char **argv, PLINT mode );
 
 /* Set fill pattern directly. */
 
@@ -481,7 +493,7 @@ void pat( PLINT nlin, PLINT *inc, PLINT *del );
 
 /* Draws a polygon in 3 space.  */
 
-    void poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT *draw, bool ifcc );
+    void poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, bool *draw, bool ifcc );
 
 /* Set the floating point precision (in number of places) in numeric labels. */
 
@@ -496,6 +508,11 @@ void pat( PLINT nlin, PLINT *inc, PLINT *del );
     void ptex( PLFLT x, PLFLT y, PLFLT dx, PLFLT dy, PLFLT just,
 	       const char *text );
 
+/* Prints out "text" at world cooordinate (x,y,z). */
+
+    void ptex3(PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz, 
+	     PLFLT sx, PLFLT sy, PLFLT sz, PLFLT just, const char *text);
+
 /* Replays contents of plot buffer to current device/file. */
 
     void replot();
@@ -524,24 +541,51 @@ void pat( PLINT nlin, PLINT *inc, PLINT *del );
 
     void scmap0( PLINT *r, PLINT *g, PLINT *b, PLINT ncol0 );
 
+/* Set color map 0 colors by 8 bit RGB values and alpha value (0.0-1.0) */
+
+    void scmap0a( PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol0 );
+
 /* Set color map 1 colors by 8 bit RGB values */
 
     void scmap1( PLINT *r, PLINT *g, PLINT *b, PLINT ncol1 );
 
+/* Set color map 1 colors by 8 bit RGB values and alpha value (0.0-1.0) */
+
+    void scmap1a( PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol1 );
+
 /* Set color map 1 colors using a piece-wise linear relationship between */
 /* intensity [0,1] (cmap 1 index) and position in HLS or RGB color space. */
 
     void scmap1l( bool itype, PLINT npts, PLFLT *intensity,
-		  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, bool *rev );
+		  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, bool *rev = NULL );
+
+/*    void scmap1l( bool itype, PLINT npts, PLFLT *intensity,
+		  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3 );*/
+
+/* Set color map 1 colors using a piece-wise linear relationship between */
+/* intensity [0,1] (cmap 1 index) and position in HLS or RGB color space. */
+/* Include alpha value in range 0.0-1.0.*/
+
+    void scmap1la( bool itype, PLINT npts, PLFLT *intensity,
+		   PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLFLT *a, 
+		   bool *rev = NULL );
 
 /* Set a given color from color map 0 by 8 bit RGB value */
 
     void scol0( PLINT icol0, PLINT r, PLINT g, PLINT b );
 
+/* Set a given color from color map 0 by 8 bit RGB value and alpha value (0.0-1.0) */
+
+    void scol0a( PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT a );
+
 /* Set the background color by 8 bit RGB value */
 
     void scolbg( PLINT r, PLINT g, PLINT b );
 
+/* Set the background color by 8 bit RGB + alpha value */
+
+    void scolbga( PLINT r, PLINT g, PLINT b, PLFLT a );
+
 /* Used to globally turn color output on/off */
 
     void scolor( PLINT color );
@@ -706,13 +750,13 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Create 1d stripchart */
 
-    void stripc(PLINT *id, char *xspec, char *yspec,
+    void stripc(PLINT *id, const char *xspec, const char *yspec,
         PLFLT xmin, PLFLT xmax, PLFLT xjump, PLFLT ymin, PLFLT ymax,
         PLFLT xlpos, PLFLT ylpos,
         bool y_ascl, bool acc,
         PLINT colbox, PLINT collab,
-        PLINT colline[], PLINT styline[], char *legline[],
-        char *labx, char *laby, char *labtop);
+        PLINT colline[], PLINT styline[], const char *legline[],
+        const char *labx, const char *laby, const char *labtop);
 
 /* Add a point to a stripchart.  */
 
@@ -760,6 +804,10 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     void text();
 
+/* Set the format for date / time labels */
+
+    void timefmt(const char *fmt);
+
 /* Sets the edges of the viewport with the given aspect ratio, leaving */
 /* room for labels. */
 
@@ -800,7 +848,7 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Returns a list of file-oriented device names and their menu strings */
 
-    void gFileDevs( char ***p_menustr, char ***p_devname, int *p_ndev );
+    void gFileDevs( const char ***p_menustr, const char ***p_devname, int *p_ndev );
 
 /* Set the function pointer for the keyboard event handler */
 
@@ -821,7 +869,7 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Sets an optional user exit handler. */
 
-    void sexit( int (*handler) (char *) );
+    void sexit( int (*handler) (const char *) );
 
 	/* Transformation routines */
 
@@ -887,7 +935,7 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Merge user option table into internal info structure. */
 
-    int MergeOpts( PLOptionTable *options, char *name, char **notes );
+    int MergeOpts( PLOptionTable *options, const char *name, const char **notes );
 
 /* Set the strings used in usage and syntax messages. */
 
@@ -895,11 +943,11 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
 /* Process input strings, treating them as an option and argument pair. */
 
-    int SetOpt( char *opt, char *optarg );
+    int SetOpt( const char *opt, const char *optarg );
 
 /* Process options list using current options info. */
 
-    int ParseOpts( int *p_argc, char **argv, PLINT mode );
+    int ParseOpts( int *p_argc, const char **argv, PLINT mode );
 
 /* Print usage & syntax message. */
 
@@ -969,9 +1017,11 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     int GetCursor( PLGraphicsIn *plg );
 
-// Depreciated versions of methods which use PLINT instead of bool
+// Deprecated versions of methods which use PLINT instead of bool
     void svect( PLFLT *arrow_x, PLFLT *arrow_y, PLINT npts, PLINT fill);
     void cpstrm( plstream &pls, PLINT flags );
+    void plot3d( PLFLT *x, PLFLT *y, PLFLT **z,
+		 PLINT nx, PLINT ny, PLINT opt, PLINT side );
     void poly3( PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT *draw, PLINT ifcc );
     void scmap1l( PLINT itype, PLINT npts, PLFLT *intensity,
 		  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLINT *rev );
@@ -1030,13 +1080,13 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     void spause( PLINT pause );
 
-    void stripc(PLINT *id, char *xspec, char *yspec,
+    void stripc(PLINT *id, const char *xspec, const char *yspec,
         PLFLT xmin, PLFLT xmax, PLFLT xjump, PLFLT ymin, PLFLT ymax,
         PLFLT xlpos, PLFLT ylpos,
         PLINT y_ascl, PLINT acc,
         PLINT colbox, PLINT collab,
-        PLINT colline[], PLINT styline[], char *legline[],
-        char *labx, char *laby, char *labtop);
+        PLINT colline[], PLINT styline[], const char *legline[],
+        const char *labx, const char *laby, const char *labtop);
 
     void xormod(PLINT mode, PLINT *status);
 };
