@@ -1,4 +1,4 @@
-/* $Id: plstubs.h 7909 2007-09-30 20:58:26Z airwin $
+/* $Id: plstubs.h 8187 2008-01-29 17:24:29Z andrewross $
 
    Maurice LeBrun
    IFS, University of Texas
@@ -190,6 +190,7 @@
 #define    PLFONTLD	FNAME(PLFONTLD,plfontld)
 #define    PLGCHR	FNAME(PLGCHR,plgchr)
 #define    PLGCOL0	FNAME(PLGCOL0,plgcol0)
+#define    PLGCOL0A	FNAME(PLGCOL0A,plgcol0a)
 #define    PLGCOLBG	FNAME(PLGCOLBG,plgcolbg)
 #define    PLGCOMPRESSION	FNAME(PLGCOMPRESSION,plgcompression)
 #define    PLGDEV7	FNAME(PLGDEV7,plgdev7)
@@ -245,12 +246,17 @@
 #define    PLRGBHLS     FNAME(PLRGBHLS,plrgbhls)
 #define    PLSCHR	FNAME(PLSCHR,plschr)
 #define    PLSCMAP0	FNAME(PLSCMAP0,plscmap0)
+#define    PLSCMAP0A	FNAME(PLSCMAP0A,plscmap0a)
 #define    PLSCMAP0N	FNAME(PLSCMAP0N,plscmap0n)
 #define    PLSCMAP1	FNAME(PLSCMAP1,plscmap1)
+#define    PLSCMAP1A	FNAME(PLSCMAP1A,plscmap1a)
 #define    PLSCMAP1L	FNAME(PLSCMAP1L,plscmap1l)
+#define    PLSCMAP1LA	FNAME(PLSCMAP1LA,plscmap1la)
 #define    PLSCMAP1N	FNAME(PLSCMAP1N,plscmap1n)
 #define    PLSCOL0	FNAME(PLSCOL0,plscol0)
+#define    PLSCOL0A	FNAME(PLSCOL0A,plscol0a)
 #define    PLSCOLBG	FNAME(PLSCOLBG,plscolbg)
+#define    PLSCOLBGA	FNAME(PLSCOLBGA,plscolbga)
 #define    PLSCOLOR	FNAME(PLSCOLOR,plscolor)
 #define    PLSCOMPRESSION	FNAME(PLSCOMPRESSION,plscompression)
 #define    PLSDEV7	FNAME(PLSDEV7,plsdev7)
@@ -295,6 +301,7 @@
 #define    PLSYM	FNAME(PLSYM,plsym)
 #define    PLSZAX	FNAME(PLSZAX,plszax)
 #define    PLTEXT	FNAME(PLTEXT,pltext)
+#define    PLTIMEFMT7	FNAME(PLTIMEFMT7,pltimefmt7)
 #define    PLVASP	FNAME(PLVASP,plvasp)
 #define    PLVEC07	FNAME(PLVEC07,plvec07)
 #define    PLVEC17	FNAME(PLVEC17,plvec17)
