@@ -1,4 +1,4 @@
-/* $Id: sc3d.c,v 1.14 2005/04/27 06:43:09 rlaboiss Exp $
+/* $Id: sc3d.c 7308 2007-01-07 21:43:02Z smekal $
 
 	Stub routines for 3d plots.
 
@@ -97,7 +97,7 @@ PLMESH(PLFLT *x, PLFLT *y, PLFLT *z,
    PLFLT clevel = 0.;
 
    optlocal = *opt | MESH;
-   PLOT3DC(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
+   PLOT3DC_(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
 }
 
 void
@@ -107,7 +107,7 @@ PLMESHC(PLFLT *x, PLFLT *y, PLFLT *z,
 {
    PLINT optlocal;
    optlocal = *opt | MESH;
-   PLOT3DC(x, y, z, nx, ny, &optlocal, clevel, nlevel, lx);
+   PLOT3DC_(x, y, z, nx, ny, &optlocal, clevel, nlevel, lx);
 }
 
 
@@ -119,6 +119,6 @@ PLOT3D(PLFLT *x, PLFLT *y, PLFLT *z,
    PLFLT clevel = 0.;
 
    optlocal = *opt | (*side == 1 ? DRAW_SIDES : 0);
-   PLOT3DC(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
+   PLOT3DC_(x, y, z, nx, ny, &optlocal, &clevel, &nlevel, lx);
 }
 
