@@ -1,4 +1,4 @@
-/* $Id: sccont.c 7308 2007-01-07 21:43:02Z smekal $
+/* $Id: sccont.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Contour plotter front-ends for Fortran.
 
@@ -438,7 +438,7 @@ PLVECT7(PLFLT *u, PLFLT *v, PLINT *nx, PLINT *ny, PLFLT *scale,
 \*----------------------------------------------------------------------*/
 
 void
-PLSHADE07(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADE07(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	  PLFLT *shade_min, PLFLT *shade_max,
 	  PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
@@ -472,7 +472,7 @@ PLSHADE07(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 /* 1-d transformation */
 
 void
-PLSHADE17(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADE17(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	  PLFLT *shade_min, PLFLT *shade_max,
 	  PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
@@ -511,7 +511,7 @@ PLSHADE17(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 /* 2-d transformation */
 
 void
-PLSHADE27(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADE27(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	  PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	  PLFLT *shade_min, PLFLT *shade_max,
 	  PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
@@ -553,7 +553,7 @@ PLSHADE27(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 }
 
 void
-PLSHADE7(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADE7(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	 PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	 PLFLT *shade_min, PLFLT *shade_max,
 	 PLINT *sh_cmap, PLFLT *sh_color, PLINT *sh_width,
@@ -594,7 +594,7 @@ PLSHADE7(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 \*----------------------------------------------------------------------*/
 
 void
-PLSHADES07(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADES07(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	   PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	   PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
 	   PLINT *cont_color, PLINT *cont_width, PLINT *lx)
@@ -622,7 +622,7 @@ PLSHADES07(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 }
 
 void
-PLSHADES17(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADES17(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	   PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	   PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
 	   PLINT *cont_color, PLINT *cont_width,
@@ -657,7 +657,7 @@ PLSHADES17(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 }
 
 void
-PLSHADES27(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADES27(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	   PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	   PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
 	   PLINT *cont_color, PLINT *cont_width,
@@ -695,7 +695,7 @@ PLSHADES27(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
 }
 
 void
-PLSHADES7(PLFLT *z, PLINT *nx, PLINT *ny, char *defined,
+PLSHADES7(PLFLT *z, PLINT *nx, PLINT *ny, const char *defined,
 	   PLFLT *xmin, PLFLT *xmax, PLFLT *ymin, PLFLT *ymax,
 	   PLFLT *clevel, PLINT *nlevel, PLINT *fill_width,
 	   PLINT *cont_color, PLINT *cont_width, PLFLT *ftr, PLINT *lx)
