@@ -1,4 +1,4 @@
-/* $Id: plstubs.h 7910 2007-09-30 20:59:00Z airwin $
+/* $Id: plstubs.h 8164 2008-01-23 10:59:02Z andrewross $
 
    Maurice LeBrun
    IFS, University of Texas
@@ -179,7 +179,9 @@
 #define    PLFONTLD	FNAME(PLFONTLD,plfontld)
 #define    PLGCHR	FNAME(PLGCHR,plgchr)
 #define    PLGCOL0	FNAME(PLGCOL0,plgcol0)
+#define    PLGCOL0A	FNAME(PLGCOL0A,plgcol0a)
 #define    PLGCOLBG	FNAME(PLGCOLBG,plgcolbg)
+#define    PLGCOLBGA	FNAME(PLGCOLBGA,plgcolbga)
 #define    PLGCOMPRESSION	FNAME(PLGCOMPRESSION,plgcompression)
 #define    PLGDEV7	FNAME(PLGDEV7,plgdev7)
 #define    PLGDIDEV	FNAME(PLGDIDEV,plgdidev)
@@ -240,13 +242,19 @@
 #define    PLRGBHLS     FNAME(PLRGBHLS,plrgbhls)
 #define    PLSCHR	FNAME(PLSCHR,plschr)
 #define    PLSCMAP0	FNAME(PLSCMAP0F77,plscmap0f77)
+#define    PLSCMAP0A	FNAME(PLSCMAP0AF77,plscmap0af77)
 #define    PLSCMAP0N	FNAME(PLSCMAP0N,plscmap0n)
 #define    PLSCMAP1	FNAME(PLSCMAP1F77,plscmap1f77)
+#define    PLSCMAP1A	FNAME(PLSCMAP1AF77,plscmap1af77)
 #define    PLSCMAP1L	FNAME(PLSCMAP1LF77,plscmap1lf77)
+#define    PLSCMAP1L2	FNAME(PLSCMAP1L2F77,plscmap1l2f77)
 #define    PLSCMAP1LA	FNAME(PLSCMAP1LAF77,plscmap1laf77)
+#define    PLSCMAP1LA2	FNAME(PLSCMAP1LA2F77,plscmap1la2f77)
 #define    PLSCMAP1N	FNAME(PLSCMAP1N,plscmap1n)
 #define    PLSCOL0	FNAME(PLSCOL0,plscol0)
+#define    PLSCOL0A	FNAME(PLSCOL0A,plscol0a)
 #define    PLSCOLBG	FNAME(PLSCOLBG,plscolbg)
+#define    PLSCOLBGA	FNAME(PLSCOLBGA,plscolbga)
 #define    PLSCOLOR	FNAME(PLSCOLOR,plscolor)
 #define    PLSCOMPRESSION	FNAME(PLSCOMPRESSION,plscompression)
 #define    PLSDEV7	FNAME(PLSDEV7,plsdev7)
@@ -291,6 +299,7 @@
 #define    PLSYM	FNAME(PLSYMF77,plsymf77)
 #define    PLSZAX	FNAME(PLSZAX,plszax)
 #define    PLTEXT	FNAME(PLTEXT,pltext)
+#define    PLTIMEFMT7	FNAME(PLTIMEFMT7,pltimefmt7)
 #define    PLVASP	FNAME(PLVASP,plvasp)
 #define    PLVEC07	FNAME(PLVEC07,plvec07)
 #define    PLVEC17	FNAME(PLVEC17,plvec17)
