@@ -1,4 +1,4 @@
-/* $Id: scstubs.c 7910 2007-09-30 20:59:00Z airwin $
+/* $Id: scstubs.c 8164 2008-01-23 10:59:02Z andrewross $
 
 	C stub routines.
 
@@ -63,8 +63,8 @@ PLADV(PLINT *sub)
 }
 
 void
-PLAXES7(PLFLT *x0, PLFLT *y0, char *xopt, PLFLT *xtick,
-	PLINT *nxsub, char *yopt, PLFLT *ytick, PLINT *nysub)
+PLAXES7(PLFLT *x0, PLFLT *y0, const char *xopt, PLFLT *xtick,
+	PLINT *nxsub, const char *yopt, PLFLT *ytick, PLINT *nysub)
 {
     c_plaxes(*x0, *y0, xopt, *xtick, *nxsub, yopt, *ytick, *nysub);
 }
@@ -82,16 +82,16 @@ PLBOP(void)
 }
 
 void
-PLBOX7(char *xopt, PLFLT *xtick, PLINT *nxsub,
-       char *yopt, PLFLT *ytick, PLINT *nysub)
+PLBOX7(const char *xopt, PLFLT *xtick, PLINT *nxsub,
+       const char *yopt, PLFLT *ytick, PLINT *nysub)
 {
     c_plbox(xopt, *xtick, *nxsub, yopt, *ytick, *nysub);
 }
 
 void
-PLBOX37(char *xopt, char *xlabel, PLFLT *xtick, PLINT *nxsub,
-	char *yopt, char *ylabel, PLFLT *ytick, PLINT *nysub,
-	char *zopt, char *zlabel, PLFLT *ztick, PLINT *nzsub)
+PLBOX37(const char *xopt, const char *xlabel, PLFLT *xtick, PLINT *nxsub,
+	const char *yopt, const char *ylabel, PLFLT *ytick, PLINT *nysub,
+	const char *zopt, const char *zlabel, PLFLT *ztick, PLINT *nzsub)
 {
     c_plbox3(xopt, xlabel, *xtick, *nxsub,
 	     yopt, ylabel, *ytick, *nysub,
@@ -227,12 +227,24 @@ PLGCOL0(PLINT *icol0, PLINT *r, PLINT *g, PLINT *b)
     c_plgcol0(*icol0, r, g, b);
 }
 
+void
+PLGCOL0A(PLINT *icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+    c_plgcol0a(*icol0, r, g, b, a);
+}
+
 void
 PLGCOLBG(PLINT *r, PLINT *g, PLINT *b)
 {
     c_plgcolbg(r, g, b);
 }
 
+void
+PLGCOLBGA(PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+    c_plgcolbga(r, g, b, a);
+}
+
 void
 PLGCOMPRESSION(PLINT *compression)
 {
@@ -386,7 +398,7 @@ PLJOIN(PLFLT *x1, PLFLT *y1, PLFLT *x2, PLFLT *y2)
 }
 
 void
-PLLAB7(char *xlab, char *ylab, char *title)
+PLLAB7(const char *xlab, const char *ylab, const char *title)
 {
     c_pllab(xlab, ylab, title);
 }
@@ -422,7 +434,7 @@ plmapf2c( PLINT n, PLFLT *x, PLFLT *y )
 }
 
 void
-PLMAPC( char *type,
+PLMAPC( const char *type,
         PLFLT *minlong, PLFLT *maxlong, PLFLT *minlat, PLFLT *maxlat )
 
 {
@@ -444,24 +456,24 @@ PLMKSTRM(PLINT *p_strm)
 }
 
 void
-PLMTEX7(char *side, PLFLT *disp, PLFLT *pos, PLFLT *just, char *text)
+PLMTEX7(const char *side, PLFLT *disp, PLFLT *pos, PLFLT *just, const char *text)
 {
     c_plmtex(side, *disp, *pos, *just, text);
 }
 
 void
-PLMTEX37(char *side, PLFLT *disp, PLFLT *pos, PLFLT *just, char *text)
+PLMTEX37(const char *side, PLFLT *disp, PLFLT *pos, PLFLT *just, const char *text)
 {
     c_plmtex3(side, *disp, *pos, *just, text);
 }
 
 void
-PLPARSEOPTS7(int *numargs, char *iargs, PLINT *mode, PLINT *maxindex)
+PLPARSEOPTS7(int *numargs, const char *iargs, PLINT *mode, PLINT *maxindex)
 {
 /* Same as in plparseopts fortran subroutine that calls this one. */
 #define MAXARGS 20
    if(*numargs <= MAXARGS) {
-      char *argv[MAXARGS];
+      const char *argv[MAXARGS];
       int i;
       for(i = 0; i < *numargs; i++) {
 	 argv[i] = iargs + (i* *maxindex);
@@ -509,7 +521,7 @@ PLPSTY(PLINT *patt)
 }
 
 void
-PLPTEX7(PLFLT *x, PLFLT *y, PLFLT *dx, PLFLT *dy, PLFLT *just, char *text)
+PLPTEX7(PLFLT *x, PLFLT *y, PLFLT *dx, PLFLT *dy, PLFLT *just, const char *text)
 {
     c_plptex(*x, *y, *dx, *dy, *just, text);
 }
@@ -519,7 +531,7 @@ PLPTEX37(
 	 PLFLT *x, PLFLT *y, PLFLT *z, 
 	 PLFLT *dx, PLFLT *dy, PLFLT *dz,
 	 PLFLT *sx, PLFLT *sy, PLFLT *sz,
-	 PLFLT *just, char *text)
+	 PLFLT *just, const char *text)
 {
     c_plptex3(*x, *y, *z, *dx, *dy, *dz, *sx, *sy, *sz, *just, text);
 }
@@ -560,6 +572,12 @@ PLSCMAP0(PLINT *r, PLINT *g, PLINT *b, PLINT *ncol0)
     c_plscmap0(r, g, b, *ncol0);
 }
 
+void
+PLSCMAP0A(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT *ncol0)
+{
+    c_plscmap0a(r, g, b, a, *ncol0);
+}
+
 void
 PLSCMAP0N(PLINT *n)
 {
@@ -572,6 +590,12 @@ PLSCMAP1(PLINT *r, PLINT *g, PLINT *b, PLINT *ncol1)
     c_plscmap1(r, g, b, *ncol1);
 }
 
+void
+PLSCMAP1A(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT *ncol1)
+{
+    c_plscmap1a(r, g, b, a, *ncol1);
+}
+
 void
 PLSCMAP1L(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
 	  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLBOOL *rev)
@@ -580,12 +604,26 @@ PLSCMAP1L(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
 }
 
 void
-PLSCMAP1LA(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
+PLSCMAP1L2(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
 	  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3)
 {
     c_plscmap1l(*itype, *npts, intensity, coord1, coord2, coord3, NULL);
 }
 
+void
+PLSCMAP1LA(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
+	  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLFLT *a, PLBOOL *rev)
+{
+    c_plscmap1la(*itype, *npts, intensity, coord1, coord2, coord3, a, rev);
+}
+
+void
+PLSCMAP1LA2(PLBOOL *itype, PLINT *npts, PLFLT *intensity,
+	  PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLFLT *a)
+{
+    c_plscmap1la(*itype, *npts, intensity, coord1, coord2, coord3, a, NULL);
+}
+
 void
 PLSCMAP1N(PLINT *n)
 {
@@ -598,12 +636,24 @@ PLSCOL0(PLINT *icol0, PLINT *r, PLINT *g, PLINT *b)
     c_plscol0(*icol0, *r, *g, *b);
 }
 
+void
+PLSCOL0A(PLINT *icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+    c_plscol0a(*icol0, *r, *g, *b, *a);
+}
+
 void
 PLSCOLBG(PLINT *r, PLINT *g, PLINT *b)
 {
     c_plscolbg(*r, *g, *b);
 }
 
+void
+PLSCOLBGA(PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+    c_plscolbga(*r, *g, *b, *a);
+}
+
 void
 PLSCOLOR(PLINT *color)
 {
@@ -617,7 +667,7 @@ PLSCOMPRESSION(PLINT *compression)
 }
 
 void
-PLSDEV7(char *dev)
+PLSDEV7(const char *dev)
 {
     c_plsdev(dev);
 }
@@ -667,7 +717,7 @@ PLSETMAPFORMC( void (*mapform)(PLINT *, PLFLT *, PLFLT *) )
 }
 
 void
-PLSETOPT7(char *opt, char *optarg)
+PLSETOPT7(const char *opt, const char *optarg)
 {
     c_plsetopt(opt, optarg);
 }
@@ -679,7 +729,7 @@ PLSFAM(PLINT *fam, PLINT *num, PLINT *bmax)
 }
 
 void
-PLSFNAM7(char *fnam)
+PLSFNAM7(const char *fnam)
 {
     c_plsfnam(fnam);
 }
@@ -746,7 +796,7 @@ PLSTAR(PLINT *nx, PLINT *ny)
 }
 
 void
-PLSTART7(char *devname, PLINT *nx, PLINT *ny)
+PLSTART7(const char *devname, PLINT *nx, PLINT *ny)
 {
     c_plstart(devname, *nx, *ny);
 }
@@ -758,16 +808,17 @@ PLSTRIPA(PLINT *id, PLINT *pen, PLFLT *x, PLFLT *y)
 }
 
 void
-PLSTRIPC(PLINT *id, char *xspec, char *yspec,
+PLSTRIPC(PLINT *id, const char *xspec, const char *yspec,
 	  PLFLT *xmin, PLFLT *xmax, PLFLT *xjump, PLFLT *ymin, PLFLT *ymax,
 	  PLFLT *xlpos, PLFLT *ylpos,
 	  PLBOOL *y_ascl, PLBOOL *acc,
 	  PLINT *colbox, PLINT *collab,
 	  PLINT *colline, PLINT *styline,
-	  char *legline0, char *legline1, char *legline2, char *legline3,
-	  char *labx, char *laby, char *labtop)
+	  const char *legline0, const char *legline1, 
+          const char *legline2, const char *legline3,
+	  const char *labx, const char *laby, const char *labtop)
 {
-   char* legline[4];
+   const char* legline[4];
    legline[0] = legline0;
    legline[1] = legline1;
    legline[2] = legline2;
@@ -836,6 +887,12 @@ PLTEXT(void)
     c_pltext();
 }
 
+void
+PLTIMEFMT7(const char *fmt)
+{
+    c_pltimefmt(fmt);
+}
+
 void
 PLVASP(PLFLT *aspect)
 {
