@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 7920 2007-10-02 11:35:57Z andrewross $
+!  $Id: sfstubs.f90 8164 2008-01-23 10:59:02Z andrewross $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -717,3 +717,19 @@
 
       end subroutine
 
+!***********************************************************************
+
+      subroutine pltimefmt(fmt)
+
+      implicit none
+      character*(*) fmt 
+
+      include 'sfstubs.h'
+
+      call plstrf2c(fmt, string1, maxlen)
+      s1 = transfer( string1, s1 )
+      call pltimefmt7(s1)
+
+      end subroutine
+
+!***********************************************************************
