@@ -14,8 +14,10 @@
 
 function p2 
 
-  t = automatic_replot;
-  automatic_replot = 0;
+  if (exist("automatic_replot"))
+    t = automatic_replot;
+    automatic_replot = 0;
+  endif
 
   legend("opaque",0)
   title("PLplot Example 2");
@@ -28,7 +30,9 @@ function p2
        x, y2, 'b;sin(x)*cos(2*x);',
        x, y3, 'g;x*sin(x);');
   
-  automatic_replot = t;
-  
+  if (exist("automatic_replot"))
+    automatic_replot = t;
+  endif
+
 endfunction
 
