@@ -14,8 +14,10 @@
 
 function p3
 
-  t = automatic_replot;
-  automatic_replot = 0;
+  if (exist("automatic_replot"))
+    t = automatic_replot;
+    automatic_replot = 0;
+  endif
 
   xscale = 6.;
   yscale = 1.;
@@ -37,6 +39,8 @@ function p3
   title("#frPLplot Example 3 - y=x#u2 #d(with error bars)");
   plot(x, y, [xs' xe'], [ys' yel' yer'], '~g; ;');
 
-  automatic_replot = t;
+  if (exist("automatic_replot"))
+    automatic_replot = t;
+  endif
 
 endfunction
