@@ -47,7 +47,7 @@ function x07c
 
     ## Draw the grid using plbox */
 
-    plbox("bcgt", 0.1, 0, "bcgt", 0.1, 0);
+    plbox("bcg", 0.1, 0, "bcg", 0.1, 0);
 
     ## Write the digits below the frame */
 
