@@ -1,4 +1,4 @@
-/* $Id: tclMain.c 7083 2006-09-19 04:47:04Z arjenmarkus $
+/* $Id: tclMain.c 8186 2008-01-29 10:50:48Z andrewross $
  *
  * Modified version of tclMain.c, from Tcl 8.3.2.
  * Maurice LeBrun
@@ -45,7 +45,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclMain.c 7083 2006-09-19 04:47:04Z arjenmarkus $
+ * RCS: @(#) $Id: tclMain.c 8186 2008-01-29 10:50:48Z andrewross $
  */
 
 #include <tcl.h>
@@ -53,10 +53,17 @@
 #define MAKINGPLDLL
 #include "pldll.h"
 
-/* From tclIntDecls.h */
-
+#ifdef HAVE_TCL_GT_84
+/* From (private) tclInt.h in tcl8.5 */
+#define TclFormatInt(buf, n)            sprintf((buf), "%ld", (long)(n))
+#else
+/* From (private) tclIntDecls.h in tcl8.4 and before*/
 EXTERN int		TclFormatInt _ANSI_ARGS_((char * buffer, long n));
+#endif
+
+#ifndef TclObjCommandComplete_TCL_DECLARED
 EXTERN int		TclObjCommandComplete _ANSI_ARGS_((Tcl_Obj * cmdPtr));
+#endif
 
 # undef TCL_STORAGE_CLASS
 # define TCL_STORAGE_CLASS DLLEXPORT
@@ -83,7 +90,7 @@ int (*tclDummyLinkVarPtr)() = Tcl_LinkVar;
 extern int		isatty _ANSI_ARGS_((int fd));
 extern char *		strcpy _ANSI_ARGS_((char *dst, CONST char *src));
 
-static char *tclStartupScriptFileName = NULL;
+static const char *tclStartupScriptFileName = NULL;
 
 /* pltcl enhancements */
 
@@ -100,7 +107,7 @@ void (*tclPrepOutputHandler)(Tcl_Interp *interp, int code, int tty)
 /* Options data structure definition. */
 
 static char *tclStartupScript = NULL;
-static char *pltcl_notes[] = {
+static const char *pltcl_notes[] = {
     "Specifying the filename on the command line is compatible with modern",
     "tclsh syntax.  Old tclsh's used the -f syntax, which is still supported.",
     "You may use either syntax but not both.",
@@ -181,7 +188,7 @@ void TclSetStartupScriptFileName(char *fileName)
  *
  *----------------------------------------------------------------------
  */
-char *TclGetStartupScriptFileName(void)
+const char *TclGetStartupScriptFileName(void)
 {
     return tclStartupScriptFileName;
 }
@@ -208,7 +215,7 @@ char *TclGetStartupScriptFileName(void)
  */
 
 int PLDLLEXPORT
-pltclMain(int argc, char **argv, char *RcFileName /* OBSOLETE */,
+pltclMain(int argc, const char **argv, char *RcFileName /* OBSOLETE */,
 	  int (*appInitProc)(Tcl_Interp *interp))
 {
     Tcl_Obj *resultPtr;
