@@ -1,5 +1,5 @@
 /* -*-C++-*-
- * $Id: tclMatrix.h 7082 2006-09-18 04:36:21Z arjenmarkus $
+ * $Id: tclMatrix.h 8186 2008-01-29 10:50:48Z andrewross $
 
     Copyright 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -76,7 +76,7 @@ typedef struct {
 
 /* These do the put/get operations for each supported type */
 
-    void (*put) (ClientData clientData, Tcl_Interp* interp, int index, char *string);
+    void (*put) (ClientData clientData, Tcl_Interp* interp, int index, const char *string);
     void (*get) (ClientData clientData, Tcl_Interp* interp, int index, char *string);
 
 } tclMatrix;
@@ -326,17 +326,17 @@ int PLDLLIMPEXP Matrix_Init	(Tcl_Interp*);
 
 int
 Tcl_MatrixCmd(ClientData clientData, Tcl_Interp *interp,
-	      int argc, char **argv);
+	      int argc, const char **argv);
 
 /* Returns a pointer to the specified matrix operator's data. */
 
 tclMatrix PLDLLIMPEXP *
-Tcl_GetMatrixPtr(Tcl_Interp *interp, char *matName);
+Tcl_GetMatrixPtr(Tcl_Interp *interp, const char *matName);
 
 /* Some stuff for handling extension subcommands. */
 
 typedef int (*tclMatrixXtnsnProc) ( tclMatrix *pm, Tcl_Interp *interp,
-				    int argc, char *argv[] );
+				    int argc, const char *argv[] );
 
 typedef struct tclMatrixXtnsnDescr {
     char *cmd;
