@@ -1,4 +1,4 @@
-/* $Id: plplotter.c 6212 2005-04-27 06:44:27Z rlaboiss $
+/* $Id: plplotter.c 8196 2008-01-30 15:59:12Z andrewross $
  * Copyright (C) 2004  Joao Cardoso
  *
  * This file is part of PLplot.
@@ -267,7 +267,7 @@ static Tk_ConfigSpec configSpecs[] = {
 
 /* Externals */
 
-int   plPlotterCmd        (ClientData, Tcl_Interp *, int, char **);
+int   plPlotterCmd        (ClientData, Tcl_Interp *, int, const char **);
 void PlplotterAtEop(Tcl_Interp *interp, register PlPlotter *plPlotterPtr);
 void PlplotterAtBop(Tcl_Interp *interp, register PlPlotter *plPlotterPtr);
 
@@ -346,7 +346,7 @@ static void  UpdateHScrollbar   (register PlPlotter *);
 
 int
 plPlotterCmd(ClientData clientData, Tcl_Interp *interp,
-           int argc, char **argv)
+           int argc, const char **argv)
 {
     Tk_Window tkwin;
     register PlPlotter *plPlotterPtr;
@@ -438,7 +438,7 @@ plPlotterCmd(ClientData clientData, Tcl_Interp *interp,
         plPlotterPtr->devName[i] = NULL;
     }
     ndev = NDEV;
-    plgFileDevs(&plPlotterPtr->devDesc, &plPlotterPtr->devName, &ndev);
+    plgFileDevs((const char ***) &plPlotterPtr->devDesc, (const char ***) &plPlotterPtr->devName, &ndev);
 
 /* Start up event handlers and other good stuff */
 
@@ -1647,7 +1647,7 @@ Cmd(Tcl_Interp *interp, register PlPlotter *plPlotterPtr,
 /* no option -- return list of available PLplot commands */
 
     if (argc == 0)
-        return plTclCmd(cmdlist, interp, argc, (char **) argv);
+        return plTclCmd(cmdlist, interp, argc, argv);
 
 /* Make sure widget has been initialized before going any further */
 
@@ -1849,7 +1849,7 @@ Cmd(Tcl_Interp *interp, register PlPlotter *plPlotterPtr,
 /* unrecognized, so give it to plTclCmd to take care of */
 
     else
-        result = plTclCmd(cmdlist, interp, argc, (char **)argv);
+        result = plTclCmd(cmdlist, interp, argc, argv);
 
     plflush();
     return result;
