@@ -1,4 +1,4 @@
-/* $Id: plserver.h 4103 2002-12-03 08:39:28Z airwin $
+/* $Id: plserver.h 8186 2008-01-29 10:50:48Z andrewross $
  *
  * Maurice LeBrun
  * 6-May-93
@@ -35,10 +35,10 @@ typedef struct {
 
 int
 plFrameCmd(ClientData clientData, Tcl_Interp *interp,
-	   int argc, char **argv);
+	   int argc, const char **argv);
 int
 plPlotterCmd(ClientData clientData, Tcl_Interp *interp,
-	   int argc, char **argv);
+	   int argc, const char **argv);
 
 /* plr.c */
 /* Set default state parameters before anyone else has a chance to. */
