@@ -1,4 +1,4 @@
-/* $Id: pltk.h 4103 2002-12-03 08:39:28Z airwin $
+/* $Id: pltk.h 8198 2008-01-30 18:58:16Z andrewross $
  *
  * Maurice LeBrun
  * 28-Apr-95
@@ -29,7 +29,7 @@ Pltk_Init( Tcl_Interp *interp );
 /* Main program for wish, with PLplot extensions. */
 
 int
-pltkMain(int argc, char **argv, char *RcFileName,
+pltkMain(int argc, const char **argv, char *RcFileName,
 	 int (*AppInit)(Tcl_Interp *interp));
 
 #ifdef __cplusplus
