@@ -1,4 +1,4 @@
-/* $Id: tcpip.c,v 1.23 2005/04/27 06:43:22 rlaboiss Exp $
+/* $Id: tcpip.c 6950 2006-08-08 00:54:05Z airwin $
  *
  * Maurice LeBrun
  * 6-Jan-94
@@ -61,8 +61,9 @@
 */
 
 #include "plDevs.h"
+#include "plConfig.h"
 
-#if defined (PLD_tk)
+#if defined (PLD_tk) || defined (ENABLE_tk)
 
 /* This file is meant to be compiled with non-ANSI compilers ("cc").
  * The reason for doing it this way is to ensure that the full C
@@ -77,7 +78,6 @@
  * I forego the ANSI compiler here and go with good (bad) old "cc".
  */
 
-#include "plConfig.h"
 #ifdef _POSIX_SOURCE
 #undef _POSIX_SOURCE
 #endif
@@ -694,4 +694,4 @@ pldummy_tcpip()
     return 0;
 }
 
-#endif	/* defined(PLD_tk) */
+#endif	/* defined(PLD_tk) || defined (ENABLE_tk)*/
