@@ -95,7 +95,7 @@ typedef struct {
 #endif
 } PLCairo;
 
-char* plD_DEVICE_INFO_cairo = 
+const char* plD_DEVICE_INFO_cairo = 
 #if defined(PLD_xcairo)
   "xcairo:Cairo X Windows Driver:1:cairo:59:xcairo\n"
 #endif
@@ -279,6 +279,9 @@ void plD_tidy_cairo(PLStream *pls)
   // Free the cairo context and surface.
   cairo_destroy(aStream->cairoContext);
   cairo_surface_destroy(aStream->cairoSurface);
+
+  if (pls->OutFile)
+    fclose(pls->OutFile);
 }
 
 //---------------------------------------------------------------------
@@ -695,10 +698,11 @@ void set_current_context(PLStream *pls)
   PLCairo *aStream;
 
   aStream = (PLCairo *)pls->dev;
-  cairo_set_source_rgb(aStream->cairoContext,
-		       (double)pls->curcolor.r/255.0, 
-  		       (double)pls->curcolor.g/255.0,
-  		       (double)pls->curcolor.b/255.0);
+  cairo_set_source_rgba(aStream->cairoContext,
+			(double)pls->curcolor.r/255.0, 
+			(double)pls->curcolor.g/255.0,
+			(double)pls->curcolor.b/255.0,
+			(double)pls->curcolor.a);
   // In Cairo, zero width lines are not hairlines, they are completely invisible.
   if(pls->width < 1){
     cairo_set_line_width(aStream->cairoContext, 1.0);
@@ -1039,7 +1043,7 @@ void plD_dispatch_init_pdfcairo(PLDispatchTable *pdt)
    pdt->pl_MenuStr  = "Cairo PDF Driver";
    pdt->pl_DevName  = "pdfcairo";
 #endif
-   pdt->pl_type     = plDevType_Interactive;
+   pdt->pl_type     = plDevType_FileOriented;
    pdt->pl_seq      = 60;
    pdt->pl_init     = (plD_init_fp)     plD_init_pdfcairo;
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
@@ -1110,7 +1114,7 @@ void plD_dispatch_init_pscairo(PLDispatchTable *pdt)
    pdt->pl_MenuStr  = "Cairo PS Driver";
    pdt->pl_DevName  = "pscairo";
 #endif
-   pdt->pl_type     = plDevType_Interactive;
+   pdt->pl_type     = plDevType_FileOriented;
    pdt->pl_seq      = 61;
    pdt->pl_init     = (plD_init_fp)     plD_init_pscairo;
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
@@ -1183,7 +1187,7 @@ void plD_dispatch_init_svgcairo(PLDispatchTable *pdt)
    pdt->pl_MenuStr  = "Cairo SVG Driver";
    pdt->pl_DevName  = "svgcairo";
 #endif
-   pdt->pl_type     = plDevType_Interactive;
+   pdt->pl_type     = plDevType_FileOriented;
    pdt->pl_seq      = 62;
    pdt->pl_init     = (plD_init_fp)     plD_init_svgcairo;
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
@@ -1256,7 +1260,7 @@ void plD_dispatch_init_pngcairo(PLDispatchTable *pdt)
    pdt->pl_MenuStr  = "Cairo PNG Driver";
    pdt->pl_DevName  = "pngcairo";
 #endif
-   pdt->pl_type     = plDevType_Interactive;
+   pdt->pl_type     = plDevType_FileOriented;
    pdt->pl_seq      = 63;
    pdt->pl_init     = (plD_init_fp)     plD_init_pngcairo;
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
@@ -1386,7 +1390,7 @@ void plD_dispatch_init_memcairo(PLDispatchTable *pdt)
    pdt->pl_MenuStr  = "Cairo memory driver";
    pdt->pl_DevName  = "memcairo";
 #endif
-   pdt->pl_type     = plDevType_Interactive;
+   pdt->pl_type     = plDevType_FileOriented;
    pdt->pl_seq      = 64;
    pdt->pl_init     = (plD_init_fp)     plD_init_memcairo;
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
