@@ -1,4 +1,4 @@
-/* $Id: gnome.c 6212 2005-04-27 06:44:27Z rlaboiss $
+/* $Id: gnome.c 8033 2007-11-23 15:28:09Z andrewross $
 
         PLplot GnomeCanvas device driver.
 
@@ -39,7 +39,7 @@
 #include <unistd.h>
 
 /* Device info */
-char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome";
+const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome";
 
 /*#undef DEBUG*/
 #define DEBUG
