@@ -1,4 +1,4 @@
-/* $Id: impress.c 5181 2004-01-19 19:10:19Z airwin $
+/* $Id: impress.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot ImPress device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-char* plD_DEVICE_INFO_impress = "imp:Impress File:0:impress:37:imp";
+const char* plD_DEVICE_INFO_impress = "imp:Impress File:0:impress:37:imp";
 
 /* Function prototypes */
 
