@@ -1,4 +1,4 @@
-/* $Id: linuxvga.c 5453 2004-02-24 10:06:10Z rlaboiss $
+/* $Id: linuxvga.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	S. Fanchiotti (Using gnusvga.c by Geoffrey Furnish)
 	4 May 1993
@@ -18,7 +18,7 @@
 #include <vga.h>
 
 /* Device info */
-char* plD_DEVICE_INFO_linuxvga = "linuxvga:Linux VGA driver:0:linuxvga:8:vga";
+const char* plD_DEVICE_INFO_linuxvga = "linuxvga:Linux VGA driver:0:linuxvga:8:vga";
 
 
 /* Function prototypes */
