@@ -1,4 +1,4 @@
-/* $Id: ljii.c 5181 2004-01-19 19:10:19Z airwin $
+/* $Id: ljii.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot Laser Jet II device driver.
 
@@ -22,7 +22,7 @@
 #endif
 
 /* Device info */
-char* plD_DEVICE_INFO_ljii =
+const char* plD_DEVICE_INFO_ljii =
   "ljii:LaserJet II Bitmap File (150 dpi):0:ljii:33:ljii";
 
 /* Function prototypes */
