@@ -1,4 +1,4 @@
-/* $Id: ljiip.c 5181 2004-01-19 19:10:19Z airwin $
+/* $Id: ljiip.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot Laser Jet IIp device driver.
 	Based on old LJII driver, modifications by Wesley Ebisuzaki
@@ -27,7 +27,7 @@
 #endif
 
 /* Device info */
-char* plD_DEVICE_INFO_ljiip =
+const char* plD_DEVICE_INFO_ljiip =
   "ljiip:LaserJet IIp/deskjet compressed graphics:0:ljiip:32:ljiip";
 
 /* Function prototypes */
