@@ -1,5 +1,5 @@
 /*
-  $Id: mem.c 5684 2004-06-26 22:44:27Z airwin $
+  $Id: mem.c 8033 2007-11-23 15:28:09Z andrewross $
 
   PLplot MEM (in user-supplied memory) device driver.
   The idea here is that the user will specify the Y by X by RGB
@@ -21,7 +21,7 @@
 #include "drivers.h"
 
 /* Device info */
-char* plD_DEVICE_INFO_mem = "mem:User-supplied memory device:-1:mem:46:mem";
+const char* plD_DEVICE_INFO_mem = "mem:User-supplied memory device:-1:mem:46:mem";
 
 void plD_dispatch_init_mem	( PLDispatchTable *pdt );
 
