@@ -1,4 +1,4 @@
-/* $Id: ntk.c 6212 2005-04-27 06:44:27Z rlaboiss $
+/* $Id: ntk.c 8033 2007-11-23 15:28:09Z andrewross $
 
    Experimental tk driver using a plain "wish"
 
@@ -34,7 +34,7 @@
 #include <tk.h>
 
 /* Device info */
-char* plD_DEVICE_INFO_ntk = "ntk:New tk driver:1:ntk:43:ntk";
+const char* plD_DEVICE_INFO_ntk = "ntk:New tk driver:1:ntk:43:ntk";
 
 
 void plD_dispatch_init_ntk	( PLDispatchTable *pdt );
