@@ -1,4 +1,4 @@
-/* $Id: null.c 5181 2004-01-19 19:10:19Z airwin $
+/* $Id: null.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot Null device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-char* plD_DEVICE_INFO_null = "null:Null device:-1:null:42:null";
+const char* plD_DEVICE_INFO_null = "null:Null device:-1:null:42:null";
 
 void plD_dispatch_init_null	( PLDispatchTable *pdt );
 
