@@ -1,5 +1,5 @@
 /*
-  $Id: pbm.c 5181 2004-01-19 19:10:19Z airwin $
+  $Id: pbm.c 8033 2007-11-23 15:28:09Z andrewross $
 
   PLplot PBM (PPM) device driver.
 
@@ -14,7 +14,7 @@
 #include "drivers.h"
 
 /* Device info */
-char* plD_DEVICE_INFO_pbm = "pbm:PDB (PPM) Driver:0:pbm:38:pbm";
+const char* plD_DEVICE_INFO_pbm = "pbm:PDB (PPM) Driver:0:pbm:38:pbm";
 
 
 void plD_dispatch_init_pbm	( PLDispatchTable *pdt );
