@@ -1,4 +1,4 @@
-/* $Id: plmeta.c 6047 2005-02-28 11:35:19Z mlebrun $
+/* $Id: plmeta.c 8033 2007-11-23 15:28:09Z andrewross $
 
     Copyright 1991, 1992, 1993, 1994, 1995
     Geoffrey Furnish			furnish@dino.ph.utexas.edu
@@ -37,7 +37,7 @@
 #include <string.h>
 
 /* Device info */
-char* plD_DEVICE_INFO_plmeta = "plmeta:PLplot Native Meta-File:0:plmeta:26:plm";
+const char* plD_DEVICE_INFO_plmeta = "plmeta:PLplot Native Meta-File:0:plmeta:26:plm";
 
 
 void plD_dispatch_init_plm	( PLDispatchTable *pdt );
