@@ -1,4 +1,4 @@
-/* $Id: ps.c 7796 2007-08-14 17:20:30Z andrewross $
+/* $Id: ps.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot PostScript device driver.
 
@@ -49,7 +49,7 @@
 
 /* Device info */
 
-char* plD_DEVICE_INFO_ps = 
+const char* plD_DEVICE_INFO_ps = 
   "ps:PostScript File (monochrome):0:ps:29:psm\n"
   "psc:PostScript File (color):0:ps:30:psc";
 
