@@ -1,4 +1,4 @@
-/* $Id: tek.c 6627 2006-05-24 00:58:19Z airwin $
+/* $Id: tek.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot tektronix device & emulators driver.
 */
@@ -23,7 +23,7 @@
 
 /* Device info */
 
-char* plD_DEVICE_INFO_tek = 
+const char* plD_DEVICE_INFO_tek = 
 #if defined(PLD_conex)
   "conex:Conex vt320/tek emulator:1:tek:24:conex\n"
 #endif
