@@ -1,4 +1,4 @@
-/* $Id: tkwin.c 6212 2005-04-27 06:44:27Z rlaboiss $
+/* $Id: tkwin.c 8033 2007-11-23 15:28:09Z andrewross $
  *
  * PLplot Tk device driver.
  *
@@ -80,7 +80,7 @@
 #endif
 
 /* Device info */
-char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin";
+const char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin";
 
 
 void *	ckcalloc(size_t nmemb, size_t size);
