@@ -1,4 +1,4 @@
-/* $Id: wingcc.c 7335 2007-01-25 09:52:12Z smekal $
+/* $Id: wingcc.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot WIN32 under GCC device driver.
 
@@ -62,7 +62,7 @@
 
 /* Device info */
 
-char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:9:wingcc";
+const char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wingcc:9:wingcc";
 
 /* Struct to hold device-specific info. */
 
