@@ -1,4 +1,4 @@
-/* $Id: wxwidgets.cpp 7377 2007-02-14 08:05:27Z smekal $
+/* $Id: wxwidgets.cpp 8222 2008-02-07 13:55:45Z smekal $
 
    Copyright (C) 2005  Werner Smekal, Sjaak Verdoold
    Copyright (C) 2005  Germain Carrera Corraleche
@@ -23,8 +23,7 @@
 
 
 /* TODO: - implement the GraphicsIn stuff
- *       - provide helper functions for bindings (freetype support, etc.)
- *         we need a header file for this
+ *       - clear screen should only clear current plot (e.g in a 2x2 plot) not the whole window
  */
 
 #include "plDevs.h"
@@ -133,7 +132,7 @@ extern "C"
 
 /* Application icon as XPM */
 /* This free icon was taken from http://2pt3.com/news/twotone-icons-for-free/ */
-static char *graph[] = {
+static const char *graph[] = {
 /* columns rows colors chars-per-pixel */
 "16 16 4 2",
 "   c black",
@@ -226,11 +225,32 @@ public: /* variables */
   unsigned char m_colbluefill;
 #endif
 
-  char** devDesc;		/* Descriptive names for file-oriented devices.  Malloc'ed. */
-  char** devName;		/* Keyword names of file-oriented devices. Malloc'ed. */
+  const char** devDesc;		/* Descriptive names for file-oriented devices.  Malloc'ed. */
+  const char** devName;		/* Keyword names of file-oriented devices. Malloc'ed. */
 	int ndev;
 };
 
+struct dev_entry {    
+  wxString dev_name;
+  wxString dev_menu_short;
+  wxString dev_menu_long;
+  wxString dev_file_app;
+};
+
+struct dev_entry dev_entries[] = {
+  { wxT("gif"), wxT("gif..."), wxT("Save this plot as gif!"), wxT("gif files (*.gif)|*.gif") },
+  { wxT("jpeg"), wxT("jpeg..."), wxT("Save this plot as jpeg!"), wxT("jpg files (*.jpg;*.jpeg)|*.jpg;*.jpeg") },
+  { wxT("png"), wxT("png..."), wxT("Save this plot as png"), wxT("png files (*.png)|*.png") },
+  { wxT("pngcairo"), wxT("png (cairo)..."), wxT("Save this plot as png using cairo!"), wxT("png files (*.png)|*.png") },
+  { wxT("pdfcairo"), wxT("pdf..."), wxT("Save this plot as pdf using cairo!"), wxT("pdf files (*.pdf)|*.pdf") },
+  { wxT("ps"), wxT("postscript..."), wxT("Save this plot as postscript!"), wxT("ps files (*.ps)|*.ps") },
+  { wxT("psc"), wxT("color postscript..."), wxT("Save this plot as color postscript!"), wxT("ps files (*.ps;*.psc)|*.ps;*.psc") },
+  { wxT("pscairo"), wxT("color postscript (cairo)..."), wxT("Save this plot as color postscript using cairo!"), wxT("ps files (*.ps;*.psc)|*.ps;*.psc") },
+  { wxT("svg"), wxT("svg..."), wxT("Save this plot as svg!"), wxT("svg files (*.svg)|*.svg") },
+  { wxT("svgcairo"), wxT("svg (cairo)..."), wxT("Save this plot as svg using cairo!"), wxT("svg files (*.svg)|*.svg") },
+  { wxT("xfig"), wxT("xfig..."), wxT("Save this plot as xfig!"), wxT("fig files (*.fig)|*.fig") }
+};
+
 inline void AddtoClipRegion( wxPLdev* dev, int x1, int y1, int x2, int y2 )
 {
 	dev->newclipregion=false;
@@ -330,7 +350,7 @@ public:
   wxPLplotFrame( const wxString& title, PLStream* pls );
   void OnMenu( wxCommandEvent& event );
   void OnClose( wxCloseEvent& event );
-	bool SavePlot( char* filename, char* devname, int width,  int height );
+  bool SavePlot( const char* filename, const char* devname, int width,  int height );
   void SetRefreshFlag( bool flag=true ) { m_window->SetRefreshFlag( flag ); };
   bool GetRefreshFlag( void ) { return m_window->GetRefreshFlag(); };
 
@@ -342,25 +362,25 @@ private:
   DECLARE_EVENT_TABLE()
 };
 
-enum { wxPL_Quit = 10000, wxPL_Save };
+enum { wxPL_Save=10000, wxPL_Next=10100 };
 
 /* event table */
 BEGIN_EVENT_TABLE( wxPLplotFrame, wxFrame )
-  EVT_MENU( -1, wxPLplotFrame::OnMenu )      /* handle menu events */
+  EVT_MENU( -1, wxPLplotFrame::OnMenu )      /* handle all menu events */
   EVT_CLOSE( wxPLplotFrame::OnClose )
 END_EVENT_TABLE()
 
 /* Use this macro if you want to define your own main() or WinMain() function
    and call wxEntry() from there. */
 #define IMPLEMENT_PLAPP_NO_MAIN(appname)                                      \
-    wxAppConsole *wxCreateApp()                                             \
+    wxAppConsole *wxPLCreateApp()                                             \
     {                                                                       \
         wxAppConsole::CheckBuildOptions( WX_BUILD_OPTIONS_SIGNATURE,         \
                                          "your program" );                    \
         return new appname;                                                 \
     }                                                                       \
     wxAppInitializer                                                        \
-        wxAppInitializer((wxAppInitializerFunction) wxCreateApp);        \
+        wxAppInitializer((wxAppInitializerFunction) wxPLCreateApp);        \
     static appname& wxGetApp() { return *(appname *)wxTheApp; } 
 
 IMPLEMENT_PLAPP_NO_MAIN( wxPLplotApp )
@@ -379,7 +399,7 @@ static void GetCursorCmd( PLStream *pls, PLGraphicsIn *ptr );
 \*----------------------------------------------------------------------*/
 
 /* Device info */
-char* plD_DEVICE_INFO_wxwidgets = "wxwidgets:wxWidgets DC:1:wxwidgets:51:wxwidgets";
+const char* plD_DEVICE_INFO_wxwidgets = "wxwidgets:wxWidgets DC:1:wxwidgets:51:wxwidgets";
 
 void plD_init_wxwidgets		(PLStream *);
 void plD_line_wxwidgets		(PLStream *, short, short, short, short);
@@ -407,11 +427,11 @@ void plD_erroraborthandler_wxwidgets( char *errormessage );
 /* #define _DEBUG_VERBOSE //*/
 
 /*--------------------------------------------------------------------------*\
- *  void Log_Verbose( char *fmt, ... )
+ *  void Log_Verbose( const char *fmt, ... )
  *
  *  Print verbose debug message to stderr (printf style).
 \*--------------------------------------------------------------------------*/
-void Log_Verbose( char *fmt, ... )
+void Log_Verbose( const char *fmt, ... )
 {
 #ifdef _DEBUG_VERBOSE
   va_list args;
@@ -426,11 +446,11 @@ void Log_Verbose( char *fmt, ... )
 
 
 /*--------------------------------------------------------------------------*\
- *  void Log_Debug( char *fmt, ... )
+ *  void Log_Debug( const char *fmt, ... )
  *
  *  Print debug message to stderr (printf style).
 \*--------------------------------------------------------------------------*/
-void Log_Debug( char *fmt, ... )
+void Log_Debug( const char *fmt, ... )
 {
 #ifdef _DEBUG
   va_list args;
@@ -479,7 +499,7 @@ void plD_dispatch_init_wxwidgets( PLDispatchTable *pdt )
 
 wxPLdev::wxPLdev( void )
 {
-  // Log_Verbose( "wxPLdev::wxPLdev()" );
+  Log_Verbose( "wxPLdev::wxPLdev()" );
 
   ready = false;
   ownGUI = false;
@@ -488,20 +508,33 @@ wxPLdev::wxPLdev( void )
   exit=false;
 
   comcount = 0;
+
+	dc=NULL;
+  m_bitmap=NULL;
+  m_buffer=NULL;
+  m_frame=NULL;
+  // width, height are set in plD_init_wxwidgets
+  // bm_width, bm_height are set in install_buffer
+  
+  // xmin, xmax, ymin, ymax are set in plD_init_wxwidgets
+  // scalex, scaley are set in plD_init_wxwidgets
+
+  plstate_width = false;
+  plstate_color0 = false;
+  plstate_color1 = false;
+
+  locate_mode=0;
+  draw_xhair=false;
+  
 	newclipregion=true;
 	clipminx=1024;
 	clipmaxx=0;
 	clipminy=800;
 	clipmaxy=0;
 
-	dc=NULL;
-  m_buffer=NULL;
-  m_bitmap=NULL;
-
-  plstate_width = false;
-  plstate_color0 = false;
-  plstate_color1 = false;
-
+	antialized=0;
+	freetype=0;
+	smooth_text=0;
 #ifdef HAVE_AGG
   m_rendering_buffer=NULL;
   m_strokewidth=1.0;
@@ -514,9 +547,9 @@ wxPLdev::wxPLdev( void )
   m_colbluefill=0;
 #endif
 
-  devName = (char **)malloc( NDEV * sizeof(char**) );
+  devName = (const char **)malloc( NDEV * sizeof(char**) );
   memset( devName, '\0', NDEV * sizeof(char**) );
-  devDesc = (char **)malloc( NDEV * sizeof(char**) );
+  devDesc = (const char **)malloc( NDEV * sizeof(char**) );
   memset( devDesc, '\0', NDEV * sizeof(char**) );
 	ndev=NDEV;
 }
@@ -539,7 +572,7 @@ wxPLdev::~wxPLdev( void )
 void
 plD_init_wxwidgets( PLStream *pls )
 {
-  // Log_Verbose( "plD_init_wxwidgets()" );
+  Log_Verbose( "plD_init_wxwidgets()" );
 
   wxPLdev* dev;
 
@@ -624,7 +657,7 @@ DrvOpt wx_options[] = {
     pls->freeaspect = 1;
   }
 
-  // Log_Verbose( "settings" );
+  Log_Verbose( "settings" );
 
   /* Set the number of pixels per mm */
   plP_setpxl( (PLFLT)VIRTUAL_PIXELS_PER_MM, (PLFLT)VIRTUAL_PIXELS_PER_MM );
@@ -665,7 +698,7 @@ DrvOpt wx_options[] = {
 \*--------------------------------------------------------------------------*/
 void plD_line_wxwidgets( PLStream *pls, short x1a, short y1a, short x2a, short y2a )
 {
-  // Log_Verbose( "plD_line_wxwidgets(x1a=%d, y1a=%d, x2a=%d, y2a=%d)", x1a, y1a, x2a, y2a );
+  Log_Verbose( "plD_line_wxwidgets(x1a=%d, y1a=%d, x2a=%d, y2a=%d)", x1a, y1a, x2a, y2a );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -675,8 +708,8 @@ void plD_line_wxwidgets( PLStream *pls, short x1a, short y1a, short x2a, short y
   if( !(dev->ready) )
     install_buffer( pls );
   
-  // Log_Verbose( "plD_line_wxwidgets(x1a=%d, y1a=%d, x2a=%d, y2a=%d)", (wxCoord)(x1a/dev->scalex),
-	//						 (wxCoord)(dev->height-y1a/dev->scaley), (wxCoord)(x2a/dev->scalex), (wxCoord)(dev->height-y2a/dev->scaley) );
+  Log_Verbose( "plD_line_wxwidgets(x1a=%d, y1a=%d, x2a=%d, y2a=%d)", (wxCoord)(x1a/dev->scalex),
+							 (wxCoord)(dev->height-y1a/dev->scaley), (wxCoord)(x2a/dev->scalex), (wxCoord)(dev->height-y2a/dev->scaley) );
 
   if(dev->antialized) {
 #ifdef HAVE_AGG
@@ -723,7 +756,7 @@ void plD_line_wxwidgets( PLStream *pls, short x1a, short y1a, short x2a, short y
 void plD_polyline_wxwidgets( PLStream *pls, short *xa, short *ya, PLINT npts )
 {
 	short x1a, y1a, x2a, y2a;
-  // Log_Verbose( "plD_polyline_wxwidgets()" );
+  Log_Verbose( "plD_polyline_wxwidgets()" );
 
   /* should be changed to use the wxDC::DrawLines function? */
   wxPLdev* dev = (wxPLdev*)pls->dev;
@@ -792,7 +825,7 @@ void plD_polyline_wxwidgets( PLStream *pls, short *xa, short *ya, PLINT npts )
 \*--------------------------------------------------------------------------*/
 void plD_eop_wxwidgets( PLStream *pls )
 {
-  // Log_Verbose( "plD_eop_wxwidgets()" );
+  Log_Verbose( "plD_eop_wxwidgets()" );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -815,7 +848,7 @@ void plD_eop_wxwidgets( PLStream *pls )
 \*--------------------------------------------------------------------------*/
 void plD_bop_wxwidgets( PLStream *pls )
 {
-  // Log_Verbose( "plD_bop_wxwidgets()" );
+  Log_Verbose( "plD_bop_wxwidgets()" );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -864,7 +897,7 @@ void plD_bop_wxwidgets( PLStream *pls )
 \*--------------------------------------------------------------------------*/
 void plD_tidy_wxwidgets( PLStream *pls )
 {
-  // Log_Verbose( "plD_tidy_wxwidgets()" );
+  Log_Verbose( "plD_tidy_wxwidgets()" );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -906,7 +939,7 @@ void plD_tidy_wxwidgets( PLStream *pls )
 \*--------------------------------------------------------------------------*/
 void plD_state_wxwidgets( PLStream *pls, PLINT op )
 {
-  // Log_Verbose( "plD_state_wxwidgets(op=%d)", op );
+  Log_Verbose( "plD_state_wxwidgets(op=%d)", op );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -919,9 +952,9 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
         dev->m_strokewidth = pls->width>0 ? pls->width : 1;  // TODO: why and when ist width 0???
 #endif
       } else {
-        dev->dc->SetPen( wxPen(wxColour(pls->curcolor.r, pls->curcolor.g,
-                                        pls->curcolor.b),
-                               pls->width>0 ? pls->width : 1) );
+        dev->dc->SetPen( *(wxThePenList->FindOrCreatePen(wxColour(pls->curcolor.r, pls->curcolor.g,
+                                                                   pls->curcolor.b),
+                                                          pls->width>0 ? pls->width : 1, wxSOLID)) );
       }
     } else
       dev->plstate_width = true;
@@ -933,12 +966,13 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
 #ifdef HAVE_AGG
         dev->m_colredstroke = pls->cmap0[pls->icol0].r;
         dev->m_colgreenstroke = pls->cmap0[pls->icol0].g;
-        dev->m_colbluestroke = pls->cmap0[pls->icol0].b;      
+        dev->m_colbluestroke = pls->cmap0[pls->icol0].b;
+        dev->m_StrokeOpacity = (wxUint8)(pls->cmap0[pls->icol0].a*255);
 #endif
       } else {
-        dev->dc->SetPen( wxPen(wxColour(pls->cmap0[pls->icol0].r, pls->cmap0[pls->icol0].g,
-                                        pls->cmap0[pls->icol0].b),
-                               pls->width>0 ? pls->width : 1) );
+        dev->dc->SetPen( *(wxThePenList->FindOrCreatePen(wxColour(pls->cmap0[pls->icol0].r, pls->cmap0[pls->icol0].g,
+                                                                    pls->cmap0[pls->icol0].b),
+                                                          pls->width>0 ? pls->width : 1, wxSOLID)) );
         dev->dc->SetBrush( wxBrush(wxColour(pls->cmap0[pls->icol0].r, pls->cmap0[pls->icol0].g,
                                             pls->cmap0[pls->icol0].b)) );
       }
@@ -953,13 +987,13 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
         dev->m_colredstroke = pls->curcolor.r;
         dev->m_colgreenstroke = pls->curcolor.g;
         dev->m_colbluestroke = pls->curcolor.b;      
+        dev->m_StrokeOpacity = (wxUint8)(pls->curcolor.a*255);
 #endif
       } else {
-        dev->dc->SetPen( wxPen(wxColour(pls->curcolor.r, pls->curcolor.g,
-                                        pls->curcolor.b),
-                               pls->width>0 ? pls->width : 1) );
-        dev->dc->SetBrush( wxBrush(wxColour(pls->curcolor.r, pls->curcolor.g,
-                                            pls->curcolor.b)) );
+        dev->dc->SetPen( *(wxThePenList->FindOrCreatePen(wxColour(pls->curcolor.r, pls->curcolor.g,
+                                                                    pls->curcolor.b),
+                                                          pls->width>0 ? pls->width : 1, wxSOLID)) );
+        dev->dc->SetBrush( wxBrush(wxColour(pls->curcolor.r, pls->curcolor.g, pls->curcolor.b)) );
       }
     } else 
       dev->plstate_color1 = true;
@@ -981,7 +1015,7 @@ void plD_state_wxwidgets( PLStream *pls, PLINT op )
 \*--------------------------------------------------------------------------*/
 void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 {
-  // Log_Verbose( "plD_esc_wxwidgets(op=%d, ptr=%x)", op, ptr );
+  Log_Verbose( "plD_esc_wxwidgets(op=%d, ptr=%x)", op, ptr );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -1021,6 +1055,17 @@ void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
     break;
 
 	case PLESC_CLEAR: {
+    /* Since the plot is updated only every MAC_COMCOUNT commands (usually 5000)
+       before we clear the screen we need to show the plot at least once :) */
+    if( dev->ownGUI ) {
+        wxRunApp( pls, true );
+  			dev->comcount=0;
+    }
+/*				"x1", (double) (pls->sppxmi) * PIXELS_PER_DU,
+				"y1", (double) -(pls->sppyma) * PIXELS_PER_DU,
+				"x2", (double) (pls->sppxma) * PIXELS_PER_DU,
+				"y2", (double) -(pls->sppymi) * PIXELS_PER_DU,
+				"fill_color", (pls->cmap0[0]).name,*/
 			PLINT bgr, bgg, bgb;  /* red, green, blue */
 			plgcolbg( &bgr, &bgg, &bgb );  /* get background color information */
 
@@ -1056,7 +1101,7 @@ void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 static void fill_polygon( PLStream *pls )
 {
 	short x1a, y1a, x2a, y2a;
-  // Log_Verbose( "fill_polygon(), npts=%d, x[0]=%d, y[0]=%d", pls->dev_npts, pls->dev_y[0], pls->dev_y[0] );
+  Log_Verbose( "fill_polygon(), npts=%d, x[0]=%d, y[0]=%d", pls->dev_npts, pls->dev_y[0], pls->dev_y[0] );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -1127,7 +1172,7 @@ static void fill_polygon( PLStream *pls )
 void wx_set_size( PLStream* pls, int width, int height )
 {
   /* TODO: buffer must be resized here or in wxplotstream */
-  // Log_Verbose( "wx_set_size()" );
+  Log_Verbose( "wx_set_size()" );
   
   wxPLdev* dev = (wxPLdev*)pls->dev;
 
@@ -1188,7 +1233,7 @@ void wx_set_size( PLStream* pls, int width, int height )
 \*--------------------------------------------------------------------------*/
 void wx_set_dc( PLStream* pls, wxDC* dc )
 {
-  // Log_Verbose( "wx_set_dc()" );
+  Log_Verbose( "wx_set_dc()" );
   
   wxPLdev* dev = (wxPLdev*)pls->dev;
   dev->dc=dc;  /* Add the dc to the device */
@@ -1208,7 +1253,7 @@ void wx_set_dc( PLStream* pls, wxDC* dc )
 \*--------------------------------------------------------------------------*/
 void wx_set_buffer( PLStream* pls, wxImage* buffer )
 {
-  // Log_Verbose( "wx_set_buffer()" );
+  Log_Verbose( "wx_set_buffer()" );
   
   wxPLdev* dev = (wxPLdev*)pls->dev;
   dev->m_buffer = buffer;
@@ -1273,19 +1318,18 @@ void plD_erroraborthandler_wxwidgets( char *errormessage )
 \*----------------------------------------------------------------------*/
 static void plD_pixel_wxwidgets( PLStream *pls, short x, short y )
 {
-  // Log_Verbose( "plD_pixel_wxwidgets" );
+  Log_Verbose( "plD_pixel_wxwidgets" );
 
   wxPLdev *dev=(wxPLdev*)pls->dev;
 
   if( !(dev->ready) )
     install_buffer( pls );
 
-  // Log_Verbose( "Draw Pixel @ %d, %d\n", x, y );	
   if( dev->antialized ) {
 #ifdef HAVE_AGG
-    dev->m_buffer->SetRGB( x, y, dev->m_colredstroke, dev->m_colgreenstroke, dev->m_colbluestroke );    
+    dev->m_buffer->SetRGB( x, y, dev->m_colredstroke, dev->m_colgreenstroke, dev->m_colbluestroke );
 #endif
-  } else  
+  } else
     dev->dc->DrawPoint( x, y );
 
   if( !(dev->resizing) && dev->ownGUI ) {
@@ -1307,21 +1351,23 @@ static void plD_pixel_wxwidgets( PLStream *pls, short x, short y )
 \*----------------------------------------------------------------------*/
 static void plD_set_pixel_wxwidgets( PLStream *pls, short x, short y, PLINT colour)
 {
-  // Log_Verbose( "plD_set_pixel_wxwidgets" );
+  Log_Verbose( "plD_set_pixel_wxwidgets" );
 
   wxPLdev *dev=(wxPLdev*)pls->dev;
 
   if( !(dev->ready) )
     install_buffer( pls );
 
-  // Log_Verbose( "Draw Pixel @ %d, %d\n", x, y );	
   if( dev->antialized ) {
 #ifdef HAVE_AGG
     dev->m_buffer->SetRGB( x, y, GetRValue(colour), GetGValue(colour), GetBValue(colour) );    
 #endif
   } else  {
-    dev->dc->SetPen( wxPen(wxColour(GetRValue(colour), GetGValue(colour), GetBValue(colour)), 1) );
+    const wxPen oldpen=dev->dc->GetPen();
+    dev->dc->SetPen( *(wxThePenList->FindOrCreatePen(wxColour(GetRValue(colour), GetGValue(colour), GetBValue(colour)),
+                                                   1, wxSOLID)) );
     dev->dc->DrawPoint( x, y );
+    dev->dc->SetPen( oldpen );
   }
 
   if( !(dev->resizing) && dev->ownGUI ) {
@@ -1336,14 +1382,14 @@ static void plD_set_pixel_wxwidgets( PLStream *pls, short x, short y, PLINT colo
 
 
 /*--------------------------------------------------------------------------*\
- *  void plD_read_pixel_wingcc (PLStream *pls, short x, short y)
+ *  void plD_read_pixel_wxwidgets (PLStream *pls, short x, short y)
  *
  *  callback function, of type "plD_pixel_fp", which specifies how a single
  *  pixel is read.
 \*--------------------------------------------------------------------------*/
 static PLINT plD_read_pixel_wxwidgets ( PLStream *pls, short x, short y )
 {
-  // Log_Verbose( "plD_read_pixel_wxwidgets" );
+  Log_Verbose( "plD_read_pixel_wxwidgets" );
 
   wxPLdev *dev=(wxPLdev*)pls->dev;
   PLINT colour;
@@ -1357,10 +1403,17 @@ static PLINT plD_read_pixel_wxwidgets ( PLStream *pls, short x, short y )
                   dev->m_buffer->GetBlue( x, y ) );    
 #endif
   } else {  
+#ifdef __WXGTK__
+    // The GetPixel method is incredible slow for wxGTK. Therefore we set the colour
+    // always to the background color, since this is the case anyway 99% of the time.
+    PLINT bgr, bgg, bgb;  /* red, green, blue */
+    plgcolbg( &bgr, &bgg, &bgb );  /* get background color information */
+    colour=RGB( bgr, bgg, bgb );
+#else
     wxColour col;
     dev->dc->GetPixel( x, y, &col );
-  
-    colour = RGB( col.Red(), col.Green(), col.Blue() );    
+    colour = RGB( col.Red(), col.Green(), col.Blue());
+#endif
 	}
 
   return colour;
@@ -1377,7 +1430,7 @@ static PLINT plD_read_pixel_wxwidgets ( PLStream *pls, short x, short y )
 \*----------------------------------------------------------------------*/
 static void init_freetype_lv1( PLStream *pls )
 {
-  // Log_Verbose( "init_freetype_lv1" );
+  Log_Verbose( "init_freetype_lv1" );
 
   wxPLdev *dev=(wxPLdev*)pls->dev;
 
@@ -1388,20 +1441,18 @@ static void init_freetype_lv1( PLStream *pls )
 
   /*
    *  See if we have a 24 bit device (or better), in which case
-   *  we can use the better antialaaising.
+   *  we can use the better antialising.
    */
   if( dev->antialized ) {
     FT->BLENDED_ANTIALIASING=1;
     FT->read_pixel= (plD_read_pixel_fp)plD_read_pixel_wxwidgets;
     FT->set_pixel= (plD_set_pixel_fp)plD_set_pixel_wxwidgets;
   } else {
-    //wxDisplay display(0);
-    //printf("bitmap depth=%d\n", display->GetDepth() );
-    //if( display->GetDepth()>=24) {
-      FT->BLENDED_ANTIALIASING=1;
-      FT->read_pixel= (plD_read_pixel_fp)plD_read_pixel_wxwidgets;
-      FT->set_pixel= (plD_set_pixel_fp)plD_set_pixel_wxwidgets;
-    //}
+    // the bitmap we are using in the antialized case has always
+    // 32 bit depth
+    FT->BLENDED_ANTIALIASING=1;
+    FT->read_pixel= (plD_read_pixel_fp)plD_read_pixel_wxwidgets;
+    FT->set_pixel= (plD_set_pixel_fp)plD_set_pixel_wxwidgets;
   }
 }
 
@@ -1433,7 +1484,7 @@ static void init_freetype_lv1( PLStream *pls )
 
 static void init_freetype_lv2( PLStream *pls )
 {
-  // Log_Verbose( "init_freetype_lv2" );
+  Log_Verbose( "init_freetype_lv2" );
 
   wxPLdev *dev=(wxPLdev *)pls->dev;
   FT_Data *FT=(FT_Data *)pls->FT;
@@ -1485,6 +1536,8 @@ static void init_freetype_lv2( PLStream *pls )
 \*--------------------------------------------------------------------------*/
 static void GetCursorCmd( PLStream* pls, PLGraphicsIn* ptr)
 {
+  Log_Verbose( "GetCursorCmd" );
+
   wxPLdev *dev=(wxPLdev *)pls->dev;
   PLGraphicsIn *gin = &(dev->gin);
 
@@ -1497,7 +1550,7 @@ static void GetCursorCmd( PLStream* pls, PLGraphicsIn* ptr)
   wxRunApp( pls, false );
   
   *ptr = *gin;
-  if (dev->locate_mode) {
+  if( dev->locate_mode ) {
     dev->locate_mode = 0;
     dev->draw_xhair=false;
   }
@@ -1521,7 +1574,7 @@ static void GetCursorCmd( PLStream* pls, PLGraphicsIn* ptr)
 \*----------------------------------------------------------------------*/
 static void install_buffer( PLStream *pls )
 {
-  // Log_Verbose( "install_buffer" );
+  Log_Verbose( "install_buffer" );
 
   wxPLdev* dev = (wxPLdev*)pls->dev;
   static bool initApp=false;
@@ -1547,7 +1600,7 @@ static void install_buffer( PLStream *pls )
     initApp=true;
   }
   
-  dev->m_frame = new wxPLplotFrame( _T("wxWidgets PLplot App"), pls );
+  dev->m_frame = new wxPLplotFrame( wxT("wxWidgets PLplot App"), pls );
   wxGetApp().AddFrame( dev->m_frame );
   dev->m_frame->SetClientSize( dev->width, dev->height );
   dev->m_frame->Show( true );
@@ -1568,7 +1621,7 @@ static void install_buffer( PLStream *pls )
       dev->dc = new wxMemoryDC();
     
     /* get a new bitmap */
-    dev->m_bitmap = new wxBitmap( dev->bm_width, dev->bm_height, -1 );
+    dev->m_bitmap = new wxBitmap( dev->bm_width, dev->bm_height, 32 );
     ((wxMemoryDC*)dev->dc)->SelectObject( wxNullBitmap );   /* deselect bitmap */
     ((wxMemoryDC*)dev->dc)->SelectObject( *(dev->m_bitmap) );   /* select new bitmap */
   }
@@ -1589,6 +1642,8 @@ static void install_buffer( PLStream *pls )
 \*----------------------------------------------------------------------*/
 static void wxRunApp( PLStream *pls, bool runonce )
 {
+  Log_Verbose( "wxRunApp" );  
+  
   wxPLdev* dev = (wxPLdev*)pls->dev;
   
   dev->waiting=true;
@@ -1606,8 +1661,8 @@ static void wxRunApp( PLStream *pls, bool runonce )
     wxGetApp().SetAdvanceFlag( runonce );
     wxGetApp().SetRefreshFlag();
 
-		/* to add an idle event is necessary for Linux (wxGTK2)
-		   and not for Windows, but it doesn't harm */
+		/* add an idle event is necessary for Linux (wxGTK2)
+		   but not for Windows, but it doesn't harm */
 	  wxIdleEvent event;
     wxGetApp().AddPendingEvent( event );
 		wxGetApp().OnRun();   /* start wxWidgets application     */
@@ -1632,7 +1687,7 @@ static void wxRunApp( PLStream *pls, bool runonce )
 \*----------------------------------------------------------------------*/
 bool wxPLplotApp::OnInit()
 {
-  // Log_Verbose( "wxPLplotApp::OnInit" );
+  Log_Verbose( "wxPLplotApp::OnInit" );
   
   exit=false;
   advance=false;
@@ -1648,7 +1703,7 @@ bool wxPLplotApp::OnInit()
 \*----------------------------------------------------------------------*/
 void wxPLplotApp::SetRefreshFlag( bool flag )
 {
-  // Log_Verbose( "wxPLplotApp::RefreshFrames" );
+  Log_Verbose( "wxPLplotApp::SetRefreshFlag" );
 
 	for( size_t i=0; i<FrameArray.GetCount(); i++)
 		FrameArray[i]->SetRefreshFlag( flag );
@@ -1662,7 +1717,7 @@ void wxPLplotApp::SetRefreshFlag( bool flag )
 \*----------------------------------------------------------------------*/
 void wxPLplotApp::OnIdle( wxIdleEvent& WXUNUSED(event) )
 {
-  // Log_Verbose( "wxPLplotApp::OnIdle" );
+  Log_Verbose( "wxPLplotApp::OnIdle" );
 
 	bool refresh=false;
 
@@ -1688,7 +1743,7 @@ wxPLplotFrame::wxPLplotFrame( const wxString& title, PLStream *pls )
                         wxMINIMIZE_BOX | wxMAXIMIZE_BOX | wxSYSTEM_MENU | wxCAPTION |
                         wxCLOSE_BOX | wxRESIZE_BORDER | wxCLIP_CHILDREN ) 
 {
-  // Log_Verbose( "wxPLplotFrame::wxPLplotFrame" );
+  Log_Verbose( "wxPLplotFrame::wxPLplotFrame" );
   m_dev=(wxPLdev*)pls->dev;
 
   m_panel = new wxPanel( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN );
@@ -1698,17 +1753,26 @@ wxPLplotFrame::wxPLplotFrame( const wxString& title, PLStream *pls )
   m_panel->SetSizer( box );
 	m_window->SetFocus();
 	  
+  wxMenu* saveMenu = new wxMenu;
+  for( size_t j=0; j<sizeof(dev_entries)/sizeof(dev_entry); j++ )
+    for( size_t i=0; i<m_dev->ndev; i++ ) {
+      if( !strcmp(m_dev->devName[i], dev_entries[j].dev_name.mb_str()) )
+        saveMenu->Append( wxPL_Save+j, dev_entries[j].dev_menu_short, dev_entries[j].dev_menu_long );
+    }
+
   wxMenu* fileMenu = new wxMenu;
-	for( size_t i=0; i<m_dev->ndev; i++ ) 
-		if( !strcmp(m_dev->devName[i], "png") )
-		  fileMenu->Append( wxPL_Save, _T("Save as png"), _T("Save this plot as png!") );
-  fileMenu->Append( wxPL_Quit, _T("E&xit\tAlt-X"), _T("Quit this program") );
+#if (wxMAJOR_VERSION<=2) & (wxMINOR_VERSION<=6)
+  fileMenu->Append( -1, wxT("Save plot as..."), saveMenu, wxT("Save this plot as ...!") );
+#else
+  fileMenu->AppendSubMenu( saveMenu, wxT("Save plot as..."), wxT("Save this plot as ...!") );
+#endif
+  fileMenu->Append( wxID_EXIT, wxT("E&xit\tAlt-X"), wxT("Exit wxWidgets PLplot App") );
 
   wxMenuBar* menuBar = new wxMenuBar();
-  menuBar->Append( fileMenu, _T("&File") );
+  menuBar->Append( fileMenu, wxT("&File") );
   SetMenuBar( menuBar );
 
-  SetTitle( _T("wxWidgets PLplot App") );
+  SetTitle( wxT("wxWidgets PLplot App") );
   SetIcon( wxIcon(graph) );
 }
 
@@ -1720,11 +1784,11 @@ wxPLplotFrame::wxPLplotFrame( const wxString& title, PLStream *pls )
 \*----------------------------------------------------------------------*/
 void wxPLplotFrame::OnMenu( wxCommandEvent& event )
 {
-  // Log_Verbose( "wxPLplotFrame::OnMenu" );
+  Log_Verbose( "wxPLplotFrame::OnMenu" );
 
-  switch( event.GetId( ) )
+  switch( event.GetId() )
   {
-  case wxPL_Quit:
+  case wxID_EXIT:
 		{
 			wxMessageDialog dialog( this, wxT("Do you really want to quit?"), wxT("Close wxWidgets PLplot App?"), wxYES_NO |wxNO_DEFAULT| wxICON_EXCLAMATION );
 			if( dialog.ShowModal() == wxID_YES ) {
@@ -1733,24 +1797,25 @@ void wxPLplotFrame::OnMenu( wxCommandEvent& event )
 			}
 		}
 		break;
-	case wxPL_Save:
-		{
-			wxFileDialog dialog( this, wxT("Save plot as png"), wxT(""), wxT(""),
-													 wxT("png files (*.png)|*.png|All Files (*.*)|*.*") ,
+  }
+    
+  size_t index=event.GetId()-wxPL_Save;
+  if( (index>=0) && (index<sizeof(dev_entries)/sizeof(dev_entry)) ) {
+    wxFileDialog dialog( this, wxT("Save plot as ")+dev_entries[index].dev_name, wxT(""), wxT(""),
+                         dev_entries[index].dev_file_app+wxT("|All Files (*.*)|*.*"),
 #if (wxMAJOR_VERSION<=2) & (wxMINOR_VERSION<=6)
-													 wxSAVE | wxOVERWRITE_PROMPT );
+                         wxSAVE | wxOVERWRITE_PROMPT );
 #else
-													 wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
+                         wxFD_SAVE | wxFD_OVERWRITE_PROMPT );
 #endif	
-			if (dialog.ShowModal() == wxID_OK)
-				SavePlot( "test.png", "png", 800, 600 );
-				//SavePlot( dialog.GetPath().c_str(), "png", 800, 600 );
-		}
-		break;
-	}
+    if (dialog.ShowModal() == wxID_OK) {
+      const wxCharBuffer buf1=dialog.GetPath().mb_str();
+      const wxCharBuffer buf2=dev_entries[index].dev_name.mb_str();
+      SavePlot( (const char*)buf1, (const char*)buf2, 800, 600 );
+    }
+  }
 }
 
-
 /*----------------------------------------------------------------------*\
  *  void wxPLplotFrame::OnClose( wxCloseEvent& event )
  *
@@ -1758,7 +1823,7 @@ void wxPLplotFrame::OnMenu( wxCommandEvent& event )
 \*----------------------------------------------------------------------*/
 void wxPLplotFrame::OnClose( wxCloseEvent& event )
 {
-  // Log_Verbose( "wxPLplotFrame::OnClose" );
+  Log_Verbose( "wxPLplotFrame::OnClose" );
 
   // Are you old enough to know that you want really to quit?
   wxMessageDialog dialog( this, wxT("Do you really want to quit?"), wxT("Close wxWidgets PLplot App?"), wxYES_NO |wxNO_DEFAULT| wxICON_EXCLAMATION );
@@ -1770,14 +1835,14 @@ void wxPLplotFrame::OnClose( wxCloseEvent& event )
 
 
 /*----------------------------------------------------------------------*\
- *  bool wxPLplotFrame::SavePlot( char* filename, int dev, int width,
+ *  bool wxPLplotFrame::SavePlot( const char* filename, cost char* dev, int width,
  *                                int height )
  *
  *  This function saves the current plot to a file (filename) using a
  *  device (devname) with given width and height. There is no test if
  *  the device really exists.
 \*----------------------------------------------------------------------*/
-bool wxPLplotFrame::SavePlot( char* filename, char* devname, int width,  int height )
+bool wxPLplotFrame::SavePlot( const char* filename, const char* devname, int width,  int height )
 {  
   int pls, pls_save;
   FILE *sfile;
@@ -1802,9 +1867,10 @@ bool wxPLplotFrame::SavePlot( char* filename, char* devname, int width,  int hei
 		return false;
 	}
 	plsdev( devname );
-  plsfile( sfile );
+  //plsfile( sfile );
+  plsfnam(filename);       /* file name */
   
-  plspage( 0., 0., width, height, 0, 0 );
+  //plspage( 0., 0., width, height, 0, 0 );
 	plcpstrm( pls, 0);
 	pladv( 0 );
 	plreplot();
@@ -1824,7 +1890,7 @@ wxPLplotWindow::wxPLplotWindow( wxWindow* parent, PLStream *pls )
              : wxWindow( parent, wxID_ANY, wxDefaultPosition, wxDefaultSize,
                          wxNO_BORDER|wxWANTS_CHARS|wxCLIP_CHILDREN )
 {
-  // Log_Verbose( "wxPLplotWindow::wxPLplotWindow" );
+  Log_Verbose( "wxPLplotWindow::wxPLplotWindow" );
 
   m_pls=pls;
   m_dev=(wxPLdev*)pls->dev;
@@ -1847,7 +1913,7 @@ wxPLplotWindow::wxPLplotWindow( wxWindow* parent, PLStream *pls )
 \*----------------------------------------------------------------------*/
 void wxPLplotWindow::OnPaint( wxPaintEvent& WXUNUSED(event) )
 {
-  // Log_Verbose( "wxPLplotWindow::OnPaint" );
+  Log_Verbose( "wxPLplotWindow::OnPaint" );
 	//static int counter=0;  
   /* copy bitmap into client area */
   wxPaintDC dc( this );
@@ -1872,14 +1938,18 @@ void wxPLplotWindow::OnPaint( wxPaintEvent& WXUNUSED(event) )
 		//printf( "Clipping region: x=%d, y=%d, width=%d, height=%d, counter=%d\n", vX, vY, vW, vH, counter++ );
   
     if( m_dev->antialized ) {
-      wxMemoryDC MemoryDC;
-			wxBitmap bitmap( m_dev->m_buffer->GetSubImage(wxRect(vX, vY, vW, vH)), -1 );
-      MemoryDC.SelectObject( bitmap );
-      dc.Blit( vX, vY, vW, vH, &MemoryDC, 0, 0 );
-      MemoryDC.SelectObject( wxNullBitmap );
+    	if( m_dev->m_buffer ) {
+	      wxMemoryDC MemoryDC;
+				wxBitmap bitmap( m_dev->m_buffer->GetSubImage(wxRect(vX, vY, vW, vH)), -1 );
+	      MemoryDC.SelectObject( bitmap );
+	      dc.Blit( vX, vY, vW, vH, &MemoryDC, 0, 0 );
+	      MemoryDC.SelectObject( wxNullBitmap );
+    	}
+    }
+    else {
+    	if( m_dev->dc )
+   	   dc.Blit( vX, vY, vW, vH, m_dev->dc, vX, vY );
     }
-    else 
-      dc.Blit( vX, vY, vW, vH, m_dev->dc, vX, vY );
 
     upd ++ ;
   }
@@ -1895,7 +1965,7 @@ void wxPLplotWindow::OnPaint( wxPaintEvent& WXUNUSED(event) )
 
 void wxPLplotWindow::OnChar( wxKeyEvent& event )
 {
-  // Log_Verbose( "wxPLplotWindow::OnChar" );
+  Log_Verbose( "wxPLplotWindow::OnChar" );
 
   int keycode = event.GetKeyCode();
   switch( keycode ) {
@@ -1923,7 +1993,7 @@ void wxPLplotWindow::OnChar( wxKeyEvent& event )
 
 void wxPLplotWindow::OnIdle( wxIdleEvent& WXUNUSED(event) )
 {
-  // Log_Verbose( "wxPLplotWindow::OnIdle" );
+  Log_Verbose( "wxPLplotWindow::OnIdle" );
 
   if( refresh ) {
     if(!m_dev->newclipregion) {
@@ -1951,13 +2021,13 @@ void wxPLplotWindow::OnIdle( wxIdleEvent& WXUNUSED(event) )
 
 void wxPLplotWindow::OnErase( wxEraseEvent &WXUNUSED(event) )
 {  
-  // Log_Verbose( "wxPLplotWindow::OnErase" );
+  Log_Verbose( "wxPLplotWindow::OnErase" );
 }
 
 
 void wxPLplotWindow::OnSize( wxSizeEvent & WXUNUSED(event) )
 {
-  // Log_Verbose( "wxPLplotWindow::OnSize" );
+  Log_Verbose( "wxPLplotWindow::OnSize" );
 
   int width, height;
   GetClientSize( &width, &height );
@@ -1977,7 +2047,7 @@ void wxPLplotWindow::OnSize( wxSizeEvent & WXUNUSED(event) )
           ((wxMemoryDC*)m_dev->dc)->SelectObject( wxNullBitmap );   /* deselect bitmap */
           if( m_dev->m_bitmap )
             delete m_dev->m_bitmap;
-          m_dev->m_bitmap = new wxBitmap( m_dev->bm_width, m_dev->bm_height, -1 );
+          m_dev->m_bitmap = new wxBitmap( m_dev->bm_width, m_dev->bm_height, 32 );
           ((wxMemoryDC*)m_dev->dc)->SelectObject( *(m_dev->m_bitmap) );   /* select new bitmap */
         }
       }
@@ -1994,7 +2064,7 @@ void wxPLplotWindow::OnSize( wxSizeEvent & WXUNUSED(event) )
 
 void wxPLplotWindow::OnMaximize( wxMaximizeEvent & WXUNUSED(event) )
 {
-  // Log_Verbose( "wxPLplotWindow::OnMax" );
+  Log_Verbose( "wxPLplotWindow::OnMax" );
 
   wxSizeEvent event( GetClientSize() );
   AddPendingEvent( event );
@@ -2002,7 +2072,7 @@ void wxPLplotWindow::OnMaximize( wxMaximizeEvent & WXUNUSED(event) )
 
 void wxPLplotWindow::OnMouse( wxMouseEvent &event )
 {
-  // Log_Verbose( "wxPLplotWindow::OnMouse" );
+  Log_Verbose( "wxPLplotWindow::OnMouse" );
 
   PLGraphicsIn *gin = &(m_dev->gin);
   wxPoint pos( event.GetPosition() );
