@@ -1,4 +1,4 @@
-/* $Id: xfig.c 5181 2004-01-19 19:10:19Z airwin $
+/* $Id: xfig.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot xfig device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-char* plD_DEVICE_INFO_xfig = "xfig:Fig file:0:xfig:31:xfig";
+const char* plD_DEVICE_INFO_xfig = "xfig:Fig file:0:xfig:31:xfig";
 
 /* Function prototypes */
 
