@@ -1,4 +1,4 @@
-/* $Id: xwin.c 7044 2006-09-05 05:10:13Z mlebrun $
+/* $Id: xwin.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	PLplot X-windows device driver.
 
@@ -45,7 +45,7 @@ static int already = 0;
 #endif
 
 /* Device info */
-char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw";
+const char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw";
 
 static int synchronize = 0;	/* change to 1 for X synchronized operation */
                                 /* Use "-drvopt sync" cmd line option to set. */
