@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x01.cc,v 1.20 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x01.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -46,7 +46,7 @@ static int test_xor;
 static int fontset;
 static char *f_name;
 
-static char *notes[] = {"Make sure you get it right!", ""};
+static const char *notes[] = {"Make sure you get it right!", ""};
 
 /* Options data structure definition. */
 static PLOptionTable options[] = {
@@ -96,7 +96,7 @@ static PLOptionTable options[] = {
 class x01 {
 
 public:
-  x01(int, char **);
+  x01(int, const char **);
 
   void plot1(int);
   void plot2();
@@ -112,9 +112,8 @@ private:
 };
 
 
-x01::x01( int argc, char ** argv ) {
+x01::x01( int argc, const char ** argv ) {
 
-  PLINT cur_strm, new_strm;
   char ver[80];
 
   fontset = 1;
@@ -378,7 +377,7 @@ void x01::plot3()
   delete[] y;
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x01 *x = new x01( argc, argv );
   delete x;
 
