@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x01cc.cc,v 1.14 2004/06/24 00:57:57 airwin Exp $
+// $Id: x01cc.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -21,7 +21,7 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -30,15 +30,7 @@
 // relating to 2-d plotting.
 //---------------------------------------------------------------------------//
 
-#ifdef HAVE_CMATH
-#include <cmath>
-#else
-#include <math.h>
-#endif
-
-#include <iostream>
-
-#include "plstream.h"
+#include "plc++demos.h"
 
 #ifdef USE_NAMESPACE
 using namespace std;
@@ -158,7 +150,7 @@ class CoordinateMatrix : public Coord_2d {
 class x01cc {
 
 public:
-   x01cc(int, char**);
+   x01cc(int, const char**);
    void plot1();
    void plot2();
 
@@ -260,7 +252,7 @@ void x01cc::plot2()
 	pls->shade( d, 0., 1., 0., twopi,
 		   shade_min, shade_max, sh_cmap, sh_color, sh_width,
 		   min_color, min_width, max_color, max_width,
-		   1, NULL );
+		   true, NULL );
     }
 
     pls->col(Red);
@@ -286,7 +278,7 @@ void x01cc::plot2()
 	pls->shade( d, 0., 1., 0., twopi,
 		   shade_min, shade_max, sh_cmap, sh_color, sh_width,
 		   min_color, min_width, max_color, max_width,
-		   0, &tr );
+		   false, &tr );
     }
 
     pls->col(Red);
@@ -337,7 +329,7 @@ void x01cc::plot2()
 	pls->shade( d, 0., 1., 0., twopi,
 		   shade_min, shade_max, sh_cmap, sh_color, sh_width,
 		   min_color, min_width, max_color, max_width,
-		   0, &tr );
+		   false, &tr );
     }
 
     pls->col(Red);
@@ -352,13 +344,13 @@ void x01cc::plot2()
     pls->line( 65, x, y );
 }
 
-x01cc::x01cc( int argc, char **argv ) {
+x01cc::x01cc( int argc, const char **argv ) {
 
    pls = new plstream();
 
    // Parse and process command line arguments.
   
-   pls->ParseOpts( &argc, argv, PL_PARSE_FULL );
+   pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
    // Initialize plplot.
   
@@ -372,7 +364,7 @@ x01cc::x01cc( int argc, char **argv ) {
 // Finally!
 //---------------------------------------------------------------------------//
 
-int main( int argc, char **argv ) 
+int main( int argc, const char **argv ) 
 {
    x01cc *x = new x01cc( argc, argv );
 
