@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x03.cc,v 1.8 2005/10/07 19:10:11 airwin Exp $
+// $Id: x03.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x03 {
 
 public:
-  x03(int, char **);
+  x03(int, const char **);
 
 private:
   // Class data
@@ -45,7 +45,7 @@ private:
 };
 
 
-x03::x03( int argc, char ** argv ) {
+x03::x03( int argc, const char ** argv ) {
 
   int i, j;
   char text[4];
@@ -96,7 +96,7 @@ x03::x03( int argc, char ** argv ) {
 
     // Draw radial spokes for polar grid.
     pls->join(0.0, 0.0, dx, dy);
-    sprintf(text, "%d", (int)rint(theta));
+    sprintf(text, "%d", (int)ROUND(theta));
 
     // Write labels for angle.
 
@@ -133,7 +133,7 @@ x03::x03( int argc, char ** argv ) {
 
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x03 *x = new x03( argc, argv );
 
   delete x;
