@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x06.cc,v 1.9 2005/10/07 19:10:11 airwin Exp $
+// $Id: x06.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x06 {
 
 public:
-  x06(int, char **);
+  x06(int, const char **);
 
 private:
   // Class data
@@ -45,7 +45,7 @@ private:
 };
 
 
-x06::x06( int argc, char ** argv ) {
+x06::x06( int argc, const char ** argv ) {
 
   int i, j, k;
   PLFLT x, y;
@@ -107,7 +107,7 @@ x06::x06( int argc, char ** argv ) {
   delete pls;
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x06 *x = new x06( argc, argv );
 
   delete x;
