@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x09.cc,v 1.6 2004/06/24 08:08:53 andrewross Exp $
+// $Id: x09.cc 8093 2007-12-13 09:11:34Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -19,17 +19,14 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
 // Implementation of PLplot example 09 in C++.
 //---------------------------------------------------------------------------//
 
-#include "plstream.h"
-
-#include <iostream>
-#include <cmath>
+#include "plc++demos.h"
 
 #ifdef USE_NAMESPACE
 using namespace std;
@@ -37,7 +34,7 @@ using namespace std;
 
 class x09 {
 public:
-  x09(int, char**);
+  x09(int, const char**);
   void polar();
   const void potential();
 
@@ -100,7 +97,7 @@ static void mypltr(PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data){
 // Does a large series of unlabelled and labelled contour plots.
 
 
-x09::x09( int argc, char **argv ) {
+x09::x09( int argc, const char **argv ) {
 
   int i, j;
 
@@ -119,7 +116,7 @@ x09::x09( int argc, char **argv ) {
 
   // Parse and process command line arguments.
 
-  pls->ParseOpts( &argc, argv, PL_PARSE_FULL );
+  pls->parseopts( &argc, argv, PL_PARSE_FULL );
   /* Initialize plplot */
 
   pls->init();
@@ -374,10 +371,10 @@ const void x09::potential()
 
   // Expanded limits
   peps = 0.05;
-  xpmin = xmin - abs(xmin)*peps;
-  xpmax = xmax + abs(xmax)*peps;
-  ypmin = ymin - abs(ymin)*peps;
-  ypmax = ymax + abs(ymax)*peps;
+  xpmin = xmin - fabs(xmin)*peps;
+  xpmax = xmax + fabs(xmax)*peps;
+  ypmin = ymin - fabs(ymin)*peps;
+  ypmax = ymax + fabs(ymax)*peps;
 
   // Potential inside a conducting cylinder (or sphere) by method of images.
   // Charge 1 is placed at (d1, d1), with image charge at (d2, d2).
@@ -478,7 +475,7 @@ const void x09::potential()
   delete[] py;
 }
 
-int main( int argc, char **argv )
+int main( int argc, const char **argv )
 {
   x09 *x = new x09( argc, argv );
 
