@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x11.cc,v 1.11 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x11.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x11 {
 
 public:
-  x11(int, char**);
+  x11(int, const char**);
   void cmap1_init();
 
 private:
@@ -101,7 +101,7 @@ void x11::cmap1_init()
 }
 
 
-x11::x11( int argc, char **argv ) {
+x11::x11( int argc, const char **argv ) {
 
   int i, j, k;
 
@@ -187,7 +187,7 @@ x11::x11( int argc, char **argv ) {
 
       /* magnitude colored wireframe plot with sides */
       else if (i==2) {
-	pls->plot3d(x, y, z, XPTS, YPTS, opt[k] | MAG_COLOR, 1);
+	pls->plot3d(x, y, z, XPTS, YPTS, opt[k] | MAG_COLOR, true);
       }
 
       /* magnitude colored wireframe plot with base contour */
@@ -216,7 +216,7 @@ x11::x11( int argc, char **argv ) {
 // options in each plot.
 
 
-int main( int argc, char **argv )
+int main( int argc, const char **argv )
 {
   x11 *x = new x11( argc, argv );
 
