@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x12.cc,v 1.5 2004/03/03 17:41:16 andrewross Exp $
+// $Id: x12.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -19,17 +19,14 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
 // Implementation of PLplot example 12 in C++.
 //---------------------------------------------------------------------------//
 
-#include "plstream.h"
-
-#include <iostream>
-#include <cmath>
+#include "plc++demos.h"
 
 #ifdef USE_NAMESPACE
 using namespace std;
@@ -38,7 +35,7 @@ using namespace std;
 class x12 {
 
 public:
-  x12(int, char**);
+  x12(int, const char**);
   void plfbox(PLFLT, PLFLT);
 private:
   plstream *pls;
@@ -50,7 +47,7 @@ private:
 
 const PLFLT x12::y0[10] = {5., 15., 12., 24., 28., 30., 20., 8., 12., 3.};
 
-x12::x12( int argc, char **argv ) {
+x12::x12( int argc, const char **argv ) {
 
   int i;
   char string[20];
@@ -59,7 +56,7 @@ x12::x12( int argc, char **argv ) {
 
   // Parse and process command line arguments.
 
-  pls->ParseOpts( &argc, argv, PL_PARSE_FULL );
+  pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
 
   // Initialize plplot.
@@ -111,7 +108,7 @@ void x12::plfbox(PLFLT x0, PLFLT y0) {
 
 
 
-int main( int argc, char **argv )
+int main( int argc, const char **argv )
 {
   x12 *x = new x12( argc, argv );
 
