@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x13.cc,v 1.8 2005/10/07 19:10:11 airwin Exp $
+// $Id: x13.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -32,13 +32,13 @@
 using namespace std;
 #endif
 
-static char* text[] = {"Maurice", "Geoffrey", "Alan", "Rafael", "Vince"};
+static const char* text[] = {"Maurice", "Geoffrey", "Alan", "Rafael", "Vince"};
 static int per[] = {10, 32, 12, 30, 16};
 
 class x13 {
 
 public:
-  x13(int, char **);
+  x13(int, const char **);
 
 private:
   // Class data
@@ -48,7 +48,7 @@ private:
 };
 
 
-x13::x13( int argc, char ** argv ) {
+x13::x13( int argc, const char ** argv ) {
 
   int i, j, dthet, theta0, theta1, theta;
   PLFLT just, dx, dy;
@@ -113,7 +113,7 @@ x13::x13( int argc, char ** argv ) {
 
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x13 *x = new x13( argc, argv );
 
   delete x;
