@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x14.cc,v 1.13 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x14.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x14 {
 
 public:
-  x14(int, char **);
+  x14(int, const char **);
   void plot1(plstream *);
   void plot2(plstream *);
   void plot3(plstream *);
@@ -85,18 +85,16 @@ static PLFLT clevel[11] =
  * This version sends the output of the first 4 plots (one page) to two
  * independent streams.
 \*--------------------------------------------------------------------------*/
-x14::x14( int argc, char ** argv ) {
-  int i, digmax;
-  int xleng0 = 400, yleng0 = 300, xoff0 = 200, yoff0 = 200;
-  int xleng1 = 400, yleng1 = 300, xoff1 = 500, yoff1 = 500;
+x14::x14( int argc, const char ** argv ) {
+  int digmax;
 
   // Select either TK or DP driver and use a small window
   // Using DP results in a crash at the end due to some odd cleanup problems
   // The geometry strings MUST be in writable memory
 
   char driver[80];
-  char geometry_master[] = "500x410+100+200";
-  char geometry_slave[]  = "500x410+650+200";
+  const char geometry_master[] = "500x410+100+200";
+  const char geometry_slave[]  = "500x410+650+200";
 
   // plplot initialization
 
@@ -311,7 +309,7 @@ void x14::plot4(plstream *pls)
 {
     int i, j;
     PLFLT dtr, theta, dx, dy, r;
-    char text[3];
+    char text[4];
     PLFLT x0[361], y0[361];
     PLFLT x[361], y[361];
 
@@ -344,7 +342,7 @@ void x14::plot4(plstream *pls)
 /* Draw radial spokes for polar grid */
 
 	pls->join(0.0, 0.0, dx, dy);
-	sprintf(text, "%d", (int)rint(theta));
+	sprintf(text, "%d", (int)ROUND(theta));
 
 /* Write labels for angle */
 
@@ -408,7 +406,7 @@ void x14::plot5(plstream *pls)
 }
 
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x14 *x = new x14( argc, argv );
 
   delete x;
