@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x15.cc,v 1.6 2004/06/24 08:08:53 andrewross Exp $
+// $Id: x15.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -19,17 +19,14 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
 // Implementation of PLplot example 15 in C++.
 //---------------------------------------------------------------------------//
 
-#include "plstream.h"
-
-#include <iostream>
-#include <cmath>
+#include "plc++demos.h"
 
 #ifdef USE_NAMESPACE
 using namespace std;
@@ -38,7 +35,7 @@ using namespace std;
 class x15 {
 
 public:
-  x15(int, char **);
+  x15(int, const char **);
   void plot1( PLFLT **, PLFLT, PLFLT);
   void plot2( PLFLT **, PLFLT, PLFLT);
 
@@ -65,7 +62,7 @@ const PLFLT x15::YSPA =  2./(YPTS-1);
 const PLFLT x15::tr[] = {XSPA, 0.0, -1.0, 0.0, YSPA, -1.0};
 
 
-x15::x15( int argc, char ** argv ) {
+x15::x15( int argc, const char ** argv ) {
 
   int i, j;
 
@@ -82,7 +79,7 @@ x15::x15( int argc, char ** argv ) {
   pls = new plstream();
 
   // Parse and process command line arguments.
-  pls->ParseOpts( &argc, argv, PL_PARSE_FULL );
+  pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
   // Initialize PLplot.
   pls->init();
@@ -145,7 +142,7 @@ void x15::plot1( PLFLT **z, PLFLT zmin, PLFLT zmax) {
 	       shade_min, shade_max,
 	       sh_cmap, sh_color, sh_width,
 	       min_color, min_width, max_color, max_width,
-	       plstream::fill, 1, NULL, NULL );
+	       plstream::fill, true, NULL, NULL );
 
   pls->col0(1);
   pls->box("bcnst", 0.0, 0, "bcnstv", 0.0, 0);
@@ -180,7 +177,7 @@ void x15::plot2(PLFLT **z, PLFLT zmin, PLFLT zmax)
 		 shade_min, shade_max,
 		 sh_cmap, sh_color, sh_width,
 		 min_color, min_width, max_color, max_width,
-		 plstream::fill, 1, NULL, NULL );
+		 plstream::fill, true, NULL, NULL );
   }
 
   pls->col0(1);
@@ -189,7 +186,7 @@ void x15::plot2(PLFLT **z, PLFLT zmin, PLFLT zmax)
   pls->lab("distance", "altitude", "Bogon flux");
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x15 *x = new x15( argc, argv );
 
   delete x;
