@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x17.cc,v 1.11 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x17.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -42,28 +42,28 @@ using namespace std;
 class x17 {
 
 public:
-  x17(int, char **);
+  x17(int, const char **);
 
 private:
   // Class data
   plstream *pls;
 
 public:
-  static PLINT errcode;
+  static PLINT pl_errcode;
   static char errmsg[160];
 
 };
 
-PLINT x17::errcode = 0;
+PLINT x17::pl_errcode = 0;
 char x17::errmsg[160] = "";
 
-x17::x17( int argc, char ** argv ) {
-  PLINT id1, id2, n, nsteps = 1000;
+x17::x17( int argc, const char ** argv ) {
+  PLINT id1, n, nsteps = 1000;
   bool autoy, acc;
   PLFLT y1, y2, y3, y4, ymin, ymax, xlab, ylab;
   PLFLT t, tmin, tmax, tjump, dt, noise;
   PLINT colbox, collab, colline[4], styline[4];
-  char *legline[4], toplab[20];
+  const char *legline[4];
 
   // plplot initialization
 
@@ -120,7 +120,7 @@ x17::x17( int argc, char ** argv ) {
   // Register our error variables with PLplot
   // From here on, we're handling all errors here
 
-  pls->sError(&errcode, errmsg);
+  pls->sError(&pl_errcode, errmsg);
 
   pls->stripc(&id1, "bcnst", "bcnstv",
              tmin, tmax, tjump, ymin, ymax,
@@ -130,7 +130,7 @@ x17::x17( int argc, char ** argv ) {
              colline, styline, legline,
              "t", "", "Strip chart demo");
 
-  if (errcode) {
+  if (pl_errcode) {
     cout << errmsg << endl;
     delete pls;
     exit(1);
@@ -140,8 +140,8 @@ x17::x17( int argc, char ** argv ) {
 
   pls->sError(NULL, NULL);
 
-  autoy = 0;  // autoscale y
-  acc = 1;    // accumulate/
+  autoy = false;  // autoscale y
+  acc = true;    // accumulate/
 
   // This is to represent a loop over time
   // Let's try a random walk process
@@ -158,7 +158,7 @@ x17::x17( int argc, char ** argv ) {
 # endif
 #endif
     t = (double)n * dt;
-    noise = drand48() - 0.5;
+    noise = ((double)rand()/(RAND_MAX+1.0)) - 0.5;
     y1 = y1 + noise;
     y2 = sin(t*M_PI/18.);
     y3 = y2 * noise;
@@ -185,7 +185,7 @@ x17::x17( int argc, char ** argv ) {
 
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x17 *x = new x17( argc, argv );
 
   delete x;
