@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x18.cc,v 1.10 2005/12/06 16:36:03 andrewross Exp $
+// $Id: x18.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x18 {
 
 public:
-  x18(int, char **);
+  x18(int, const char **);
   PLFLT THETA(int);
   PLFLT PHI(int);
   void test_poly(int);
@@ -58,9 +58,9 @@ const PLFLT x18::alt[4] = {20.0, 35.0, 50.0, 65.0};
 const PLFLT x18::az[4] = {30.0, 40.0, 50.0, 60.0};
 
 
-x18::x18( int argc, char ** argv ) {
+x18::x18( int argc, const char ** argv ) {
 
-  int i, j, k;
+  int i, k;
   PLFLT r;
   char title[80];
 
@@ -138,11 +138,11 @@ PLFLT x18::PHI (int a) {
 
 void x18::test_poly(int k) {
   int i, j;
-  PLINT draw[4][4]  = {
-    { 1, 1, 1, 1 },
-    { 1, 0, 1, 0 },
-    { 0, 1, 0, 1 },
-    { 1, 1, 0, 0 }
+  bool draw[4][4]  = {
+    { true, true, true, true },
+    { true, false, true, false },
+    { false, true, false, true },
+    { true, true, false, false }
   };
 
   PLFLT *x = new PLFLT [5];
@@ -199,7 +199,7 @@ void x18::test_poly(int k) {
   delete[] z;
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x18 *x = new x18( argc, argv );
 
   delete x;
