@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x19.cc,v 1.8 2005/10/07 19:10:11 airwin Exp $
+// $Id: x19.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -35,7 +35,7 @@ using namespace std;
 class x19 {
 
 public:
-  x19(int, char **);
+  x19(int, const char **);
 
 private:
   // Class data
@@ -67,10 +67,9 @@ mapform19(PLINT n, PLFLT *x, PLFLT *y)
 }
 
 
-x19::x19( int argc, char ** argv ) {
+x19::x19( int argc, const char ** argv ) {
 
   PLFLT minx, maxx, miny, maxy;
-  int c;
 
   // plplot initialization
 
@@ -119,7 +118,7 @@ x19::x19( int argc, char ** argv ) {
 
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x19 *x = new x19( argc, argv );
 
   delete x;
