@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x20.cc,v 1.7 2004/06/24 01:19:23 airwin Exp $
+// $Id: x20.cc 8033 2007-11-23 15:28:09Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -19,19 +19,16 @@
 //
 // You should have received a copy of the GNU Library General Public License
 // along with PLplot; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
 // Implementation of PLplot example 20 in C++.
 //---------------------------------------------------------------------------//
 
-#include "plstream.h"
+#include "plc++demos.h"
 #include "plevent.h"
-
 #include <fstream>
-#include <iostream>
-#include <cmath>
 
 #ifdef USE_NAMESPACE
 using namespace std;
@@ -40,10 +37,10 @@ using namespace std;
 class x20 {
 
 public:
-  x20(int, char **);
-  void save_plot(char *);
-  void gray_cmap(int);
-  int read_img(char *, PLFLT ***, int *, int *, int *);
+  x20(int, const char **);
+  void save_plot(const char *);
+  void gray_cmap(PLINT);
+  int read_img(const char *, PLFLT ***, int *, int *, int *);
   int get_clip(PLFLT *, PLFLT *, PLFLT *, PLFLT *);
 
 private:
@@ -113,7 +110,7 @@ PLOptionTable x20::options[] = {
 };
 
 
-x20::x20( int argc, char ** argv ) {
+x20::x20( int argc, const char ** argv ) {
   PLFLT x[XDIM], y[YDIM], **z, **r;
   PLFLT xi, yi, xe, ye;
   int i, j, width, height, num_col;
@@ -135,7 +132,7 @@ x20::x20( int argc, char ** argv ) {
 
   // Parse and process command line arguments.
   pls->MergeOpts(options, "x20c options", NULL);
-  pls->ParseOpts( &argc, argv, PL_PARSE_FULL );
+  pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
   // Initialize PLplot.
   pls->init();
@@ -200,9 +197,11 @@ x20::x20( int argc, char ** argv ) {
 
   /* read Lena image */
   if (read_img("lena.pgm", &img_f, &width, &height, &num_col)) {
-    cout << "No such file - aborting" << endl;
-    delete pls;
-    exit(1);
+    if (read_img("../lena.pgm", &img_f, &width, &height, &num_col)) {
+      cout << "No such file - aborting" << endl;
+      delete pls;
+      exit(1);
+    }
   }
 
   /* set gray colormap */
@@ -243,19 +242,19 @@ x20::x20( int argc, char ** argv ) {
     /* pls->bop(); */
 
     /*
-       spause(0), adv(0), spause(1), also works,
+       spause(false), adv(0), spause(true), also works,
        but the above question remains.
        With this approach, the previous pause state is lost,
        as there is no API call to get its current state.
     */
 
-    pls->spause(0);
+    pls->spause(false);
     pls->adv(0);
 
     // display selection only
     pls->image(img_f, width, height, 1., width, 1., height, 0., 0., xi, xe, ye, yi);
 
-    pls->spause(1);
+    pls->spause(true);
     pls->adv(0);
 
     // zoom in selection
@@ -271,7 +270,7 @@ x20::x20( int argc, char ** argv ) {
 }
 
 // read image from file in binary ppm format
-int x20::read_img(char *fname, PLFLT ***img_f, int *width, int *height, int *num_col) {
+int x20::read_img(const char *fname, PLFLT ***img_f, int *width, int *height, int *num_col) {
   ifstream ifs(fname,ios::out | ios::binary);
   unsigned char *img;
   char ver[80];
@@ -298,6 +297,7 @@ int x20::read_img(char *fname, PLFLT ***img_f, int *width, int *height, int *num
   ifs.putback(c);
 
   ifs >> w >> h >> *num_col;
+  ifs.getline(ver,80);
   //cout << "width=" << w << " height=" << h << " num_col=" << *num_col << endl;
 
   img = new unsigned char[w*h];
@@ -319,7 +319,7 @@ int x20::read_img(char *fname, PLFLT ***img_f, int *width, int *height, int *num
 }
 
 // save plot
-void x20::save_plot(char *fname) {
+void x20::save_plot(const char *fname) {
   plstream *pls2;
 
   pls2 = new plstream(); // create a new one
@@ -327,7 +327,7 @@ void x20::save_plot(char *fname) {
   pls2->sdev("psc"); // new device type. Use a known existing driver
   pls2->sfnam(fname); // file name
 
-  pls2->cpstrm(*pls, 0); // copy old stream parameters to new stream
+  pls2->cpstrm(*pls, false); // copy old stream parameters to new stream
   pls2->replot();	// do the save
 
   delete pls2; // close new device
@@ -338,17 +338,18 @@ void x20::save_plot(char *fname) {
 int x20::get_clip(PLFLT *xi, PLFLT *xe, PLFLT *yi, PLFLT *ye) {
   PLGraphicsIn gin;
   PLFLT xxi=*xi, yyi=*yi, xxe=*xe, yye=*ye, t;
-  int st, start = 0;
+  PLINT start = 0;
+  bool st;
 
-  pls->xormod(1, &st); /* enter xor mode to draw a selection rectangle */
+  pls->xormod(true, &st); /* enter xor mode to draw a selection rectangle */
 
   if (st) { /* driver has xormod capability, continue */
     while(1) {
       PLFLT sx[5], sy[5];
 
-      pls->xormod(0, &st);
+      pls->xormod(false, &st);
       pls->GetCursor(&gin);
-      pls->xormod(1, &st);
+      pls->xormod(true, &st);
 
       if (gin.button == 1) {
 	xxi = gin.wX; yyi = gin.wY;
@@ -361,7 +362,7 @@ int x20::get_clip(PLFLT *xi, PLFLT *xe, PLFLT *yi, PLFLT *ye) {
 	sx[4] = xxi; sy[4] = yyi;
       }
 
-      if (gin.state && 0x100) {
+      if (gin.state & 0x100) {
 	xxe = gin.wX; yye = gin.wY;
 	if (start)
 	  pls->line(5, sx, sy); /* clear previous rectangle */
@@ -380,19 +381,20 @@ int x20::get_clip(PLFLT *xi, PLFLT *xe, PLFLT *yi, PLFLT *ye) {
 	break;
       }
     }
-    pls->xormod(0, &st); /* leave xor mod */
-  }
+    pls->xormod(false, &st); /* leave xor mod */
 
-  if (xxe < xxi) {
-    t=xxi; xxi=xxe; xxe=t;}
+    if (xxe < xxi) {
+      t=xxi; xxi=xxe; xxe=t;}
 
-  if (yyi < yye) {
-    t=yyi; yyi=yye; yye=t;}
+    if (yyi < yye) {
+      t=yyi; yyi=yye; yye=t;}
 
-  *xe = xxe; *xi = xxi;
-  *ye = yye; *yi = yyi;
+    *xe = xxe; *xi = xxi;
+    *ye = yye; *yi = yyi;
 
-  return (gin.keysym == 'Q');
+    return (gin.keysym == 'Q');
+   } else /* driver has no xormod capability, just do nothing */
+		return 0;
 }
 
 /* set gray colormap */
@@ -406,10 +408,10 @@ void x20::gray_cmap(PLINT num_col) {
   pos[1] = 1.0;
 
   pls->scmap1n(num_col);
-  pls->scmap1l(1, 2, pos, r, g, b, NULL);
+  pls->scmap1l(true, 2, pos, r, g, b, NULL);
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x20 *x = new x20( argc, argv );
 
   delete x;
