@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x21.cc 7038 2006-08-31 17:34:18Z airwin $
+// $Id: x21.cc 8094 2007-12-13 09:28:06Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -27,7 +27,7 @@
 //---------------------------------------------------------------------------//
 
 #include "plc++demos.h"
-#include <time.h>
+#include <ctime>
 
 #if !defined(HAVE_ISNAN)
   #define isnan(x) ((x) != (x))
@@ -55,7 +55,7 @@ using namespace std;
 class x21 {
 
 public:
-  x21(int, char **);
+  x21(int, const char **);
 
 private:
   void create_data(PLFLT **xi, PLFLT **yi, PLFLT **zi, PLINT pts);
@@ -174,7 +174,7 @@ PLOptionTable x21::options[] = {
     NULL }                      /* long syntax */
 };
 
-x21::x21( int argc, char ** argv ) {
+x21::x21( int argc, const char ** argv ) {
   PLFLT *x, *y, *z, *clev;
   PLFLT *xg, *yg, **zg;
   PLFLT zmin, zmax, lzm, lzM;
@@ -182,7 +182,7 @@ x21::x21( int argc, char ** argv ) {
   int i, j, k;
   PLINT alg;
   char ylab[40], xlab[40];
-  char *title[] = {"Cubic Spline Approximation",
+  const char *title[] = {"Cubic Spline Approximation",
 		   "Delaunay Linear Interpolation",
 		   "Natural Neighbors Interpolation",
 		   "KNN Inv. Distance Weighted",
@@ -412,7 +412,7 @@ void x21::free_data(PLFLT *x, PLFLT *y, PLFLT *z) {
   delete[] z;
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
   x21 *x = new x21( argc, argv );
 
   delete x;
