@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x22.cc,v 1.15 2006/05/13 06:44:43 airwin Exp $
+// $Id: x22.cc 8033 2007-11-23 15:28:09Z andrewross $
 //    Simple vector plot example
 //---------------------------------------------------------------------------//
 //
@@ -35,7 +35,7 @@ using namespace std;
 class x22 {
 
 public:
-    x22(int, char **);
+    x22(int, const char **);
 
 private:
     void circulation();
@@ -248,7 +248,7 @@ x22::f2mnmx(PLFLT **f, PLINT nx, PLINT ny, PLFLT *fmin, PLFLT *fmax)
 }
 
 
-x22::x22( int argc, char ** argv ) {
+x22::x22( int argc, const char ** argv ) {
 
     PLINT narr;
     bool fill;
@@ -310,7 +310,7 @@ x22::x22( int argc, char ** argv ) {
     exit(0);
 }
 
-int main( int argc, char ** argv ) {
+int main( int argc, const char ** argv ) {
     x22 *x = new x22( argc, argv );
     delete x;
 
