@@ -8,10 +8,10 @@
  *   Department of Physics and Atmospheric Science,
  *   Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5
  *
- *   $Author: tomduck $
- *   $Revision: 1.6 $
- *   $Date: 2005/05/16 17:05:35 $
- *   $Name: cvs-tarball_2006-05-29-23-03-54 $
+ *   $Author: andrewross $
+ *   $Revision: 8197 $
+ *   $Date: 2008-01-30 13:38:39 -0500 (Wed, 30 Jan 2008) $
+ *   $Name$
  *
  *
  * NOTICE
@@ -132,12 +132,12 @@ void plot(PlplotCanvas *canvas,gdouble offset,char* title)
 }
 
 /* Delete event callback */
-gint delete_event( GtkWidget *widget,GdkEvent *event,gpointer data ) {
+gint delete_event_local( GtkWidget *widget,GdkEvent *event,gpointer data ) {
   return FALSE;
 }
 
 /* Destroy event calback */
-void destroy(GtkWidget *widget,gpointer data) {
+void destroy_local(GtkWidget *widget,gpointer data) {
   G_LOCK(gtkstate);
   gtkstate=GTKSTATE_QUIT;
   G_UNLOCK(gtkstate);
@@ -218,7 +218,7 @@ int main(int argc,char *argv[] )
   GtkBox* vbox;
 
   /* Parse the options */
-  plparseopts(&argc, argv, PL_PARSE_FULL);
+  plparseopts(&argc, (const char **) argv, PL_PARSE_FULL);
 
   /* Initialize */
   g_thread_init(NULL);
@@ -275,8 +275,8 @@ int main(int argc,char *argv[] )
   
   /* Connect the signal handlers to the window decorations */
   g_signal_connect(G_OBJECT(window),"delete_event",
-		   G_CALLBACK(delete_event),NULL);
-  g_signal_connect(G_OBJECT(window),"destroy",G_CALLBACK(destroy),NULL);
+		   G_CALLBACK(delete_event_local),NULL);
+  g_signal_connect(G_OBJECT(window),"destroy",G_CALLBACK(destroy_local),NULL);
   
   /* Put the vbox into the window */
   gtk_container_add(GTK_CONTAINER(window),GTK_WIDGET(vbox));
