@@ -8,10 +8,10 @@
  *  Department of Physics and Atmospheric Science,
  *  Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5
  *
- *  $Author: tomduck $
- *  $Revision: 1.6 $
- *  $Date: 2005/05/16 17:05:54 $
- *  $Name: cvs-tarball_2006-05-29-23-03-54 $
+ *  $Author: andrewross $
+ *  $Revision: 8197 $
+ *  $Date: 2008-01-30 13:38:39 -0500 (Wed, 30 Jan 2008) $
+ *  $Name$
  *
  *
  * NOTICE
@@ -40,12 +40,12 @@
 #define HEIGHT 600 /* 300 */
 
 /* Delete event callback */
-gint delete_event( GtkWidget *widget,GdkEvent *event,gpointer data ) {
+gint delete_event_local( GtkWidget *widget,GdkEvent *event,gpointer data ) {
   return FALSE;
 }
 
 /* Destroy event calback */
-void destroy(GtkWidget *widget,gpointer data) {
+void destroy_local(GtkWidget *widget,gpointer data) {
   gtk_main_quit ();
 }
 
@@ -57,7 +57,7 @@ int main(int argc,char *argv[] )
   GtkWidget *window;
 
   /* Parse the options */
-  plparseopts(&argc, argv, PL_PARSE_FULL);
+  plparseopts(&argc, (const char **) argv, PL_PARSE_FULL);
 
   /* The data to plot */
   double x[11] = {0,1,2,3,4,5,6,7,8,9,10};
@@ -80,8 +80,8 @@ int main(int argc,char *argv[] )
 
   /* Connect the signal handlers to the window decorations */
   g_signal_connect(G_OBJECT(window),"delete_event",
-		   G_CALLBACK(delete_event),NULL);
-  g_signal_connect(G_OBJECT(window),"destroy",G_CALLBACK(destroy),NULL);
+		   G_CALLBACK(delete_event_local),NULL);
+  g_signal_connect(G_OBJECT(window),"destroy",G_CALLBACK(destroy_local),NULL);
 
   /* Display everything */
   gtk_widget_show_all(window);
