@@ -1,4 +1,4 @@
-/* $Id: x03c.c,v 1.18 2002/12/03 08:39:24 airwin Exp $
+/* $Id: x03c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Polar plot demo.
 */
@@ -12,7 +12,7 @@
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     int i, j;
     PLFLT dtr, theta, dx, dy, r;
@@ -20,7 +20,7 @@ main(int argc, char *argv[])
     static PLFLT x0[361], y0[361];
     static PLFLT x[361], y[361];
 
-    dtr = PI / 180.0;
+    dtr = M_PI / 180.0;
     for (i = 0; i <= 360; i++) {
 	x0[i] = cos(dtr * i);
 	y0[i] = sin(dtr * i);
@@ -28,7 +28,7 @@ main(int argc, char *argv[])
 
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
