@@ -1,4 +1,4 @@
-/* $Id: x09c.c,v 1.30 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x09c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Contour plot demo.
 
@@ -273,7 +273,7 @@ static void potential()
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     int i, j;
     PLFLT xx, yy, argx, argy, distort;
