@@ -1,4 +1,4 @@
-/* $Id: x10c.c,v 1.13 2002/12/03 08:39:24 airwin Exp $
+/* $Id: x10c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Window positioning demo.
 */
@@ -12,12 +12,12 @@
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
 
 /* Parse and process command line arguments */
 
-    (void) plParseOpts(&argc, argv, PL_PARSE_FULL);
+    (void) plparseopts(&argc, argv, PL_PARSE_FULL);
 
 /* Initialize plplot */
 
