@@ -1,4 +1,4 @@
-/* $Id: x14c.c,v 1.29 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x14c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Demo of multiple stream/window capability (requires Tk or Tcl-DP).
 
@@ -47,11 +47,9 @@ void plot5();
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
-    int i, digmax;
-    int xleng0 = 400, yleng0 = 300, xoff0 = 200, yoff0 = 200;
-    int xleng1 = 400, yleng1 = 300, xoff1 = 500, yoff1 = 500;
+    int digmax;
 
 /* Select either TK or DP driver and use a small window */
 /* Using DP results in a crash at the end due to some odd cleanup problems */
@@ -285,7 +283,7 @@ plot4(void)
 {
     int i, j;
     PLFLT dtr, theta, dx, dy, r;
-    char text[3];
+    char text[4];
     PLFLT x0[361], y0[361];
     PLFLT x[361], y[361];
 
