@@ -1,4 +1,4 @@
-/* $Id: x15c.c,v 1.17 2005/04/05 19:16:15 airwin Exp $
+/* $Id: x15c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Shade plot demo.
 
@@ -29,7 +29,7 @@ static void	cmap1_init2	(void);
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     int i, j;
     PLFLT xx, yy;
