@@ -1,4 +1,4 @@
-/* $Id: x17c.c,v 1.21 2006/05/27 20:46:43 hbabcock Exp $
+/* $Id: x17c.c 8033 2007-11-23 15:28:09Z andrewross $
 
  * Plots a simple stripchart with four pens.
  */
@@ -17,7 +17,7 @@
 
 /* Variables for holding error return info from PLplot */
 
-static PLINT errcode;
+static PLINT pl_errcode;
 static char errmsg[160];
 
 /*--------------------------------------------------------------------------*\
@@ -25,13 +25,13 @@ static char errmsg[160];
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     PLINT id1, n, autoy, acc, nsteps = 1000;
     PLFLT y1, y2, y3, y4, ymin, ymax, xlab, ylab;
     PLFLT t, tmin, tmax, tjump, dt, noise;
     PLINT colbox, collab, colline[4], styline[4];
-    char *legline[4];
+    const char *legline[4];
 
 /* plplot initialization */
 /* Parse and process command line arguments */
@@ -94,7 +94,7 @@ main(int argc, char *argv[])
 /* Register our error variables with PLplot */
 /* From here on, we're handling all errors here */
 
-    plsError(&errcode, errmsg);
+    plsError(&pl_errcode, errmsg);
 
     plstripc(&id1, "bcnst", "bcnstv",
 	     tmin, tmax, tjump, ymin, ymax,
@@ -104,7 +104,7 @@ main(int argc, char *argv[])
 	     colline, styline, legline, 
 	     "t", "", "Strip chart demo"); 
 
-    if (errcode) {
+    if (pl_errcode) {
 	fprintf(stderr, "%s\n", errmsg);
 	exit(1);
     }
