@@ -1,4 +1,4 @@
-/* $Id: x19c.c,v 1.13 2006/05/27 20:59:50 hbabcock Exp $
+/* $Id: x19c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Illustrates backdrop plotting of world, US maps.
 	Contributed by Wesley Ebisuzaki.
@@ -35,7 +35,7 @@ mapform19(PLINT n, PLFLT *x, PLFLT *y)
 \*--------------------------------------------------------------------------*/
 
 int 
-main(int argc, char **argv) 
+main(int argc, const char **argv) 
 {
     PLFLT minx, maxx, miny, maxy;
 
