@@ -1,4 +1,4 @@
-/* $Id: x20c.c,v 1.18 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x20c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	plimage demo
 
@@ -6,6 +6,7 @@
 
 #include "plcdemos.h"
 #include "plevent.h"
+#include "plplotP.h"
 #include <math.h>
 
 #define XDIM 260
@@ -65,7 +66,7 @@ static PLOptionTable options[] = {
 };
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
   PLFLT x[XDIM], y[YDIM], **z, **r;
   PLFLT xi, yi, xe, ye; 
@@ -150,10 +151,14 @@ main(int argc, char *argv[])
   plFree2dGrid(z, XDIM, YDIM);
 
   /* read Lena image */
-  if (read_img("lena.pgm", &img_f, &width, &height, &num_col)) {
-    plabort("No such file");
-    plend();
-    exit(1);
+  /* Note we try two different locations to cover the case where this
+   * examples is being run from the test_c.sh script */
+  if (read_img("lena.pgm", &img_f, &width, &height, &num_col)) { 
+    if (read_img("../lena.pgm", &img_f, &width, &height, &num_col)) {
+      plabort("No such file");
+      plend();
+      exit(1);
+    }
   }
 
   /* set gray colormap */
@@ -248,7 +253,7 @@ int read_img(char *fname, PLFLT ***img_f, int *width, int *height, int *num_col)
   }
   ungetc(i, fp);
 
-  fscanf(fp,"%d%d%d", &w, &h, num_col); /* width, height num colors */
+  fscanf(fp,"%d%d%d\n", &w, &h, num_col); /* width, height num colors */
   /* printf("width=%d height=%d num_col=%d\n", w, h, *num_col); */
 
   img = (unsigned char *) malloc(w*h*sizeof(char));
@@ -315,17 +320,17 @@ int get_clip(PLFLT *xi, PLFLT *xe, PLFLT *yi, PLFLT *ye)
 	sx[4] = xxi; sy[4] = yyi;
       }
 
-      if (gin.state && 0x100) {
+      if (gin.state & 0x100) {
 	xxe = gin.wX; yye = gin.wY;
 	if (start)
 	  plline(5, sx, sy); /* clear previous rectangle */
-
+	
 	start = 1;
-  
+	
 	sx[2] = xxe; sy[2] = yye;
 	sx[1] = xxe; sy[1] = yyi;
 	sx[3] = xxi; sy[3] = yye;
-	plline(5, sx, sy); /* draw new rectangle */
+	  plline(5, sx, sy); /* draw new rectangle */	
       }
 
       if (gin.button == 3 || gin.keysym == PLK_Return || gin.keysym == 'Q') {
@@ -335,18 +340,19 @@ int get_clip(PLFLT *xi, PLFLT *xe, PLFLT *yi, PLFLT *ye)
       }      
     }
     plxormod(0, &st); /* leave xor mod */
-  }
 
-  if (xxe < xxi) {
-    t=xxi; xxi=xxe; xxe=t;}
-
-  if (yyi < yye) {
-    t=yyi; yyi=yye; yye=t;}
-
-  *xe = xxe; *xi = xxi;
-  *ye = yye; *yi = yyi;
-
-  return (gin.keysym == 'Q');
+    if (xxe < xxi) {
+      t=xxi; xxi=xxe; xxe=t;}
+    
+    if (yyi < yye) {
+      t=yyi; yyi=yye; yye=t;}
+    
+    *xe = xxe; *xi = xxi;
+    *ye = yye; *yi = yyi;
+    
+    return (gin.keysym == 'Q');
+  } else /* driver has no xormod capability, just do nothing */
+    return 0;
 }
 
 /* set gray colormap */
