@@ -1,4 +1,4 @@
-!      $Id: x16af.f90 6883 2006-07-26 14:06:57Z andrewross $
+!      $Id: x16af.f90 8133 2008-01-15 18:06:06Z airwin $
 !      Demonstration of plshade plotting
 !      Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display
 !
@@ -105,7 +105,7 @@
         sh_width = 2
         call plpsty(0)
         call plshade(z(:NX,:NY), ' ', &
-          dble ( -1._plflt), 1.0_plflt, -1.0_plflt, 1.0_plflt, &
+          -1._plflt, 1.0_plflt, -1.0_plflt, 1.0_plflt, &
           shade_min, shade_max, &
           sh_cmap, sh_color, sh_width, &
           min_color, min_width, max_color, max_width )
