@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x02.java,v 1.15 2005/07/03 12:43:39 andrewross Exp $
+// $Id: x02.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -31,7 +31,6 @@ package plplot.examples;
 
 import plplot.core.*;
 
-import java.lang.Math;
 import java.text.*;
 
 class x02 {
@@ -40,13 +39,11 @@ class x02 {
 
     public static void main( String[] args ) 
     {
-        x02 x = new x02( args );
+        new x02( args );
     }
 
     x02( String[] args )
     {
-        int i, j;
-        double vmin, vmax;
 
         pls = new PLStream();
 
