@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x03.java,v 1.15 2005/07/03 12:43:39 andrewross Exp $
+// $Id: x03.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -38,7 +38,7 @@ class x03 {
 
     public static void main( String[] args ) 
     {
-        x03 x = new x03( args );
+        new x03( args );
     }
 
     public x03( String[] args )
