@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x04.java,v 1.14 2005/07/03 12:43:39 andrewross Exp $
+// $Id: x04.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -39,7 +39,7 @@ class x04 {
 
     public static void main( String[] args ) 
     {
-        x04 x = new x04( args );
+        new x04( args );
     }
 
     public x04( String[] args )
