@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x12.java,v 1.13 2005/07/03 12:43:39 andrewross Exp $
+// $Id: x12.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -31,7 +31,6 @@ package plplot.examples;
 
 import plplot.core.*;
 
-import java.lang.Math;
 import java.text.*;
 
 class x12 {
@@ -42,7 +41,7 @@ class x12 {
    
     public static void main( String[] args ) 
     {
-        x12 x = new x12( args );
+        new x12( args );
     }
 
     public x12( String[] args )
