@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x14.java,v 1.14 2005/12/08 08:39:23 andrewross Exp $
+// $Id: x14.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -42,7 +42,7 @@ class x14 {
 
    public static void main( String[] args ) 
      {
-        x14 x = new x14( args );
+        new x14( args );
      }
    
    public x14( String[] args )
@@ -356,7 +356,7 @@ class x14 {
         double[][] z = new double[XPTS][YPTS];
         double[][] w = new double[XPTS][YPTS];
 	
-        double xx, yy, argx, argy, distort;
+        double xx, yy;
 	final int[] mark = {1500};
         final int[] space = {1500};
 	final int[] mark0 = {};
