@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x19.java,v 1.4 2005/04/27 06:43:55 rlaboiss Exp $
+// $Id: x19.java 6653 2006-05-31 09:09:08Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -27,10 +27,6 @@
 
 package plplot.examples;
 
-import plplot.core.*;
-
-import java.lang.Math;
-
 class x19 {
 
     public static void main( String[] args ) 
