@@ -141,8 +141,8 @@ plinit ();
 
 @tr = (2 / ($nx - 1), 0.0, -1.0, 0.0, 2 / ($ny - 1), -1.0);
 
-my $x = ((sequence ($nx) - $nx / 2) / ($nx / 2))->dummy (1, $ny);
-my $y = ((sequence ($ny) - $ny / 2) / ($ny / 2) - 1.0)->dummy (0, $nx);;
+my $x = ((sequence ($nx) - int($nx / 2)) / int($nx / 2))->dummy (1, $ny);
+my $y = ((sequence ($ny) - int($ny / 2)) / int($ny / 2) - 1.0)->dummy (0, $nx);;
 
 my $z = -sin (7 * $x) * cos (7 * $y) + $x ** 2 - $y ** 2;
 my $w = -cos (7 * $x) * sin (7 * $y) + 2 * $x * $y;
@@ -216,7 +216,7 @@ plwind (-1.0, 1.0, -1.0, 1.0);
 plpsty (0);
 
 plshades ($z, -1., 1., -1., 1., $shedge, $fill_width,
-	  $cont_color, $cont_width, 1, 0, \&pltr2, $cgrid2);
+	  $cont_color, $cont_width, 0, 0, \&pltr2, $cgrid2);
 
 plcol0 (1);
 plbox (0.0, 0, 0.0, 0, "bcnst", "bcnstv");
@@ -233,7 +233,7 @@ plwind (-1.0, 1.0, -1.0, 1.0);
 plpsty (0);
 
 plshades ($z, -1., 1., -1., 1., $shedge, $fill_width,
-          2, 3, 1, 0, \&pltr2, $cgrid2);
+          2, 3, 0, 0, \&pltr2, $cgrid2);
 
 plcol0 (1);
 plbox (0.0, 0, 0.0, 0, "bcnst", "bcnstv");
@@ -280,7 +280,7 @@ $z = exp (- $r ** 2) * cos (5 * pi * $r) * cos (5 * $t);
 # Need a new shedge to go along with the new data set
 
 ($zmin, $zmax) =  f2mnmx ($z);
-$shedge = $zmin + ($zmax - $zmin) * sequence ($ns) / $ns;
+$shedge = $zmin + ($zmax - $zmin) * sequence ($ns+1) / $ns;
 
 # Now we can shade the interior region
 
