@@ -117,9 +117,15 @@ EOT
 
   # read Lena image
 
-  my $lena = "../c/lena.pgm";
-  my ($img_f, $width, $height, $num_col) = read_img ($lena)
-    or die "Cannot find image file $lena";
+  my $lena = "lena.pgm";
+  my ($img_f, $width, $height, $num_col) = read_img ($lena);
+  if ($width == 0 && $height == 0) {
+    my $lena = "../lena.pgm";
+    ($img_f, $width, $height, $num_col) = read_img ($lena);
+    if ($width == 0 && $height == 0) {
+      die "Cannot find image file $lena";
+    }
+  }
 
   # set gray colormap
 
@@ -186,8 +192,16 @@ sub gray_cmap {
 
 sub read_img {
   my $fname = shift;
-  my $img = rpnm ($fname);
-  return ($img, $img->dims (), $img->max);
+  if (-r $fname) {
+    my $img = rpnm ($fname);
+    # We want the number of colours from the header, not the maximum 
+    # colour. We can't get this via PDL, so hard code it to 255.
+    #return ($img, $img->dims (), $img->max);
+    return ($img, $img->dims (), 255);
+  }
+  else {
+    return (0,0,0,0);
+  }
 }
 
 # Get selection square interactively
@@ -256,27 +270,27 @@ sub get_clip {
       }
     }
     plxormod (0); # leave xor mod
+    if ($xxe < $xxi) {
+	my $t = $xxi;
+	$xxi = $xxe;
+	$xxe = $t;
+    }
+    
+    if ($yyi < $yye) {
+	my $t = $yyi;
+	$yyi = $yye;
+	$yye = $t;
+    }
+    
+    $$xe = $xxe;
+    $$xi = $xxi;
+    $$ye = $yye;
+    $$yi = $yyi;
+    
+    return ($gin{keysym} eq 'Q');
   }
 
-  if ($xxe < $xxi) {
-    my $t = $xxi;
-    $xxi = $xxe;
-    $xxe = $t;
-  }
-
-  if (yyi < yye) {
-    my $t = $yyi;
-    $yyi = $yye;
-    $yye = $t;
-  }
-
-  $$xe = $xxe;
-  $$xi = $xxi;
-  $$ye = $yye;
-  $$yi = $yyi;
-
-  return ($gin{keysym} eq 'Q');
-
+  return 0;
 }
 
 # save plot
