@@ -9,10 +9,10 @@ demo.py - Demonstrates the simplest use of the plplot canvas widget with gtk.
   Department of Physics and Atmospheric Science,
   Dalhousie University, Halifax, Nova Scotia, Canada, B3H 3J5
 
-  $Author: tomduck $
-  $Revision: 1.8 $
-  $Date: 2005/05/16 17:06:49 $
-  $Name: cvs-tarball_2006-05-29-23-03-54 $
+  $Author: andrewross $
+  $Revision: 7770 $
+  $Date: 2007-08-01 11:32:29 -0400 (Wed, 01 Aug 2007) $
+  $Name$
 
 
 NOTICE
@@ -32,10 +32,9 @@ NOTICE
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
   MA  02110-1301  USA
 """
-import Numeric
 import plplot_python_start
+import plplot_py_demos
 import plplotcanvas
-import plplot
 import gtk
 import sys
 
@@ -55,7 +54,7 @@ def destroy(widget, data=None):
 plplot.plparseopts(sys.argv,plplot.PL_PARSE_FULL);
 
 # The data to plot
-x = Numeric.arange(11)
+x = ${PYTHON_NUMERIC_NAME}.arange(11)
 y = x**2/10.
 
 # Create the canvas and set its size; during the creation process,
