@@ -1,5 +1,4 @@
-from Numeric import *
-from plplot import *
+from plplot_py_demos import *
 
 NPTS = 2047
 
@@ -12,7 +11,7 @@ def main():
     # Fill up data points
 
     delta = 2.0 * pi / NPTS
-    data = sin(delta*arrayrange(NPTS))
+    data = sin(delta*arange(NPTS))
 
     plcol0(1)
     plhist(data, -1.1, 1.1, 44, 0)
@@ -21,6 +20,6 @@ def main():
 	   "#frPLplot Example 5 - Probability function of Oscillator")
 
     # Restore defaults
-    plcol0(1)
+    #plcol0(1)
 
 main()
