@@ -1,5 +1,4 @@
-from Numeric import *
-from plplot import *
+from plplot_py_demos import *
 
 # main
 #
@@ -49,6 +48,6 @@ def main():
 	plmtex("t", 1.5, 0.5, 0.5, "PLplot Example 7 - PLSYM symbols")
 
     # Restore defaults
-    plcol0(1)
+    #plcol0(1)
 
 main()
