@@ -18,8 +18,7 @@
 # along with PLplot; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from Numeric import *
-from plplot import *
+from plplot_py_demos import *
 
 XPTS = 35		# Data points in x
 YPTS = 46		# Data points in y
@@ -51,14 +50,10 @@ def restore_cmap1():
     l = array((0.5, midpt, vertex, vertex, midpt, 0.5))
     # Saturation is complete for default
     s = array((1., 1., 1., 1., 1., 1.))
-    # Integer flag array is zero (no interpolation along far-side of colour
-    # figure.)
-    # Drop array, see plplot-devel discussion on 2004-10-27
-    rev = array((0, 0, 0, 0, 0, 0))
     # Default number of cmap1 colours
     plscmap1n(128)
     # Interpolate between control points to set up default cmap1.
-    plscmap1l(0, i, h, l, s, rev)
+    plscmap1l(0, i, h, l, s)
 
 # Routine for defining a specific color map 1 in HLS space.
 # if gray is true, use basic grayscale variation from half-dark to light.
@@ -80,14 +75,10 @@ def cmap1_init(gray):
 	l = array((0.6, 0.6))
 	s = array((0.8, 0.8))
 
-    # Integer flag array is zero (no interpolation along far-side of colour
-    # figure.)
-    # Drop array, see plplot-devel discussion on 2004-10-27
-    rev = array((0, 0))
     # number of cmap1 colours is 256 in this case.
     plscmap1n(256)
     # Interpolate between control points to set up cmap1.
-    plscmap1l(0, i, h, l, s, rev)
+    plscmap1l(0, i, h, l, s)
 # main
 #
 # Does a series of 3-d plots for a given data set, with different
@@ -96,8 +87,8 @@ def cmap1_init(gray):
 def main():
 
     rosen = 1
-    x = (arrayrange(XPTS) - (XPTS / 2)) / float(XPTS / 2)
-    y = (arrayrange(YPTS) - (YPTS / 2)) / float(YPTS / 2)
+    x = (arange(XPTS) - (XPTS / 2)) / float(XPTS / 2)
+    y = (arange(YPTS) - (YPTS / 2)) / float(YPTS / 2)
     if rosen == 1:
 	x = 1.5*x
 	y = 0.5 + y
@@ -155,7 +146,7 @@ def main():
 		plsurf3d(x, y, z, MAG_COLOR | SURF_CONT | BASE_CONT, clevel)
 
     # Restore defaults
-    plcol0(1)
+    #plcol0(1)
     restore_cmap1()
 
 main()
