@@ -1,5 +1,5 @@
-/* $Id: font07.c,v 1.1 1992/05/20 21:33:27 furnish Exp $
-   $Log: font07.c,v $
+/* $Id: font07.c 2 1992-05-20 21:36:02Z furnish $
+   $Log$
    Revision 1.1  1992/05/20 21:33:27  furnish
    Initial checkin of the whole PLPLOT project.
 
