@@ -1,4 +1,4 @@
-/* $Id: drivers.h,v 1.54 2006/04/17 11:54:12 andrewross Exp $
+/* $Id: drivers.h 7724 2007-06-20 07:02:53Z andrewross $
 
 	Contains all prototypes for driver functions.
 
@@ -87,6 +87,14 @@ void plD_dispatch_init_ntk	( PLDispatchTable *pdt );
 void plD_dispatch_init_mem	( PLDispatchTable *pdt );
 void plD_dispatch_init_wingcc	( PLDispatchTable *pdt );
 void plD_dispatch_init_wxwidgets	( PLDispatchTable *pdt );
+void plD_dispatch_init_svg	( PLDispatchTable *pdt );
+void plD_dispatch_init_pdf	( PLDispatchTable *pdt );
+void plD_dispatch_init_xcairo  ( PLDispatchTable *pdt );
+void plD_dispatch_init_pdfcairo  ( PLDispatchTable *pdt );
+void plD_dispatch_init_pscairo  ( PLDispatchTable *pdt );
+void plD_dispatch_init_svgcairo  ( PLDispatchTable *pdt );
+void plD_dispatch_init_pngcairo  ( PLDispatchTable *pdt );
+void plD_dispatch_init_memcairo  ( PLDispatchTable *pdt );
 
 /* Prototypes for plot buffer calls. */
 
@@ -98,6 +106,8 @@ void plbuf_bop		(PLStream *);
 void plbuf_tidy		(PLStream *);
 void plbuf_state	(PLStream *, PLINT);
 void plbuf_esc		(PLStream *, PLINT, void *);
+void * plbuf_save	(PLStream *, void *);
+void * plbuf_switch	(PLStream *, void *);
 
 void plRemakePlot	(PLStream *);
 
