@@ -1,4 +1,4 @@
-/* $Id: plplotP.h,v 1.94 2006/04/06 23:05:17 andrewross Exp $
+/* $Id: plplotP.h 8082 2007-12-12 15:44:17Z andrewross $
 
     Internal (private) macros and prototypes for the PLplot package.  This
     header file must be included before all others, including system header
@@ -12,6 +12,7 @@
     Copyright (C) 2004  Joao Cardoso
     Copyright (C) 2004  Andrew Roach
     Copyright (C) 2006  Andrew Ross
+    Copyright (C) 2006  Hazen Babcock
 
 
     This file is part of PLplot.
@@ -111,6 +112,7 @@ typedef char * caddr_t;
 #include <string.h>
 #include <limits.h>
 #include <float.h>
+#include <time.h>
 #if defined(PLPLOT_WINTK)
 #elif defined(WIN32) &! defined (__GNUC__)
 /* Redefine tmpfile()! (AM)*/
@@ -187,7 +189,8 @@ typedef char * caddr_t;
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern PLStream	*plsc;
+/* extern PLStream PLDLLIMPORT *plsc; */
+extern PLDLLIMPEXP_DATA(PLStream *)plsc;
 #ifdef __cplusplus
 }
 #endif
@@ -401,7 +404,13 @@ extern "C" {
 /* Determines interval between numeric labels */
 
 void
-pldtik(PLFLT vmin, PLFLT vmax, PLFLT *tick, PLINT *nsubt);
+pldtik(PLFLT vmin, PLFLT vmax, PLFLT *tick, PLINT *nsubt, PLBOOL ld);
+
+/* Determine factor to convert date / time in seconds to more natural
+ * units */
+
+void
+pldtfac(PLFLT vmin, PLFLT vmax, PLFLT *factor, PLFLT *tstart);
 
 /* Determines precision of box labels */
 
@@ -443,8 +452,8 @@ plfill_soft(short *x, short *y, PLINT npts);
 /* In case of an abort this routine is called.  It just prints out an */
 /* error message and tries to clean up as much as possible. */
 
-void
-plexit(char *errormsg);
+PLDLLIMPEXP void
+plexit(const char *errormsg);
 
 /* Just a front-end to exit().  */
 
@@ -453,13 +462,13 @@ pl_exit(void);
 
 /* A handy way to issue warnings, if need be. */
 
-void
-plwarn(char *errormsg);
+PLDLLIMPEXP void
+plwarn(const char *errormsg);
 
 /* Same as plwarn(), but appends ", aborting plot" to the error message */
 
-void
-plabort(char *errormsg);
+PLDLLIMPEXP void
+plabort(const char *errormsg);
 
 /* Loads either the standard or extended font. */
 
@@ -473,7 +482,7 @@ plfontrel(void);
 
 /* A replacement for strdup(), which isn't portable. */
 
-char *
+char PLDLLIMPEXP *
 plstrdup(const char *src);
 
 /* Bin up cmap 1 space and assign colors to make inverse mapping easy. */
@@ -541,10 +550,10 @@ typedef struct {
  */
 
 typedef struct {
-  char *opt;     /* a string with the name of the option */
+  const char *opt;     /* a string with the name of the option */
   PLINT type;    /* the type of the variable to be set, see bellow the available types */
   void *var_ptr; /* a pointer to the variable to be set */
-  char *hlp_msg; /* help message of the option */
+  const char *hlp_msg; /* help message of the option */
 } DrvOpt;
 
   /* the available variable types, DrvOpt.type, for driver specific options */
@@ -619,17 +628,17 @@ plP_sclp(PLINT ixmin, PLINT ixmax, PLINT iymin, PLINT iymax);
 
 /* Get physical device limits in physical coordinates */
 
-void
+PLDLLIMPEXP void
 plP_gphy(PLINT *p_ixmin, PLINT *p_ixmax, PLINT *p_iymin, PLINT *p_iymax);
 
 /* Get number of subpages on physical device and current subpage */
 
-void
+PLDLLIMPEXP void
 plP_gsub(PLINT *p_nx, PLINT *p_ny, PLINT *p_cs);
 
 /* Set number of subpages on physical device and current subpage */
 
-void
+PLDLLIMPEXP void
 plP_ssub(PLINT nx, PLINT ny, PLINT cs);
 
 /* Set up plot parameters according to the number of subpages. */
@@ -639,7 +648,7 @@ plP_subpInit(void);
 
 /* Get number of pixels to a millimeter */
 
-void
+PLDLLIMPEXP void
 plP_gpixmm(PLFLT *p_x, PLFLT *p_y);
 
 /* All the drivers call this to set physical pixels/mm. */
@@ -689,7 +698,7 @@ plP_setphy(PLINT xmin, PLINT xmax, PLINT ymin, PLINT ymax);
 
 /* Set up the subpage boundaries according to the current subpage selected */
 
-void
+PLDLLIMPEXP void
 plP_setsub(void);
 
 /* Get the floating point precision (in number of places) in numeric labels. */
@@ -697,6 +706,11 @@ plP_setsub(void);
 void
 plP_gprec(PLINT *p_setp, PLINT *p_prec);
 
+/* Get the date / time format for numeric labels */
+
+const char *
+plP_gtimefmt();
+
 /* Computes the length of a string in mm, including escape sequences. */
 
 PLFLT
@@ -714,7 +728,7 @@ plP_strpos(const char *str, int chr);
 
 /* Searches string str for character chr (case insensitive). */
 
-PLINT
+PLBOOL
 plP_stsearch(const char *str, int chr);
 
 	/* Conversion functions */
@@ -829,7 +843,13 @@ plP_w3wcx(PLFLT x, PLFLT y, PLFLT z);
 PLFLT
 plP_w3wcy(PLFLT x, PLFLT y, PLFLT z);
 
-	/* Driver calls */
+/* Returns the rotation and shear angle from a plplot transformation matrix */
+
+void
+plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear);
+
+
+    /* Driver calls */
 
 /* Initialize device. */
 
@@ -858,12 +878,12 @@ plP_image(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny, PLFLT xmin,
 
 /* End of page */
 
-void
+PLDLLIMPEXP void
 plP_eop(void);
 
 /* End of page */
 
-void
+PLDLLIMPEXP void
 plP_bop(void);
 
 /* Tidy up device (flush buffers, close file, etc.) */
@@ -873,7 +893,7 @@ plP_tidy(void);
 
 /* Change state. */
 
-void
+PLDLLIMPEXP void
 plP_state(PLINT op);
 
 /* Escape function, for driver-specific commands. */
@@ -889,7 +909,7 @@ plP_swin(PLWindow *plwin);
 /* Return file pointer to lib file. */
 
 FILE *
-plLibOpen(char *fn);
+plLibOpen(const char *fn);
 
 /* Does required startup initialization of library.  */
 
@@ -932,7 +952,7 @@ RestoreWrite2BufferPixmap(void);
 void
 grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny);
 
-int
+int PLDLLIMPEXP
 plInBuildTree();
 
 void
@@ -950,7 +970,8 @@ typedef struct {
  * and vector transformations.
  * This is not currently intended to be called direct by the user
  */
-void plfvect(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
+void PLDLLIMPEXP
+plfvect(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
 		PLPointer f2evalv_data, PLPointer f2evalc_data,
 		PLINT nx, PLINT ny, PLFLT scale,
 		void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
@@ -983,6 +1004,32 @@ plP_FreeDrvOpts();
 int
 ucs4_to_utf8(PLUNICODE unichar, char *ptr);
 
+/*
+ * Wrapper functions for the system IO routines fread, fwrite
+ */
+
+/* wraps fwrite */
+
+void
+plio_fwrite(void *, size_t, size_t, FILE *);
+
+/* wraps fread */
+
+void
+plio_fread(void *, size_t, size_t, FILE *);
+
+/* wraps fgets */
+
+void
+plio_fgets(char *, int, FILE *);
+   
+/* get drivers directory */
+   
+#ifdef ENABLE_DYNDRIVERS
+char*
+plGetDrvDir (void);
+#endif
+
 #ifdef __cplusplus
 }
 #endif
