@@ -1,9 +1,10 @@
-/* $Id: plstrm.h,v 1.32 2004/06/14 21:51:57 rlaboiss Exp $
+/* $Id: plstrm.h 8057 2007-12-03 17:08:51Z andrewross $
  *
  *	Contains declarations for PLStream and PLDev structs.
  *	Also prototypes for stream & device utility functions.
 
     Copyright (C) 2004  Andrew Ross
+    Copyright (C) 2004  Andrew Roach
 
     This file is part of PLplot.
 
@@ -19,7 +20,7 @@
 
     You should have received a copy of the GNU Library General Public License
     along with PLplot; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #include "pdf.h"
@@ -28,6 +29,7 @@
 #define __PLSTRM_H__
 
 #include "disptab.h"
+#include "pldll.h"
 
 /*--------------------------------------------------------------------------*\
  * Define the PLDev data structure.
@@ -152,6 +154,8 @@ typedef struct {
  * plbuf_write	PLINT	Set if driver needs to use the plot buffer
  * dev_fill0	PLINT	Set if driver can do solid area fills
  * dev_text	PLINT	Set if driver want to do it's only text drawing
+ * dev_unicode	PLINT	Set if driver wants unicode
+ * dev_hrshsym	PLINT	Set for Hershey symbols to be used
  * dev_fill1	PLINT	Set if driver can do pattern area fills
  * dev_dash     PLINT   Set if driver can do dashed lines
  * dev_di	PLINT	Set if driver wants to handle DI commands
@@ -251,6 +255,8 @@ typedef struct {
  * db		int	Set if you want to double buffer output
  *			(only pixmap is drawn to directly; it is blitted
  *			to output window on EOP or an Expose)
+ * ext_resize_draw int  Set if you want to control the redraw caused by a
+ *                      window resize by an external agent.
  ***************************************************************************
  *
  * These are for support of the TK driver.
@@ -271,7 +277,16 @@ typedef struct {
  *
  * Variables for use by the plot buffer
  *
+ * For BUFFERED_FILE
  * plbufFile	FILE	Plot buffer file pointer
+ *
+ * For Memory Buffer (default)
+ * plbuf_buffer_grow	size_t		Memory buffer growth step
+ * plbuf_buffer_size	size_t		Current size of memory buffer
+ * plbuf_buffer			void *		Pointer to memory buffer
+ * plbuf_top			size_t		Offset to the top of used area/start of free area
+ * plbuf_readpos		size_t		Offset to current position being read
+ *
  * plbufOwner	int	Typically set; only zero if current stream is cloned.
  *
  ***************************************************************************
@@ -381,6 +396,7 @@ typedef struct {
  * precis	User-specified precision
  * xdigmax..	Allowed #digits in axes labels
  * xdigits..	Actual field widths (returned)
+ * timefmt      Format string (for strftime) 
  *
  ***************************************************************************
  *
@@ -440,7 +456,28 @@ typedef struct {
  *
  * cfont           Current font number, replaces global 'font' in plsym.c
  *                 This can be latter extended for font shape, series, family and size
+ * fci             FCI (font characterization integer)
+ * An FCI is sometimes inserted in the middle of a stream of
+ * unicode glyph indices.  Thus to distinguish it from those, the FCI is marked
+ * by 0x8 in the most significant 4 bits.  The remaining 7 hex digits
+ * stored in the 32-bit integer characterize 7 different font attributes.
+ * The font attributes are interpreted as follows:
+ * hexdigit =>                    0        1          2        3       4        5
+ * hexpower   Font attribute               Possible attribute values
+ *    0       font-family     sans-serif  serif    monospace  script  symbol |fantasy
+ *    1       font-style        upright   italic    oblique |
+ *    2       font-weight       medium     bold  |   bolder    light  lighter
+ *    3       font-variant      normal | small caps
  *
+ * Everything to the right of the vertical bars is not implemented and is
+ * subject to change.  The four font attributes (font-family, font-style,
+ * font-weight, and font-variant are stored in the FCI in the order of
+ * hexpower, the left shift that is applied to the hex digit to place the
+ * hexdigit in the FCI.  The hexpower = 3 position is essentially undefined
+ * since there is currently only one hexdigit (0) defined, and similarly
+ * for hexpower = 4-6 so there is room for expansion of this scheme into more
+ * font attributes if required.  (hexpower = 7 is reserved for the 0x8 marker
+ * of the FCI.)
 \*--------------------------------------------------------------------------*/
 
 #define PL_MAX_CMAP1CP 256
@@ -450,7 +487,7 @@ typedef struct {
 /* Misc control information */
 
     PLINT ipls, level, verbose, debug, initialized, dev_initialized;
-    char *program;
+    const char *program;
 
 /* Colormaps */
 
@@ -545,7 +582,7 @@ typedef struct {
 
     char *geometry;
     long window_id;
-    int  nopixmap, db;
+    int  nopixmap, db, ext_resize_draw;
 
 /* Stuff used by TK, DP drivers */
 
@@ -557,7 +594,15 @@ typedef struct {
 
 /* Plot buffer settings */
 
+#ifdef BUFFERED_FILE
     FILE *plbufFile;
+#else
+    size_t plbuf_buffer_grow;
+    size_t plbuf_buffer_size;	
+    void *plbuf_buffer;
+    size_t plbuf_top;
+    size_t plbuf_readpos;
+#endif
     int  plbufOwner;
 
 /* Driver interface (DI) */
@@ -600,6 +645,7 @@ typedef struct {
     PLINT setpre, precis;
     PLINT xdigmax, ydigmax, zdigmax;
     PLINT xdigits, ydigits, zdigits;
+    char *timefmt;
 
 /* Variables governing physical coordinate system */
 
@@ -639,12 +685,33 @@ typedef struct {
 
   PLINT dev_compression;
   PLINT cfont;
-  
+
   void *FT;
 
 /* Stuff used by the Tkwin driver for Plframe */
   struct PlPlotter *plPlotterPtr;
 
+
+/* Unicode section */
+
+  PLINT dev_unicode;
+
+  PLUNICODE fci;
+
+  PLINT dev_hrshsym;
+
+/* Used to keep a hold of a temporary copy of the original character height
+ * which I overload as a quick hack to fix up a bug in freetype an plsym()
+ */
+
+  PLFLT original_chrdef,original_chrht;
+
+  /*
+   * Pointer to postscript document class used by psttf
+   */
+  void *psdoc;
+
+
 } PLStream;
 
 /*--------------------------------------------------------------------------*\
@@ -657,7 +724,7 @@ extern "C" {
 
 /* Get the current stream pointer */
 
-void
+void PLDLLIMPEXP
 plgpls(PLStream **p_pls);
 
 /* Initializes device cmap 1 entry by interpolation from pls->cmap1 entries */
@@ -694,7 +761,7 @@ plGetFam(PLStream *pls);
 
 void
 plRotPhy(PLINT orient, PLINT xmin, PLINT ymin, PLINT xmax, PLINT ymax,
-	 int *px, int *py);
+	 PLINT *px, PLINT *py);
 
 /* Allocates a standard PLDev structure for device-specific data */
 
