@@ -1,4 +1,4 @@
-/* $Id: pdfutils.c 7349 2007-02-04 05:45:38Z aroach $
+/* $Id: pdfutils.c 8033 2007-11-23 15:28:09Z andrewross $
 
     pdf_utils.c
 
@@ -61,7 +61,7 @@ pdf_set(char *option, int value)
 \*--------------------------------------------------------------------------*/
 
 PDFstrm *
-pdf_fopen(char *filename, char *mode)
+pdf_fopen(const char *filename, const char *mode)
 {
     PDFstrm *pdfs;
 
