@@ -1,4 +1,4 @@
-/* $Id: plcore.c 7980 2007-10-27 06:29:52Z airwin $
+/* $Id: plcore.c 8208 2008-02-01 21:46:52Z smekal $
 
 	Central dispatch facility for PLplot.
 	Also contains the PLplot main data structures, external access
@@ -1700,6 +1700,9 @@ c_plinit(void)
     if (plsc->zdigmax == 0)
 	plsc->zdigmax = 3;
 
+    if (plsc->timefmt == NULL) 
+        pltimefmt("%c");
+
 /* Switch to graphics mode and set color and arrow style*/
 
     plgra();
@@ -1830,6 +1833,8 @@ c_plend1(void)
     if (plsc->arrow_x) free_mem(plsc->arrow_x);
     if (plsc->arrow_y) free_mem(plsc->arrow_y);
 
+    if (plsc->timefmt) free_mem(plsc->timefmt);
+
 /* Free malloc'ed stream if not in initial stream, else clear it out */
 
     if (ipls > 0) {
@@ -1999,11 +2004,13 @@ c_plcpstrm(PLINT iplsr, PLINT flags)
 #ifdef BUFFERED_FILE
     plsc->plbufFile = plsr->plbufFile;
 #else
-    plsc->plbuf_buffer = plsr->plbuf_buffer;
     plsc->plbuf_buffer_grow = plsr->plbuf_buffer_grow;
     plsc->plbuf_buffer_size = plsr->plbuf_buffer_size;
     plsc->plbuf_top = plsr->plbuf_top;
     plsc->plbuf_readpos = plsr->plbuf_readpos;
+    if ((plsc->plbuf_buffer = malloc(plsc->plbuf_buffer_size)) == NULL)
+        plexit("plcpstrm: Error allocating plot buffer.");
+    memcpy( plsc->plbuf_buffer, plsr->plbuf_buffer, plsr->plbuf_top );
 #endif
 
 /* Driver interface */
@@ -2110,6 +2117,7 @@ int PLDLLIMPEXP plInBuildTree()
 
   if (inited == 0) {
     char currdir[256];
+    char builddir[256];
 
 /* AM: getcwd has a somewhat strange status on Windows, its proper
    name is _getcwd, this is a problem in the case of DLLs, like with
@@ -2121,8 +2129,22 @@ int PLDLLIMPEXP plInBuildTree()
 
     if (getcwd(currdir, 256) == NULL) {
       pldebug("plInBuildTree():", "Not enough buffer space");
-    } else if (strncmp(BUILD_DIR, currdir, strlen(BUILD_DIR)) == 0)
-      inBuildTree = 1;
+    } else {
+      /* The chdir / getcwd call is to ensure we get the physical
+       * path without any symlinks */
+      /* Ignore error in chdir - build tree may not exist */
+      if (chdir(BUILD_DIR) == 0) {
+         if (getcwd(builddir, 256) == NULL) {
+           pldebug("plInBuildTree():", "Not enough buffer space");
+         }
+         else {
+           if (strncmp(builddir, currdir, strlen(builddir)) == 0) {
+             inBuildTree = 1;
+           }
+         }
+         chdir(currdir);
+      }
+    }
     inited = 1;
   }
   return inBuildTree;
@@ -2608,7 +2630,7 @@ c_plreplot(void)
 \*--------------------------------------------------------------------------*/
 
 void
-plgFileDevs(char ***p_menustr, char ***p_devname, int *p_ndev)
+plgFileDevs(const char ***p_menustr, const char ***p_devname, int *p_ndev)
 {
     plgdevlst(*p_menustr, *p_devname, p_ndev, 0);
 }
@@ -2620,13 +2642,13 @@ plgFileDevs(char ***p_menustr, char ***p_devname, int *p_ndev)
 \*--------------------------------------------------------------------------*/
 
 void
-plgDevs(char ***p_menustr, char ***p_devname, int *p_ndev)
+plgDevs(const char ***p_menustr, const char ***p_devname, int *p_ndev)
 {
     plgdevlst(*p_menustr, *p_devname, p_ndev, -1);
 }
 
 static void
-plgdevlst(char **p_menustr, char **p_devname, int *p_ndev, int type)
+plgdevlst(const char **p_menustr, const char **p_devname, int *p_ndev, int type)
 {
     int i, j;
 
@@ -2917,6 +2939,23 @@ plP_gprec(PLINT *p_setp, PLINT *p_prec)
     *p_prec = plsc->precis;
 }
 
+void
+c_pltimefmt(const char *fmt)
+{
+    if (plsc->timefmt)
+      free_mem(plsc->timefmt);
+
+    plsc->timefmt = (char *) malloc((size_t) (strlen(fmt)+1));
+    strcpy(plsc->timefmt, fmt);
+
+}
+
+const char *
+plP_gtimefmt()
+{
+    return (const char *) plsc->timefmt;
+}
+
 /*
  * Set the escape character for text strings.
  * From C you can pass as a character, from Fortran it needs to be the decimal
