@@ -1,4 +1,4 @@
-/* $Id: plctrl.c 7815 2007-08-20 23:15:48Z airwin $
+/* $Id: plctrl.c 8156 2008-01-22 13:57:53Z andrewross $
 
 	Misc. control routines, like begin, end, exit, change graphics/text
 	mode, change color.  Includes some spillage from plcore.c.  If you
@@ -6,6 +6,7 @@
 
    Copyright (C) 2004  Joao Cardoso
    Copyright (C) 2004  Rafael Laboissiere
+   Copyright (C) 2008  Hazen Babcock
 
    This file is part of PLplot.
 
@@ -55,16 +56,16 @@
 char PLDLLIMPEXP * plplotLibDir = 0;
 
 static void
-color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, char *name );
+color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, PLFLT a, char *name );
 
 static void
 strcat_delim(char *dirspec);
 
 static int
-(*exit_handler) (char *errormsg);
+(*exit_handler) (const char *errormsg);
 
 void
-(*abort_handler) (char *errormsg);
+(*abort_handler) (const char *errormsg);
 
 static void
 plcmap0_def(int imin, int imax);
@@ -126,6 +127,7 @@ c_plcol0(PLINT icol0)
     plsc->curcolor.r = plsc->cmap0[icol0].r;
     plsc->curcolor.g = plsc->cmap0[icol0].g;
     plsc->curcolor.b = plsc->cmap0[icol0].b;
+    plsc->curcolor.a = plsc->cmap0[icol0].a;
 
     plsc->curcmap = 0;
     plP_state(PLSTATE_COLOR0);
@@ -160,6 +162,7 @@ c_plcol1(PLFLT col1)
     plsc->curcolor.r = plsc->cmap1[plsc->icol1].r;
     plsc->curcolor.g = plsc->cmap1[plsc->icol1].g;
     plsc->curcolor.b = plsc->cmap1[plsc->icol1].b;
+    plsc->curcolor.a = plsc->cmap1[plsc->icol1].a;
 
     plsc->curcmap = 1;
     plP_state(PLSTATE_COLOR1);
@@ -177,6 +180,18 @@ c_plscolbg(PLINT r, PLINT g, PLINT b)
     plscol0(0, r, g, b);
 }
 
+/*--------------------------------------------------------------------------*\
+ * plscolbga()
+ *
+ * Set the background color (cmap0[0]) by 8 bit RGB value and alpha value
+\*--------------------------------------------------------------------------*/
+
+void
+c_plscolbga(PLINT r, PLINT g, PLINT b, PLFLT a)
+{
+  plscol0a(0, r, g, b, a);
+}
+
 /*--------------------------------------------------------------------------*\
  * plgcolbg()
  *
@@ -189,6 +204,18 @@ c_plgcolbg(PLINT *r, PLINT *g, PLINT *b)
     plgcol0(0, r, g, b);
 }
 
+/*--------------------------------------------------------------------------*\
+ * plgcolbga()
+ *
+ * Returns the background color (cmap0[0]) by 8 bit RGB value and alpha value
+\*--------------------------------------------------------------------------*/
+
+void
+c_plgcolbga(PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+  plgcol0a(0, r, g, b, a);
+}
+
 /*--------------------------------------------------------------------------*\
  * plscol0()
  *
@@ -201,7 +228,6 @@ c_plscol0(PLINT icol0, PLINT r, PLINT g, PLINT b)
 {
     if (plsc->cmap0 == NULL)
 	plscmap0n(0);
-
     if (icol0 < 0 || icol0 >= plsc->ncol0) {
 	char buffer[256];
 	sprintf(buffer, "plscol0: Illegal color table value: %d", (int) icol0);
@@ -216,9 +242,39 @@ c_plscol0(PLINT icol0, PLINT r, PLINT g, PLINT b)
 	return;
     }
 
+    plscol0a(icol0, r, g, b, 1.0);
+}
+
+/*--------------------------------------------------------------------------*\
+ * plscol0a()
+ *
+ * Set a given color from color map 0 by 8 bit RGB value and alpha value.
+ * Does not result in any additional cells to be allocated.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plscol0a(PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT a)
+{
+    if (plsc->cmap0 == NULL)
+	plscmap0n(0);
+    if (icol0 < 0 || icol0 >= plsc->ncol0) {
+	char buffer[256];
+	sprintf(buffer, "plscol0a: Illegal color table value: %d", (int) icol0);
+	plabort(buffer);
+	return;
+    }
+    if ((r < 0 || r > 255) || (g < 0 || g > 255) || (b < 0 || b > 255) || (a < 0 || a > 1.0)) {
+	char buffer[256];
+	sprintf(buffer, "plscol0a: Invalid RGB color: %d, %d, %d, %f",
+		(int) r, (int) g, (int) b, (double) a);
+	plabort(buffer);
+	return;
+    }
+
     plsc->cmap0[icol0].r = r;
     plsc->cmap0[icol0].g = g;
     plsc->cmap0[icol0].b = b;
+    plsc->cmap0[icol0].a = a;
 
     if (plsc->level > 0)
 	plP_state(PLSTATE_CMAP0);
@@ -255,6 +311,39 @@ c_plgcol0(PLINT icol0, PLINT *r, PLINT *g, PLINT *b)
     return;
 }
 
+/*--------------------------------------------------------------------------*\
+ * plgcol0a()
+ *
+ * Returns 8 bit RGB values for given color from color map 0 and alpha value
+ * Values are negative if an invalid color id is given
+\*--------------------------------------------------------------------------*/
+
+void
+c_plgcol0a(PLINT icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
+{
+    if (plsc->cmap0 == NULL)
+	plscmap0n(0);
+
+    *r = -1;
+    *g = -1;
+    *b = -1;
+    *a = -1.0;
+
+    if (icol0 < 0 || icol0 > plsc->ncol0) {
+	char buffer[256];
+	sprintf(buffer, "plgcol0: Invalid color index: %d", (int) icol0);
+	plabort(buffer);
+	return;
+    }
+
+    *r = plsc->cmap0[icol0].r;
+    *g = plsc->cmap0[icol0].g;
+    *b = plsc->cmap0[icol0].b;
+    *a = plsc->cmap0[icol0].a;
+
+    return;
+}
+
 /*--------------------------------------------------------------------------*\
  * plscmap0()
  *
@@ -290,6 +379,43 @@ c_plscmap0(PLINT *r, PLINT *g, PLINT *b, PLINT ncol0)
 	plP_state(PLSTATE_CMAP0);
 }
 
+/*--------------------------------------------------------------------------*\
+ * plscmap0a()
+ *
+ * Set color map 0 colors by 8 bit RGB and alpha value.  This sets the 
+ * entire color map -- only as many colors as specified will be allocated.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plscmap0a(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol0)
+{
+    int i;
+
+    plscmap0n(ncol0);
+
+    for (i = 0; i < plsc->ncol0; i++) {
+	if ((r[i] < 0 || r[i] > 255) ||
+	    (g[i] < 0 || g[i] > 255) ||
+	    (b[i] < 0 || b[i] > 255) ||
+	    (a[i] < 0.0 || a[i] > 1.0)) {
+
+	    char buffer[256];
+	    sprintf(buffer, "plscmap0a: Invalid RGB color: %d, %d, %d, %f",
+		    (int) r[i], (int) g[i], (int) b[i], (double) a[i]);
+	    plabort(buffer);
+	    return;
+	}
+
+	plsc->cmap0[i].r = r[i];
+	plsc->cmap0[i].g = g[i];
+	plsc->cmap0[i].b = b[i];
+	plsc->cmap0[i].a = a[i];
+    }
+
+    if (plsc->level > 0)
+	plP_state(PLSTATE_CMAP0);
+}
+
 /*--------------------------------------------------------------------------*\
  * plscmap1()
  *
@@ -318,6 +444,43 @@ c_plscmap1(PLINT *r, PLINT *g, PLINT *b, PLINT ncol1)
 	plsc->cmap1[i].r = r[i];
 	plsc->cmap1[i].g = g[i];
 	plsc->cmap1[i].b = b[i];
+	plsc->cmap1[i].a = 1.0;
+    }
+
+    if (plsc->level > 0)
+	plP_state(PLSTATE_CMAP1);
+}
+
+/*--------------------------------------------------------------------------*\
+ * plscmap1a()
+ *
+ * Set color map 1 colors by 8 bit RGB and alpha values
+ * This also sets the number of colors.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plscmap1a(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol1)
+{
+    int i;
+
+    plscmap1n(ncol1);
+
+    for (i = 0; i < plsc->ncol1; i++) {
+	if ((r[i] < 0 || r[i] > 255) ||
+	    (g[i] < 0 || g[i] > 255) ||
+	    (b[i] < 0 || b[i] > 255) ||
+	    (a[i] < 0.0 || a[i] > 1.0)) {
+
+	    char buffer[256];
+	    sprintf(buffer, "plscmap1a: Invalid RGB color: %d, %d, %d, %f",
+		    (int) r[i], (int) g[i], (int) b[i], (double) a[i]);
+	    plabort(buffer);
+	    return;
+	}
+	plsc->cmap1[i].r = r[i];
+	plsc->cmap1[i].g = g[i];
+	plsc->cmap1[i].b = b[i];
+	plsc->cmap1[i].a = a[i];
     }
 
     if (plsc->level > 0)
@@ -424,6 +587,76 @@ c_plscmap1l(PLINT itype, PLINT npts, PLFLT *pos,
 	plsc->cmap1cp[n].l = l;
 	plsc->cmap1cp[n].s = s;
 	plsc->cmap1cp[n].p = pos[n];
+	plsc->cmap1cp[n].a = 1.0;
+
+	if (rev == NULL)
+	    plsc->cmap1cp[n].rev = 0;
+	else
+	    plsc->cmap1cp[n].rev = rev[n];
+    }
+
+/* Calculate and set color map */
+
+    plcmap1_calc();
+}
+
+/*--------------------------------------------------------------------------*\
+ * plscmap1la()
+ *
+ * This is the same as plscmap1l, but also allows alpha value interpolation.
+ *
+ \*-------------------------------------------------------------------------*/
+
+void
+c_plscmap1la(PLINT itype, PLINT npts, PLFLT *pos,
+	     PLFLT *coord1, PLFLT *coord2, PLFLT *coord3, PLFLT *a, PLINT *rev)
+{
+    int n;
+    PLFLT h, l, s, r, g, b;
+
+    if (npts < 2) {
+	plabort("plscmap1la: Must specify at least two control points");
+	return;
+    }
+
+    if ( (pos[0] != 0) || (pos[npts-1] != 1)) {
+	plabort("plscmap1la: First, last control points must lie on boundary");
+	return;
+    }
+
+    if ( npts > PL_MAX_CMAP1CP ) {
+	plabort("plscmap1la: exceeded maximum number of control points");
+	return;
+    }
+
+/* Allocate if not done yet */
+
+    if (plsc->cmap1 == NULL)
+	plscmap1n(0);
+
+/* Save control points */
+
+    plsc->ncp1 = npts;
+
+    for (n = 0; n < npts; n++) {
+
+	if (itype == 0) {
+	    h = coord1[n];
+	    l = coord2[n];
+	    s = coord3[n];
+	}
+	else {
+	    r = coord1[n];
+	    g = coord2[n];
+	    b = coord3[n];
+	    c_plrgbhls(r, g, b, &h, &l, &s);
+	}
+
+	plsc->cmap1cp[n].h = h;
+	plsc->cmap1cp[n].l = l;
+	plsc->cmap1cp[n].s = s;
+	plsc->cmap1cp[n].p = pos[n];
+	plsc->cmap1cp[n].a = a[n];
 
 	if (rev == NULL)
 	    plsc->cmap1cp[n].rev = 0;
@@ -447,8 +680,8 @@ void
 plcmap1_calc(void)
 {
     int i, n;
-    PLFLT delta, dp, dh, dl, ds;
-    PLFLT h, l, s, p, r, g, b;
+    PLFLT delta, dp, dh, dl, ds, da;
+    PLFLT h, l, s, p, r, g, b, a;
 
 /* Loop over all control point pairs */
 
@@ -463,6 +696,7 @@ plcmap1_calc(void)
 	dh = plsc->cmap1cp[n+1].h - plsc->cmap1cp[n].h;
 	dl = plsc->cmap1cp[n+1].l - plsc->cmap1cp[n].l;
 	ds = plsc->cmap1cp[n+1].s - plsc->cmap1cp[n].s;
+	da = plsc->cmap1cp[n+1].a - plsc->cmap1cp[n].a;
 
     /* Adjust dh if we are to go around "the back side" */
 
@@ -487,6 +721,7 @@ plcmap1_calc(void)
 	    h = plsc->cmap1cp[n].h + dh * delta;
 	    l = plsc->cmap1cp[n].l + dl * delta;
 	    s = plsc->cmap1cp[n].s + ds * delta;
+	    a = plsc->cmap1cp[n].a + da * delta;
 
 	    while (h >= 360.)
 		h -= 360.;
@@ -499,6 +734,7 @@ plcmap1_calc(void)
 	    plsc->cmap1[i].r = MAX(0, MIN(255, (int) (256. * r)));
 	    plsc->cmap1[i].g = MAX(0, MIN(255, (int) (256. * g)));
 	    plsc->cmap1[i].b = MAX(0, MIN(255, (int) (256. * b)));
+	    plsc->cmap1[i].a = a;
 	}
     }
 
@@ -628,11 +864,12 @@ c_plscmap1n(PLINT ncol1)
 \*--------------------------------------------------------------------------*/
 
 static void
-color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, char *name )
+color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, PLFLT a, char *name )
 {
     plsc->cmap0[i].r = r;
     plsc->cmap0[i].g = g;
     plsc->cmap0[i].b = b;
+    plsc->cmap0[i].a = a;
     plsc->cmap0[i].name = name;
 }
 
@@ -647,30 +884,30 @@ color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, char *name )
  * all systems.
 \*--------------------------------------------------------------------------*/
 
-#define color_def(i, r, g, b, n) \
-if (i >= imin && i <= imax) color_set(i, r, g, b, n);
+#define color_def(i, r, g, b, a, n)			\
+  if (i >= imin && i <= imax) color_set(i, r, g, b, a, n);
 
 static void
 plcmap0_def(int imin, int imax)
 {
     int i;
 
-    color_def(0,    0,   0,   0, "black" );	/* black */
-    color_def(1,  255,   0,   0, "red");	/* red */
-    color_def(2,  255, 255,   0, "yellow" );	/* yellow */
-    color_def(3,    0, 255,   0, "green" );	/* green */
-    color_def(4,  127, 255, 212, "aquamarine" );	/* aquamarine */
-    color_def(5,  255, 192, 203, "pink" );	/* pink */
-    color_def(6,  245, 222, 179, "wheat" );	/* wheat */
-    color_def(7,  190, 190, 190, "grey" );	/* grey */
-    color_def(8,  165,  42,  42, "brown" );	/* brown */
-    color_def(9,    0,   0, 255, "blue" );	/* blue */
-    color_def(10, 138,  43, 226, "BlueViolet" );	/* Blue Violet */
-    color_def(11,   0, 255, 255, "cyan" );	/* cyan */
-    color_def(12,  64, 224, 208, "turquoise" );	/* turquoise */
-    color_def(13, 255,   0, 255, "magenta" );	/* magenta */
-    color_def(14, 250, 128, 114, "salmon" );	/* salmon */
-    color_def(15, 255, 255, 255, "white" );	/* white */
+    color_def(0,    0,   0,   0, 1.0, "black" );        /* black */
+    color_def(1,  255,   0,   0, 1.0, "red");           /* red */
+    color_def(2,  255, 255,   0, 1.0, "yellow" );       /* yellow */
+    color_def(3,    0, 255,   0, 1.0, "green" );	/* green */
+    color_def(4,  127, 255, 212, 1.0, "aquamarine" );	/* aquamarine */
+    color_def(5,  255, 192, 203, 1.0, "pink" );	        /* pink */
+    color_def(6,  245, 222, 179, 1.0, "wheat" );	/* wheat */
+    color_def(7,  190, 190, 190, 1.0, "grey" );	        /* grey */
+    color_def(8,  165,  42,  42, 1.0, "brown" );	/* brown */
+    color_def(9,    0,   0, 255, 1.0, "blue" );	        /* blue */
+    color_def(10, 138,  43, 226, 1.0, "BlueViolet" );	/* Blue Violet */
+    color_def(11,   0, 255, 255, 1.0, "cyan" );	        /* cyan */
+    color_def(12,  64, 224, 208, 1.0, "turquoise" );	/* turquoise */
+    color_def(13, 255,   0, 255, 1.0, "magenta" );	/* magenta */
+    color_def(14, 250, 128, 114, 1.0, "salmon" );	/* salmon */
+    color_def(15, 255, 255, 255, 1.0, "white" );	/* white */
 
 /*     color_def(0, 255, 255, 255, "white" );	/\* white *\/ */
 /*     color_def(1,    0,   0,   0, "black" );	/\* black *\/ */
@@ -692,7 +929,7 @@ plcmap0_def(int imin, int imax)
 /* Any others are just arbitrarily set */
 
     for (i = 16; i <= imax; i++)
-	color_def(i, 255, 0, 0, "red"); 	/* red */
+      color_def(i, 255, 0, 0, 1.0, "red"); 	/* red */
 }
 
 /*--------------------------------------------------------------------------*\
@@ -977,7 +1214,7 @@ c_plrgbhls(PLFLT r, PLFLT g, PLFLT b, PLFLT *p_h, PLFLT *p_l, PLFLT *p_s)
 \*--------------------------------------------------------------------------*/
 
 void
-plwarn(char *errormsg)
+plwarn(const char *errormsg)
 {
     int was_gfx = 0;
 
@@ -1006,7 +1243,7 @@ plwarn(char *errormsg)
 \*--------------------------------------------------------------------------*/
 
 void
-plabort(char *errormsg)
+plabort(const char *errormsg)
 {
 
     if (abort_handler != NULL)
@@ -1045,7 +1282,7 @@ plabort(char *errormsg)
 \*--------------------------------------------------------------------------*/
 
 void
-plsabort(void (*handler) (char *))
+plsabort(void (*handler) (const char *))
 {
     abort_handler = handler;
 }
@@ -1063,7 +1300,7 @@ plsabort(void (*handler) (char *))
 \*--------------------------------------------------------------------------*/
 
 void
-plexit(char *errormsg)
+plexit(const char *errormsg)
 {
     int status = 1;
 
@@ -1088,7 +1325,7 @@ plexit(char *errormsg)
 \*--------------------------------------------------------------------------*/
 
 void
-plsexit(int (*handler) (char *))
+plsexit(int (*handler) (const char *))
 {
     exit_handler = handler;
 }
@@ -1176,7 +1413,7 @@ pl_cmd(PLINT op, void *ptr)
 \*--------------------------------------------------------------------------*/
 
 char *
-plFindCommand(char *fn)
+plFindCommand(const char *fn)
 {
     char *fs = NULL, *dn;
 
@@ -1251,7 +1488,7 @@ plFindCommand(char *fn)
 \*--------------------------------------------------------------------------*/
 
 FILE *
-plLibOpen(char *fn)
+plLibOpen(const char *fn)
 {
     FILE *ret = NULL;
 
@@ -1268,7 +1505,7 @@ plLibOpen(char *fn)
 }
 
 PDFstrm *
-plLibOpenPdfstrm(char *fn)
+plLibOpenPdfstrm(const char *fn)
 {
     PDFstrm *file;
     char *fs = NULL, *dn = NULL;
@@ -1438,7 +1675,7 @@ plFindName(char *p)
 \*--------------------------------------------------------------------------*/
 
 void
-plGetName(char *dir, char *subdir, char *filename, char **filespec)
+plGetName(const char *dir, const char *subdir, const char *filename, char **filespec)
 {
     int lfilespec;
 
@@ -1513,11 +1750,13 @@ plcol_interp(PLStream *pls, PLColor *newcolor, int i, int ncol)
 	newcolor->r = pls->cmap1[il].r;
 	newcolor->g = pls->cmap1[il].g;
 	newcolor->b = pls->cmap1[il].b;
+	newcolor->a = pls->cmap1[il].a;
     }
     else {
 	newcolor->r = (1.-delta) * pls->cmap1[il].r + delta * pls->cmap1[ir].r;
 	newcolor->g = (1.-delta) * pls->cmap1[il].g + delta * pls->cmap1[ir].g;
 	newcolor->b = (1.-delta) * pls->cmap1[il].b + delta * pls->cmap1[ir].b;
+	newcolor->a = (1.-delta) * pls->cmap1[il].a + delta * pls->cmap1[ir].a;
     }
 }
 
@@ -1788,7 +2027,7 @@ plGinInit(PLGraphicsIn *gin)
 \*--------------------------------------------------------------------------*/
 
 PLINT
-plGetInt(char *s)
+plGetInt(const char *s)
 {
     int m;
     int i = 0;
@@ -1818,7 +2057,7 @@ plGetInt(char *s)
 \*--------------------------------------------------------------------------*/
 
 PLFLT
-plGetFlt(char *s)
+plGetFlt(const char *s)
 {
     PLFLT m;
     double m1;
