@@ -1,4 +1,4 @@
-/* $Id: pldeprecated.c 6252 2005-05-03 14:47:55Z airwin $
+/* $Id: pldeprecated.c 8033 2007-11-23 15:28:09Z andrewross $
 
     Copyright (C) 2005  Alan W. Irwin
 
@@ -31,7 +31,7 @@
  * Use plparseopts instead.
 \*--------------------------------------------------------------------------*/
 int
-plParseOpts(int *p_argc, char **argv, PLINT mode)
+plParseOpts(int *p_argc, const char **argv, PLINT mode)
 {
    return c_plparseopts(p_argc, argv, mode);
 }
