@@ -1,4 +1,4 @@
-/* $Id: plline.c,v 1.39 2006/05/13 05:22:43 airwin Exp $
+/* $Id: plline.c 7786 2007-08-08 10:39:58Z andrewross $
 
 	Routines dealing with line generation.
 
@@ -333,6 +333,7 @@ void
 c_plstyl(PLINT nms, PLINT *mark, PLINT *space)
 {
     short int i;
+    short int flag;
 
     if (plsc->level < 1) {
 	plabort("plstyl: Please call plinit first");
@@ -342,11 +343,20 @@ c_plstyl(PLINT nms, PLINT *mark, PLINT *space)
 	plabort("plstyl: Broken lines cannot have <0 or >10 elements");
 	return;
     }
+    flag = 1;
     for (i = 0; i < nms; i++) {
 	if ((mark[i] < 0) || (space[i] < 0)) {
 	    plabort("plstyl: Mark and space lengths must be > 0");
 	    return;
 	}
+	if ((mark[i] != 0) || (space[i] != 0)) {
+            flag = 0;
+        }
+    }
+    /* Check for blank style */
+    if ((nms > 0) && (flag == 1)) {
+      plabort("plstyl: At least one mark or space must be > 0");
+      return;
     }
 
     plsc->nms = nms;
@@ -511,8 +521,11 @@ plP_pllclp(PLINT *x, PLINT *y, PLINT npts,
         xclp = _xclp;
         yclp = _yclp;
     } else {
-        xclp = (short *) malloc( npts*sizeof(short) ) ;
-        yclp = (short *) malloc( npts*sizeof(short) ) ;
+        if (((xclp = (short *) malloc( npts*sizeof(short) ))==NULL)||
+            ((yclp = (short *) malloc( npts*sizeof(short) ))==NULL))
+            {
+              plexit("plP_pllclp: Insufficient memory");
+            }
     }
 
     for (i = 0; i < npts - 1; i++) {
@@ -607,14 +620,13 @@ circulation(PLINT *x, PLINT *y, PLINT npts)
     int i;
 
     xproduct = 0.0 ;
-    for (i = 0; i < npts - 1; i++) {
-	x1 = x[i]; x2 = x[i+1];
-	y1 = y[i]; y2 = y[i+1];
-	if (i < npts-2) {
-	    x3 = x[i+2]; y3 = y[i+2];
-	} else {
-	    x3 = x[0]; y3 = y[0];
-	}
+    x1 = x[0];
+    y1 = y[0];
+    for (i = 1; i < npts - 2; i++) {
+	x2 = x[i+1];
+	y2 = y[i+1];
+	x3 = x[i+2];
+	y3 = y[i+2];
 	xproduct = xproduct + (x2-x1)*(y3-y2) - (y2-y1)*(x3-x2);
     }
 
@@ -657,8 +669,11 @@ plP_plfclp(PLINT *x, PLINT *y, PLINT npts,
         xclp = _xclp;
         yclp = _yclp;
     } else {
-        xclp = (short *) malloc( (2*npts+2)*sizeof(short) ) ;
-        yclp = (short *) malloc( (2*npts+2)*sizeof(short) ) ;
+        if (((xclp = (short *) malloc( (2*npts+2)*sizeof(short) ))==NULL)||
+            ((yclp = (short *) malloc( (2*npts+2)*sizeof(short) ))==NULL))
+            {
+              plexit("plP_plfclp: Insufficient memory");
+            }
     }
 
 
@@ -810,26 +825,13 @@ plP_plfclp(PLINT *x, PLINT *y, PLINT npts,
 */
 
     if (iclp == 0) {
-	PLINT xmin1, xmax1, ymin1, ymax1;
-	xmin1 = xmax1 = x[0];
-	ymin1 = ymax1 = y[0];
-	for (i = 1; i < npts; i++) {
-	    if (x[i] < xmin1) xmin1 = x[i];
-	    if (x[i] > xmax1) xmax1 = x[i];
-	    if (y[i] < ymin1) ymin1 = y[i];
-	    if (y[i] > ymax1) ymax1 = y[i];
-	}
-	if (xmin1 <= xmin && xmax1 >= xmax && ymin1 <= ymin && ymax1 >= ymax ) {
-	    xclp[iclp] = xmin; yclp[iclp] = ymin; iclp++;
-	    xclp[iclp] = xmin; yclp[iclp] = ymax; iclp++;
-	    xclp[iclp] = xmax; yclp[iclp] = ymax; iclp++;
-	    xclp[iclp] = xmax; yclp[iclp] = ymin; iclp++;
+	if ( inside_lb ) {
 	    (*draw)(xclp, yclp, iclp);
 
-	    if ( xclp != _xclp ) {
-	        free( xclp );
-	        free( yclp );
-	    }
+	if ( xclp != _xclp ) {
+	    free( xclp );
+	    free( yclp );
+	}
 
 
 	    return;
@@ -1002,7 +1004,7 @@ plP_plfclp(PLINT *x, PLINT *y, PLINT npts,
 	else if (xclp[0] == xmin && yclp[iclp-1] == ymax && dir < 0)
 	{
 	    xclp[iclp] = xmax; yclp[iclp] = ymax; iclp++;
-	    xclp[iclp] = xmin; yclp[iclp] = ymax; iclp++;
+	    xclp[iclp] = xmax; yclp[iclp] = ymin; iclp++;
 	    xclp[iclp] = xmin; yclp[iclp] = ymin; iclp++;
 	}
     }
