@@ -1,4 +1,4 @@
-/* $Id: plot3d.c 7876 2007-09-20 01:51:19Z hbabcock $
+/* $Id: plot3d.c 8082 2007-12-12 15:44:17Z andrewross $
 
 	3d plot routines.
 
@@ -448,7 +448,7 @@ c_plsurf3dl(PLFLT *x, PLFLT *y, PLFLT **z, PLINT nx, PLINT ny,
     PLINT nsub=0;
 
     /* get the tick spacing */
-    pldtik(zmin, zmax, &tick, &nsub);
+    pldtik(zmin, zmax, &tick, &nsub, FALSE);
 
     /* determine the vertices for the background grid line */
     bx[0] = (ixOrigin!=ixmin && ixFast==0) || ixFast > 0 ? xmax : xmin;
@@ -1537,7 +1537,7 @@ plgrid3(PLFLT tick)
     zmin = (zmax_in > zmin_in) ? zmin_in: zmax_in;
     zmax = (zmax_in > zmin_in) ? zmax_in: zmin_in;
 
-    pldtik(zmin, zmax, &tick, &nsub);
+    pldtik(zmin, zmax, &tick, &nsub, FALSE);
     tp = tick * floor(zmin / tick) + tick;
     pl3upv = 0;
 
